#...
.*warning: orphan section `\.notbad' from `tmpdir/.*\.o' being placed in section `\.notbad'
#...
.*warning: orphan section `\.note\.bar' from `tmpdir/.*\.o' being placed in section `\.note\.bar'
#...
