# Check EVEX instructions

	.allow_index_reg
	.text
_start:
	.byte 0x62, 0xf1, 0xd6, 0x38, 0x2a, 0xf0
	.byte 0x62, 0xf1, 0xd7, 0x38, 0x2a, 0xf0
	.byte 0x62, 0xf1, 0xd6, 0x08, 0x7b, 0xf0
	.byte 0x62, 0xf1, 0xd7, 0x08, 0x7b, 0xf0
	.byte 0x62, 0xf1, 0xd6, 0x38, 0x7b, 0xf0
	.byte 0x62, 0xf1, 0xd7, 0x38, 0x7b, 0xf0
