[^:]+: Assembler messages:
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erridr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'errselr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'errselr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxfr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxctlr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxctlr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxstatus_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxstatus_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxaddr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxaddr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc0_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc0_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc1_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc1_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'vsesr_el2'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'disr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'disr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'vdisr_el2'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erridr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'errselr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'errselr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxfr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxctlr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxctlr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxstatus_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxstatus_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxaddr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxaddr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc0_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc0_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc1_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'erxmisc1_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'vsesr_el2'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'disr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'disr_el1'
^[^:]+:[0-9]+: Error: selected processor does not support system register name 'vdisr_el2'
