Primary GOT:
 Canonical gp value: 000000007ffffff0

 Reserved entries:
           Address     Access          Initial Purpose
  000000007fff8000 -32752\(gp\) 0000000000000000 Lazy resolver
  000000007fff8008 -32744\(gp\) 8000000000000000 Module pointer \(GNU extension\)

PLT GOT:

 Reserved entries:
           Address          Initial Purpose
  000000007fff7fe8 0000000000000000 PLT lazy resolver
  000000007fff7ff0 0000000000000000 Module pointer

 Entries:
           Address          Initial         Sym\.Val\. Type    Ndx Name
  000000007fff7ff8 0000000010000280 0000000000000000 FUNC    UND bar
