#name: TLS Local Exec link test
#source: tls-le.s
#ld:
#objdump: -h

.*:     file format .*

Sections:
Idx Name          Size      VMA       LMA       File off  Algn
  0 .text         .*
                  .*
  1 .tbss         .*
                  .*
