[^:]*: Assembler messages:
[^:]*:[0-9]+: Error: selected processor does not support system register name 'id_aa64mmfr2_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erridr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'errselr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'errselr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxfr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxctlr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxctlr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxstatus_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxstatus_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxaddr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxaddr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxmisc0_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxmisc0_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxmisc1_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'erxmisc1_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'vsesr_el2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'disr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'disr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'vdisr_el2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cvap'
[^:]*:[0-9]+: Error: selected processor does not support system register name 's1e1rp'
[^:]*:[0-9]+: Error: selected processor does not support system register name 's1e1wp'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmblimitr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmblimitr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmbptr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmbptr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmbsr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmbsr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmscr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmscr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsicr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsicr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsirr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsirr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsfcr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsfcr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsevfr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsevfr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmslatfr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmslatfr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmscr_el2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmscr_el2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmscr_el12'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmscr_el12'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmbidr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'pmsidr_el1'
