#as: -mcpu=nps400
#readelf: -h

#...
  Class:                             ELF32
  Data:                              2's complement, .* endian
  Version:                           1 \(current\)
  OS/ABI:                            UNIX - System V
  ABI Version:                       0
  Type:                              REL \(Relocatable file\)
  Machine:                           ARCompact
  Version:                           0x1
#...
  Flags:                             0x\d03, ARC700, .*
#...
