Primary GOT:
 Canonical gp value: 00097ff0

 Reserved entries:
   Address     Access  Initial Purpose
  00090000 -32752\(gp\) 00000000 Lazy resolver
  00090004 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Global entries:
   Address     Access  Initial Sym\.Val\. Type    Ndx Name
  00090008 -32744\(gp\) 000800f9 000800f9 FUNC    UND bar
  0009000c -32740\(gp\) 000800ed 000800ed FUNC    UND foo
