
.*


Disassembly of section \.gnu.sgstubs:

00020000 <glob_entry_veneer2>:
   20000:	e97f e97f 	sg
   20004:	f7e8 b800 	b\.w	8008 <__acle_se_glob_entry_veneer2>

00020008 <weak_entry_veneer2>:
   20008:	e97f e97f 	sg
   2000c:	f7e7 bffe 	b\.w	800c <__acle_se_weak_entry_veneer2>

00020010 <glob_entry_veneer1>:
   20010:	e97f e97f 	sg
   20014:	f7e7 bff4 	b\.w	8000 <__acle_se_glob_entry_veneer1>

00020018 <weak_entry_veneer1>:
   20018:	e97f e97f 	sg
   2001c:	f7e7 bff2 	b\.w	8004 <__acle_se_weak_entry_veneer1>
