.*Assembler messages:
.*Warning: Read-only CSR is written `csrrw a0,cycle,a1'
.*Warning: Read-only CSR is written `csrrw a0,cycle,zero'
.*Warning: Read-only CSR is written `csrrw zero,cycle,a1'
.*Warning: Read-only CSR is written `csrrw zero,cycle,zero'
.*Warning: Read-only CSR is written `csrw cycle,a1'
.*Warning: Read-only CSR is written `csrw cycle,zero'
.*Warning: Read-only CSR is written `csrrwi a0,cycle,0xb'
.*Warning: Read-only CSR is written `csrrwi a0,cycle,0x0'
.*Warning: Read-only CSR is written `csrrwi zero,cycle,0xb'
.*Warning: Read-only CSR is written `csrrwi zero,cycle,0x0'
.*Warning: Read-only CSR is written `csrwi cycle,0xb'
.*Warning: Read-only CSR is written `csrwi cycle,0x0'
.*Warning: Read-only CSR is written `csrrs a0,cycle,a1'
.*Warning: Read-only CSR is written `csrrs zero,cycle,a1'
.*Warning: Read-only CSR is written `csrs cycle,a0'
.*Warning: Read-only CSR is written `csrrsi a0,cycle,0xb'
.*Warning: Read-only CSR is written `csrrsi zero,cycle,0xb'
.*Warning: Read-only CSR is written `csrsi cycle,0xb'
.*Warning: Read-only CSR is written `csrrc a0,cycle,a1'
.*Warning: Read-only CSR is written `csrrc zero,cycle,a1'
.*Warning: Read-only CSR is written `csrc cycle,a0'
.*Warning: Read-only CSR is written `csrrci a0,cycle,0xb'
.*Warning: Read-only CSR is written `csrrci zero,cycle,0xb'
.*Warning: Read-only CSR is written `csrci cycle,0xb'
