
Primary GOT:
 Canonical gp value: 000a7ff0

 Reserved entries:
   Address     Access  Initial Purpose
  000a0000 -32752\(gp\) 00000000 Lazy resolver
  000a0004 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  000a0008 -32744\(gp\) 000a2000
  000a000c -32740\(gp\) 00043080
  000a0010 -32736\(gp\) 00043060

 Global entries:
   Address     Access  Initial Sym\.Val\. Type    Ndx Name
  000a0014 -32732\(gp\) 00000000 00000000 FUNC    UND extf2
  000a0018 -32728\(gp\) 000440a0 000440a0 FUNC    UND extf1
  000a001c -32724\(gp\) 00000000 00000000 OBJECT  UND extd1
  000a0020 -32720\(gp\) 00000000 00000000 OBJECT  UND extd4


PLT GOT:

 Reserved entries:
   Address  Initial Purpose
  00081000 00000000 PLT lazy resolver
  00081004 00000000 Module pointer

 Entries:
   Address  Initial Sym.Val. Type    Ndx Name
  00081008 00043040 00043060 FUNC    UND extf4
  0008100c 00043040 00000000 FUNC    UND extf5
  00081010 00043040 00000000 FUNC    UND extf3
