.*: Assembler messages:
.*:2: Error: the source register must not be \$0 `blezc \$0,.'
.*:3: Error: the source register must not be \$0 `bgezc \$0,.'
.*:4: Error: the source register must not be \$0 `bgtzc \$0,.'
.*:5: Error: the source register must not be \$0 `bltzc \$0,.'
.*:6: Error: the source register must not be \$0 `beqzc \$0,.'
.*:7: Error: the source register must not be \$0 `bnezc \$0,.'
.*:8: Error: the source register must not be \$0 `bgec \$0,\$2,.'
.*:9: Error: invalid operands `bgec \$2,\$0,.'
.*:10: Error: invalid operands `bgec \$2,\$2,.'
.*:11: Error: the source register must not be \$0 `bgeuc \$0,\$2,.'
.*:12: Error: invalid operands `bgeuc \$2,\$0,.'
.*:13: Error: invalid operands `bgeuc \$2,\$2,.'
.*:14: Error: the source register must not be \$0 `bltc \$0,\$2,.'
.*:15: Error: invalid operands `bltc \$2,\$0,.'
.*:16: Error: invalid operands `bltc \$2,\$2,.'
.*:17: Error: the source register must not be \$0 `bltuc \$0,\$2,.'
.*:18: Error: invalid operands `bltuc \$2,\$0,.'
.*:19: Error: invalid operands `bltuc \$2,\$2,.'
.*:20: Error: the source register must not be \$0 `beqc \$0,\$2,.'
.*:21: Error: invalid operands `beqc \$2,\$0,.'
.*:22: Error: invalid operands `beqc \$2,\$2,.'
.*:23: Error: the source register must not be \$0 `bnec \$0,\$2,.'
.*:24: Error: invalid operands `bnec \$2,\$0,.'
.*:25: Error: invalid operands `bnec \$2,\$2,.'
.*:26: Error: the source register must not be \$0 `daui \$2,\$0,1'
