# Source file used to test the register names

.set noat
.set nobreak

foo:
# Standard register names
	movi zero, 123
	movi at, 123
	movi r2, 123
	movi r3, 123
	movi r4, 123
	movi r5, 123
	movi r6, 123
	movi r7, 123
	movi r8, 123
	movi r9, 123
	movi r10, 123
	movi r11, 123
	movi r12, 123
	movi r13, 123
	movi r14, 123
	movi r15, 123
	movi r16, 123
	movi r17, 123
	movi r18, 123
	movi r19, 123
	movi r20, 123
	movi r21, 123
	movi r22, 123
	movi r23, 123
	movi et, 123
	movi bt, 123
	movi gp, 123
	movi sp, 123
	movi fp, 123
	movi ea, 123
	movi sstatus, 123
	movi ra, 123
# Alternative names for special registers
	movi r0, 123
	movi r1, 123
	movi r24, 123
	movi r25, 123
	movi r26, 123
	movi r27, 123
	movi r28, 123
	movi r29, 123
	movi r30, 123
	movi ba, 123
	movi r31, 123
