# readelf: -A
# This test is only valid on ELF based ports.
#notarget: *-*-pe *-*-wince
Attribute Section: aeabi
File Attributes
  Tag_CPU_arch: v7
  Tag_THUMB_ISA_use: Thumb-2
  Tag_DIV_use: Allowed in v7-A with integer division extension

