[^:]*: Assembler messages:
.*: Warning: SVE `movprfx' compatible instruction expected -- `bic z1.D,z1.D,z2.D'
.*: Warning: SVE `movprfx' compatible instruction expected -- `bic z1.D,z1.D,z2.D'
.*: Warning: predicated instruction expected after `movprfx' -- `bic z1.D,z1.D,#12'
