.*: Assembler messages:
.*:1: Error: invalid operands.*
.*:2: Error: a destination register must be supplied.*
.*:3: Error: source and destination must be different.*
.*:10: Error: invalid operands.*
.*:11: Error: a destination register must be supplied.*
.*:12: Error: source and destination must be different.*
