.*: Assembler messages:
.*:5: Error: operand must be LR register -- `wls r1,r2,.LB1'
.*:6: Error: operand must be LR register -- `dls r2,r2'
.*:7: Error: r15 not allowed here -- `dls lr,pc'
.*:8: Error: branch out of range or not a multiple of 2
.*:9: Error: branch out of range or not a multiple of 2
.*:10: Error: branch out of range or not a multiple of 2
