  {
    /* MOD_EVEX_0F12_PREFIX_0 */
    { "vmovlpX",	{ XMM, Vex, EXxmm_mq }, PREFIX_OPCODE },
    { VEX_W_TABLE (EVEX_W_0F12_P_0_M_1) },
  },
  {
    /* MOD_EVEX_0F12_PREFIX_2 */
    { "vmovlpX",	{ XMM, Vex, EXxmm_mq }, PREFIX_OPCODE },
  },
  {
    /* MOD_EVEX_0F13 */
    { "vmovlpX",	{ EXxmm_mq, XMM }, PREFIX_OPCODE },
  },
  {
    /* MOD_EVEX_0F16_PREFIX_0 */
    { "vmovhpX",	{ XMM, Vex, EXxmm_mq }, PREFIX_OPCODE },
    { VEX_W_TABLE (EVEX_W_0F16_P_0_M_1) },
  },
  {
    /* MOD_EVEX_0F16_PREFIX_2 */
    { "vmovhpX",	{ XMM, Vex, EXxmm_mq }, PREFIX_OPCODE },
  },
  {
    /* MOD_EVEX_0F17 */
    { "vmovhpX",	{ EXxmm_mq, XMM }, PREFIX_OPCODE },
  },
  {
    /* MOD_EVEX_0F2B */
    { "vmovntpX",	{ EXx, XM }, PREFIX_OPCODE },
  },
  {
    /* MOD_EVEX_0F38C6_REG_1 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C6_REG_1) },
  },
  {
    /* MOD_EVEX_0F38C6_REG_2 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C6_REG_2) },
  },
  {
    /* MOD_EVEX_0F38C6_REG_5 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C6_REG_5) },
  },
  {
    /* MOD_EVEX_0F38C6_REG_6 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C6_REG_6) },
  },
  {
    /* MOD_EVEX_0F38C7_REG_1 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C7_REG_1) },
  },
  {
    /* MOD_EVEX_0F38C7_REG_2 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C7_REG_2) },
  },
  {
    /* MOD_EVEX_0F38C7_REG_5 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C7_REG_5) },
  },
  {
    /* MOD_EVEX_0F38C7_REG_6 */
    { PREFIX_TABLE (PREFIX_EVEX_0F38C7_REG_6) },
  },
