Primary GOT:
 Canonical gp value: 00028040

 Reserved entries:
   Address     Access  Initial Purpose
  00020050 -32752\(gp\) 00000000 Lazy resolver
  00020054 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  00020058 -32744\(gp\) 00020000
