Primary GOT:
 Canonical gp value: 0000000000008270

 Reserved entries:
           Address     Access          Initial Purpose
  0000000000000280 -32752\(gp\) 0000000000000000 Lazy resolver
  0000000000000288 -32744\(gp\) 8000000000000000 Module pointer \(GNU extension\)

 Local entries:
           Address     Access          Initial
  0000000000000290 -32736\(gp\) 0000000000000000

 Global entries:
           Address     Access          Initial         Sym\.Val\. Type    Ndx Name
  0000000000000298 -32728\(gp\) 0000000000000000 0000000000000000 NOTYPE  ABS __gnu_absolute_zero
