[^:]*: Assembler messages:
[^:]*:6: Error: unrecognised instruction size modifier .z
[^:]*:7: Error: junk found after instruction: mov.bc r1,r2
[^:]*:8: Error: junk found after instruction: mov.cd r1,r2
[^:]*:9: Error: junk found after instruction: mov.cd r1,r2
[^:]*:10: Warning: no size modifier after period, .w assumed
[^:]*:10: Warning: a NOP might be needed here, before this interrupt state change
[^:]*:11: Error: instruction bis.a does not exist
[^:]*:16: Warning: a NOP might also be needed here, after the instruction that changed interrupt state
[^:]*:16: Warning: a NOP might be needed here, before an interrupt enable instruction
[^:]*:25: Warning: a NOP might be needed here, after an interrupt disable instruction
[^:]*:26: Warning: a NOP might be needed here, after an interrupt enable instruction
[^:]*:29: Warning: a NOP might be needed here, after an interrupt disable instruction
[^:]*:31: Warning: a NOP might be needed here, after an interrupt disable instruction
[^:]*:32: Warning: a NOP might be needed here, after an interrupt disable instruction
[^:]*:33: Warning: a NOP might be needed here, after an interrupt disable instruction
[^:]*:34: Warning: a NOP might be needed here, after an interrupt enable instruction
[^:]*: Warning: a NOP might be needed after the interrupt state change at the end of the file
