.*: Assembler messages:
.*:1: Error: .endp outside of procedure
.*:2: Error: .personality outside of procedure
.*:3: Error: .unwentry outside of procedure
.*:4: Error: .unwabi outside of procedure
.*:5: Error: .handlerdata outside of procedure
.*:6: Error: .prologue outside of procedure
.*:7: Error: .body outside of procedure
.*:8: Error: .spillreg outside of procedure
.*:9: Error: .spillreg.p outside of procedure
.*:10: Error: .spillsp outside of procedure
.*:11: Error: .spillsp.p outside of procedure
.*:12: Error: .spillpsp outside of procedure
.*:13: Error: .spillpsp.p outside of procedure
.*:14: Error: .restorereg outside of procedure
.*:15: Error: .restorereg.p outside of procedure
.*:24: Error: .label_state outside of body region
.*:25: Error: .copy_state outside of body region
.*:26: Error: .fframe outside of prologue
.*:27: Error: .vframe outside of prologue
.*:28: Error: .vframesp outside of prologue
.*:29: Error: .spill outside of prologue
.*:30: Error: .restore outside of body region
.*:31: Error: .save outside of prologue
.*:32: Error: .savesp outside of prologue
.*:33: Error: .savepsp outside of prologue
.*:34: Error: .save.g outside of prologue
.*:35: Error: .save.gf outside of prologue
.*:36: Error: .save.f outside of prologue
.*:37: Error: .save.b outside of prologue
.*:38: Error: .altrp outside of prologue
.*:43: Error: .prologue within prologue
.*:51: Error: .body outside of procedure
.*:58: Warning: Initial .prologue.*
.*:65: Warning: Initial .body.*
