Primary GOT:
 Canonical gp value: 00008270

 Reserved entries:
   Address     Access  Initial Purpose
  00000280 -32752\(gp\) 00000000 Lazy resolver
  00000284 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Global entries:
   Address     Access  Initial Sym\.Val\. Type    Ndx Name
  00000288 -32744\(gp\) 00000000 00000000 OBJECT  UND obj
