# Test for correct generation of hex prefixes.

	.sect .text

	ldaa	0x1234
	ldab	#0x12
	ldd		*0x23
	ldx		#0x1234
	movw	0x1234, 0x2345
	movb	0x3456, 0x4567
	orx		0x8765
	call	0x8007, 0x3d
	movw	#0x1234, 0x2345
	movb	#0x23, 0x3456
