	.section .debug_info,"",%progbits
	.hidden t.c.4903c230
	.globl t.c.4903c230
t.c.4903c230:
	.dc.a  .Ldebug_abbrev0

	.section .debug_abbrev,"",%progbits
.Ldebug_abbrev0:
	.byte 0x61
	.byte 0x62
	.byte 0x63
	.byte 0x64
