# objdump: -dr
# as: -linkrelax
# source: get-op.s
.*:     file format elf64-mmix

Disassembly of section \.text:

0000000000000000 <Main>:
   0:	fe7b0004 	get \$123,rJ
   4:	fe2d0013 	get \$45,rG
   8:	fef5001f 	get \$245,rZZ
