Static GOT:
 Canonical gp value: 00008020

 Reserved entries:
   Address     Access    Value
  00000030 -32752\(gp\) 00000000
  00000034 -32748\(gp\) 80000000

 Local entries:
   Address     Access    Value
  00000038 -32744\(gp\) 00000000
