[^:]*: Assembler messages:
[^:]*:11: Error: immediate value out of range -- `vcvt.f16.s16 q0,q1,#0'
[^:]*:12: Error: immediate value out of range -- `vcvt.f16.s16 q0,q1,#17'
[^:]*:13: Error: immediate value out of range -- `vcvt.f16.u16 q0,q1,#0'
[^:]*:14: Error: immediate value out of range -- `vcvt.f16.u16 q0,q1,#17'
[^:]*:15: Error: immediate value out of range -- `vcvt.s16.f16 q0,q1,#0'
[^:]*:16: Error: immediate value out of range -- `vcvt.s16.f16 q0,q1,#17'
[^:]*:17: Error: immediate value out of range -- `vcvt.u16.f16 q0,q1,#0'
[^:]*:18: Error: immediate value out of range -- `vcvt.u16.f16 q0,q1,#17'
[^:]*:19: Error: immediate value out of range -- `vcvt.f32.s32 q0,q1,#0'
[^:]*:20: Error: immediate value out of range -- `vcvt.f32.s32 q0,q1,#33'
[^:]*:21: Error: immediate value out of range -- `vcvt.f32.u32 q0,q1,#0'
[^:]*:22: Error: immediate value out of range -- `vcvt.f32.u32 q0,q1,#33'
[^:]*:23: Error: immediate value out of range -- `vcvt.s32.f32 q0,q1,#0'
[^:]*:24: Error: immediate value out of range -- `vcvt.s32.f32 q0,q1,#33'
[^:]*:25: Error: immediate value out of range -- `vcvt.u32.f32 q0,q1,#0'
[^:]*:26: Error: immediate value out of range -- `vcvt.u32.f32 q0,q1,#33'
[^:]*:27: Error: bad type in SIMD instruction -- `vcvt.f64.s64 q0,q1,#1'
[^:]*:28: Error: bad type in SIMD instruction -- `vcvt.f64.u64 q0,q1,#1'
[^:]*:29: Error: bad type in SIMD instruction -- `vcvt.s64.f64 q0,q1,#1'
[^:]*:30: Error: bad type in SIMD instruction -- `vcvt.u64.f64 q0,q1,#1'
[^:]*:31: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:31: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:31: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:31: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:31: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:31: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:33: Error: syntax error -- `vcvteq.f16.s16 q0,q1,#1'
[^:]*:34: Error: syntax error -- `vcvteq.f16.s16 q0,q1,#1'
[^:]*:36: Error: syntax error -- `vcvteq.f16.s16 q0,q1,#1'
[^:]*:37: Error: vector predicated instruction should be in VPT/VPST block -- `vcvtt.f16.s16 q0,q1,#1'
[^:]*:39: Error: instruction missing MVE vector predication code -- `vcvt.f16.s16 q0,q1,#1'
[^:]*:48: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:48: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:48: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:48: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:48: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:48: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:49: Error: bad type in SIMD instruction -- `vcvt.f64.s64 q0,q1'
[^:]*:50: Error: bad type in SIMD instruction -- `vcvt.f64.u64 q0,q1'
[^:]*:51: Error: bad type in SIMD instruction -- `vcvt.s64.f64 q0,q1'
[^:]*:52: Error: bad type in SIMD instruction -- `vcvt.u64.f64 q0,q1'
[^:]*:54: Error: syntax error -- `vcvteq.u32.f32 q0,q1'
[^:]*:55: Error: syntax error -- `vcvteq.u32.f32 q0,q1'
[^:]*:57: Error: syntax error -- `vcvteq.u32.f32 q0,q1'
[^:]*:58: Error: vector predicated instruction should be in VPT/VPST block -- `vcvtt.u32.f32 q0,q1'
[^:]*:60: Error: instruction missing MVE vector predication code -- `vcvt.u32.f32 q0,q1'
[^:]*:69: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:69: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:69: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:69: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:69: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:69: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:70: Error: bad type in SIMD instruction -- `vcvtb.f16.f64 q0,q1'
[^:]*:71: Error: bad type in SIMD instruction -- `vcvtb.f64.f16 q0,q1'
[^:]*:72: Error: bad type in SIMD instruction -- `vcvtb.f32.f64 q0,q1'
[^:]*:73: Error: bad type in SIMD instruction -- `vcvtb.f64.f32 q0,q1'
[^:]*:75: Error: syntax error -- `vcvtbeq.f16.f32 q0,q1'
[^:]*:76: Error: syntax error -- `vcvtbeq.f16.f32 q0,q1'
[^:]*:78: Error: syntax error -- `vcvtbeq.f16.f32 q0,q1'
[^:]*:79: Error: vector predicated instruction should be in VPT/VPST block -- `vcvtbt.f16.f32 q0,q1'
[^:]*:81: Error: instruction missing MVE vector predication code -- `vcvtb.f16.f32 q0,q1'
[^:]*:82: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:82: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:82: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:82: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:82: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:82: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:83: Error: bad type in SIMD instruction -- `vcvtt.f16.f64 q0,q1'
[^:]*:84: Error: bad type in SIMD instruction -- `vcvtt.f64.f16 q0,q1'
[^:]*:85: Error: bad type in SIMD instruction -- `vcvtt.f32.f64 q0,q1'
[^:]*:86: Error: bad type in SIMD instruction -- `vcvtt.f64.f32 q0,q1'
[^:]*:88: Error: syntax error -- `vcvtteq.f16.f32 q0,q1'
[^:]*:89: Error: syntax error -- `vcvtteq.f16.f32 q0,q1'
[^:]*:91: Error: syntax error -- `vcvtteq.f16.f32 q0,q1'
[^:]*:92: Error: vector predicated instruction should be in VPT/VPST block -- `vcvttt.f16.f32 q0,q1'
[^:]*:94: Error: instruction missing MVE vector predication code -- `vcvtt.f16.f32 q0,q1'
