#objdump: -d
#name:    
#source:  dec.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <L1>:
   0:	40          	dec d2
   1:	41          	dec d3
   2:	42          	dec d4
   3:	43          	dec d5
   4:	44          	dec d0
   5:	45          	dec d1
   6:	46          	dec d6
   7:	47          	dec d7
