[^:]*: Assembler messages:
[^:]*:4: Warning: system register name 'spsr_svc' is deprecated and may be removed in a future release
[^:]*:5: Warning: system register name 'spsr_hyp' is deprecated and may be removed in a future release
