#source: attr-gnu-8-0.s
#source: attr-gnu-8-2.s
#ld: -r
#readelf: -A

Attribute Section: gnu
File Attributes
  Tag_GNU_MIPS_ABI_FP: Hard float \(double precision\)
  Tag_GNU_MIPS_ABI_MSA: \?\?\? \(2\)
#pass
