	.allow_index_reg
	.text
	
_start:

    BEXTR    $0x0,%eax,%r15d
    BEXTR    $0x4DF1,%r15d,%r10d
    BEXTR    $0x2DA55E92,%r13d,%r14d
    BEXTR    $0x7FFFFFFF,0x6(%r13d,%r15d,2),%eax
    BEXTR    $0x251EF761,%r11d,%ebp
    BEXTR    $0x2B39,(%rdi,%rdx,8),%r15d
    BEXTR    $0x92,0xDEAD(,%r14),%r9d
    BEXTR    $0x6887,(%r13),%esi
    BEXTR    $0xD,(%r9d),%ecx
    BEXTR    $0x2B,0x40D8(,%rax),%ebx
    BEXTR    $0xEA2D,(%r8),%r8d
    BEXTR    $0x6C,(%r13d),%r12d
    BEXTR    $0x9E3B,0x8C8F(,%rcx),%r11d
    BEXTR    $0xF,(%r10d,%eax),%esp
    BEXTR    $0xDEAD,-0x0(,%r9d,8),%edi
    BEXTR    $0xCAFE,%r8d,%eax
    BEXTR    $0x7D263BB9,0x10BC(%r9),%r8
    BEXTR    $0x67,(,%r12d,2),%r15
    BEXTR    $0x0,%rax,%rax
    BEXTR    $0x539B,(%esi),%rsp
    BEXTR    $0x7FFFFFFF,(%r8),%rcx
    BEXTR    $0x1,0x3FFFFFFF(,%edi),%rax
    BEXTR    $0x9E,-0x227C(%r8d,%r14d),%rsi
    BEXTR    $0x2A6C464,%r15,%rax
    BEXTR    $0x4,0x2(%edi,%r11d,1),%r9
    BEXTR    $0x2,%rdi,%rbp
    BEXTR    $0x781E7EFB,(%r14d,%edx,1),%rdx
    BEXTR    $0x70CB4039,0xDB68(%r11,%r13),%r13
    BEXTR    $0x1373,(%r14),%r10
    BEXTR    $0x556D,(%edi,%r13d,4),%r15
    BEXTR    $0x0,(%r9),%r10
    BEXTR    $0x7BEEEEEF,(%rdi),%r11
    BLCFILL  %esp,%r15d
    BLCFILL  (%rsi,%r12,4),%edx
    BLCFILL  (%eax),%r14d
    BLCFILL  (,%r13,4),%ebp
    BLCFILL  (%r14d),%eax
    BLCFILL  (%r11),%r9d
    BLCFILL  0xDEAD(,%r8,2),%r13d
    BLCFILL  %r15d,%r15d
    BLCFILL  %r14d,%edi
    BLCFILL  %eax,%r11d
    BLCFILL  %r9d,%r12d
    BLCFILL  0x67(%r13d),%ebx
    BLCFILL  (%ebx),%r15d
    BLCFILL  0xB(%ecx,%r11d),%r14d
    BLCFILL  -0xB6(%r13),%eax
    BLCFILL  (%r9),%esi
    BLCFILL  %r15,%rax
    BLCFILL  %r13,%r11
    BLCFILL  %r8,%rbx
    BLCFILL  (%r15d),%r15
    BLCFILL  (%r13d),%r14
    BLCFILL  %rax,%r9
    BLCFILL  0xA(%r12,%r12,1),%rdx
    BLCFILL  %r14,%r12
    BLCFILL  %rdi,%r10
    BLCFILL  (%r11d),%r13
    BLCFILL  -0x39DB(,%edx),%r8
    BLCFILL  (%r12,%rsi),%rsp
    BLCFILL  (%r13d,%r13d,2),%r8
    BLCFILL  (%rax),%rbp
    BLCFILL  (%r9),%r15
    BLCFILL  %r11,%rcx
    BLCI     %r15d,%eax
    BLCI     (%rdx),%r15d
    BLCI     %eax,%r10d
    BLCI     (%edi),%r8d
    BLCI     (%r13d),%edx
    BLCI     (%edx),%r11d
    BLCI     0x937(,%eax),%r12d
    BLCI     (%r9),%ecx
    BLCI     (%r9d),%esp
    BLCI     %edx,%esi
    BLCI     %ebp,%r14d
    BLCI     %ebx,%eax
    BLCI     (%rax),%r8d
    BLCI     (,%r14d,2),%edi
    BLCI     (%rbx),%eax
    BLCI     0x434CA331(%r9d,%r14d),%r9d
    BLCI     (%ebx),%r11
    BLCI     (%r15),%rax
    BLCI     (%r12d,%ebx,8),%r15
    BLCI     %r15,%rbp
    BLCI     -0x0(%ebx,%esi),%rsp
    BLCI     %r12,%rcx
    BLCI     (%r9),%rdi
    BLCI     (%r12d,%edi,1),%rbx
    BLCI     0x5B19(,%rdx,8),%r15
    BLCI     (,%eax,8),%r10
    BLCI     (%rbx),%r8
    BLCI     -0xF5(%eax,%edx,2),%r9
    BLCI     (%r13),%r14
    BLCI     %rbp,%rax
    BLCI     (%eax),%r13
    BLCI     (%r12),%rdx
    BLCIC    (%r14d,%eax,8),%r15d
    BLCIC    %r15d,%eax
    BLCIC    (%r9),%r8d
    BLCIC    (%r9,%rbx,2),%r9d
    BLCIC    (%ebx),%esi
    BLCIC    -0x2(,%eax),%ebp
    BLCIC    (%rax),%ebx
    BLCIC    (%r11),%edi
    BLCIC    %eax,%r11d
    BLCIC    (%r14),%r12d
    BLCIC    %r11d,%eax
    BLCIC    0x141AD0A7(,%r11),%r15d
    BLCIC    (%rax,%r9,4),%r13d
    BLCIC    (%rbx),%r15d
    BLCIC    (%r15d,%r15d),%r10d
    BLCIC    (%r9d),%edx
    BLCIC    0x59D3CBB3(,%r13d,1),%rcx
    BLCIC    %r14,%rax
    BLCIC    (%r12d),%r15
    BLCIC    %rax,%r14
    BLCIC    %r15,%rbp
    BLCIC    (%rbx),%rsp
    BLCIC    %rbx,%rdx
    BLCIC    %r8,%rdi
    BLCIC    (%r9),%rsi
    BLCIC    0xDBDB(,%rax,8),%rdi
    BLCIC    %r10,%rbx
    BLCIC    (%ebx),%r11
    BLCIC    %r13,%r9
    BLCIC    (%r8),%rax
    BLCIC    0xDEAD(%r10,%r10,1),%r12
    BLCIC    (%edx,%eax),%rcx
    BLCMSK   (%ecx),%r15d
    BLCMSK   %ebp,%eax
    BLCMSK   (%ebx),%edi
    BLCMSK   %eax,%edx
    BLCMSK   (,%r10,8),%r13d
    BLCMSK   (%r9),%r9d
    BLCMSK   (%r10),%r12d
    BLCMSK   %ecx,%ebx
    BLCMSK   (%edx),%eax
    BLCMSK   %esi,%r11d
    BLCMSK   (,%r14,4),%r15d
    BLCMSK   %r15d,%eax
    BLCMSK   0xF35F(%r14d),%r14d
    BLCMSK   (%r8d,%esi,1),%r8d
    BLCMSK   (%r12,%rdx),%esp
    BLCMSK   (%r8d),%r10d
    BLCMSK   0x0(,%r13d),%r12
    BLCMSK   %r15,%rbx
    BLCMSK   %rax,%r15
    BLCMSK   0x3(,%r9d,1),%r8
    BLCMSK   -0xCAFE(%r9,%r15,2),%rbp
    BLCMSK   (%r13),%rsp
    BLCMSK   (%rdx),%rax
    BLCMSK   (%r12),%r13
    BLCMSK   -0x7(,%rdx,8),%rdx
    BLCMSK   (%r11),%r14
    BLCMSK   %r14,%r9
    BLCMSK   (%rcx),%r11
    BLCMSK   (%r14d),%rax
    BLCMSK   (,%rax,8),%rdi
    BLCMSK   (%r15d),%r13
    BLCMSK   (%ebx,%esi),%r14
    BLCS     (%rax),%r15d
    BLCS     0x1(,%r8d,1),%r8d
    BLCS     %r10d,%ecx
    BLCS     %r15d,%r10d
    BLCS     %r11d,%eax
    BLCS     -0x7E972365(%ecx),%edi
    BLCS     (%esi),%r14d
    BLCS     -0x3(%r10),%r11d
    BLCS     (%rdi),%esp
    BLCS     (%r15d),%ebx
    BLCS     (%r9,%rsi,4),%r13d
    BLCS     0x0(%r9,%rbx,1),%r9d
    BLCS     (%eax,%ecx),%r15d
    BLCS     %ebx,%esi
    BLCS     %esi,%eax
    BLCS     %edi,%r12d
    BLCS     %rdi,%rax
    BLCS     (%rax),%r12
    BLCS     %r15,%r15
    BLCS     %r10,%rcx
    BLCS     (%eax),%r13
    BLCS     %rax,%r8
    BLCS     -0x1(%edx),%rdi
    BLCS     %rbx,%r11
    BLCS     (,%eax,2),%rsp
    BLCS     (%r9,%r13),%r10
    BLCS     0x1DCF(,%r8d,1),%r14
    BLCS     (,%r15d,4),%r15
    BLCS     (%r9),%rbp
    BLCS     (%r13d,%eax),%rdx
    BLCS     %r12,%rsp
    BLCS     (%rdi),%rbx
    BLSFILL  (%esi),%edx
    BLSFILL  (%r9),%eax
    BLSFILL  (%ebx),%r15d
    BLSFILL  %eax,%r11d
    BLSFILL  (%r12),%r8d
    BLSFILL  -0x5582(,%r9d),%r15d
    BLSFILL  %esp,%eax
    BLSFILL  (,%r12d,2),%ebp
    BLSFILL  (%r8d),%ebx
    BLSFILL  (%eax),%esp
    BLSFILL  0x4F03(,%r11),%r12d
    BLSFILL  0xF(,%r10d),%eax
    BLSFILL  (%r15d),%edi
    BLSFILL  0x228F(,%rsi,1),%ecx
    BLSFILL  (%ecx),%esi
    BLSFILL  %r8d,%r13d
    BLSFILL  -0xC(,%eax,4),%r15
    BLSFILL  %rax,%r12
    BLSFILL  %rdx,%rax
    BLSFILL  (%r9),%rbp
    BLSFILL  (%edi),%rbx
    BLSFILL  %r15,%r9
    BLSFILL  %rbx,%rsp
    BLSFILL  (%r15),%rax
    BLSFILL  0x56B9(%edi,%edi),%r10
    BLSFILL  -0x2BD1(%r12d,%esi,4),%rcx
    BLSFILL  (%r11),%rsp
    BLSFILL  %r13,%r8
    BLSFILL  (%ebx,%eax,2),%rax
    BLSFILL  (%ebx),%rax
    BLSFILL  (%rbx,%rdx),%r11
    BLSFILL  0x2FDC(%r13),%rsi
    BLSIC    %r11d,%r15d
    BLSIC    -0x799F(,%rsi),%ebp
    BLSIC    %r15d,%eax
    BLSIC    -0x0(%rax,%r10,1),%ecx
    BLSIC    %eax,%r10d
    BLSIC    (%r13d),%r9d
    BLSIC    (%r9),%ebx
    BLSIC    (%ebx),%esp
    BLSIC    (%r12d),%r11d
    BLSIC    0xBCFE(,%rdi,1),%edx
    BLSIC    (%r14d),%edi
    BLSIC    0x78EC(,%r13d),%r15d
    BLSIC    (%r11d),%esi
    BLSIC    (%r10),%r14d
    BLSIC    (%r9d),%r15d
    BLSIC    %r10d,%r15d
    BLSIC    %r15,%rax
    BLSIC    0x67(,%rax),%r9
    BLSIC    (%r8d,%r12d),%rdx
    BLSIC    (%r15d),%r15
    BLSIC    %r9,%rcx
    BLSIC    %r10,%rdi
    BLSIC    0x3FFFFFFF(,%r8),%rbx
    BLSIC    %rdx,%r15
    BLSIC    (%rax),%rsi
    BLSIC    0x0(%r15d),%rax
    BLSIC    (%rbx),%r15
    BLSIC    %rax,%r8
    BLSIC    (%ebx),%rax
    BLSIC    %rcx,%r14
    BLSIC    (%r15d,%eax,1),%rsi
    BLSIC    %r13,%r12
    T1MSKC   -0x3(%rsi),%r15d
    T1MSKC   %r15d,%r12d
    T1MSKC   (%r12),%r9d
    T1MSKC   %esi,%eax
    T1MSKC   -0x2(%r10d),%esp
    T1MSKC   (,%eax,2),%r13d
    T1MSKC   %eax,%esi
    T1MSKC   (%r12d),%eax
    T1MSKC   0xF59C(,%rbx),%r10d
    T1MSKC   (,%eax,4),%r11d
    T1MSKC   (%ebx),%r8d
    T1MSKC   %edi,%ebx
    T1MSKC   (%edx),%r14d
    T1MSKC   (%r11d),%r15d
    T1MSKC   (%esi),%ecx
    T1MSKC   (%r9,%r13),%edi
    T1MSKC   0x3FFFFFFF(%r14),%rsp
    T1MSKC   %rax,%rax
    T1MSKC   (%r8),%rbx
    T1MSKC   (%r12d,%edi),%rdi
    T1MSKC   %r11,%rcx
    T1MSKC   (%r13),%r14
    T1MSKC   0xDEAD(,%eax,8),%rdx
    T1MSKC   %r15,%r15
    T1MSKC   (%r15),%rbp
    T1MSKC   %rsp,%r9
    T1MSKC   (%rdx),%rsi
    T1MSKC   %r10,%r10
    T1MSKC   (%r9d),%r13
    T1MSKC   %rbx,%rax
    T1MSKC   (%r9),%rax
    T1MSKC   (%r8d),%r10
    TZMSK    %ebx,%r10d
    TZMSK    (%r9),%eax
    TZMSK    (%rdx),%r15d
    TZMSK    %ebp,%r12d
    TZMSK    %r10d,%r13d
    TZMSK    %r15d,%r15d
    TZMSK    -0xCAFE(%r11,%r9,1),%ebx
    TZMSK    0x1(%esi,%r13d),%edx
    TZMSK    (%r11d),%r14d
    TZMSK    (%ecx,%r12d,4),%ecx
    TZMSK    (%eax),%r9d
    TZMSK    -0x6(%rax),%r8d
    TZMSK    %edi,%esi
    TZMSK    %eax,%r15d
    TZMSK    -0xF(%rcx,%rax,1),%ebp
    TZMSK    (%r15d),%r11d
    TZMSK    0xDEAD(,%ebx,8),%rdx
    TZMSK    -0x8(,%edx),%r15
    TZMSK    %rsp,%rax
    TZMSK    (%r9d),%r8
    TZMSK    %rax,%r12
    TZMSK    %r15,%rbp
    TZMSK    (%r9,%r9,8),%r12
    TZMSK    (%edi,%ebx,4),%r13
    TZMSK    %rdi,%rdi
    TZMSK    (%ebx),%rax
    TZMSK    (%rsi),%rsp
    TZMSK    -0xCAFE(%r8),%rcx
    TZMSK    0x3C98(%r10d,%eax),%r14
    TZMSK    (%r11d),%r15
    TZMSK    %rsi,%rsi
    TZMSK    -0xDEAD(,%r8),%r9
