.*: Assembler messages:
.*:11: Error: operand 3 must be constant `ext \$3,\$2,%lo\(bar\),16'
.*:12: Error: operand 4 must be constant `ext \$3,\$2,16,%lo\(bar\)'
.*:13: Error: operand 3 must be constant `ins \$3,\$2,%lo\(bar\),16'
.*:14: Error: operand 4 must be constant `ins \$3,\$2,16,%lo\(bar\)'
.*:15: Error: operand 3 must be constant `ins \$2,\$0,%lo\(bar\),16'
.*:16: Error: operand 4 must be constant `ins \$2,\$0,16,%lo\(bar\)'
.*:18: Error: operand 1 must be constant `sync %lo\(bar\)'
.*:20: Error: operand 2 must be constant `ll \$3,%lo\(bar\)\(\$2\)'
.*:21: Error: operand 2 must be constant `lwl \$3,%lo\(bar\)\(\$2\)'
.*:22: Error: operand 2 must be constant `lwr \$3,%lo\(bar\)\(\$2\)'
.*:23: Error: operand 2 must be constant `sc \$3,%lo\(bar\)\(\$2\)'
.*:24: Error: operand 2 must be constant `swl \$3,%lo\(bar\)\(\$2\)'
.*:25: Error: operand 2 must be constant `swr \$3,%lo\(bar\)\(\$2\)'
.*:27: Error: operand 2 must be constant `cache 3,%lo\(bar\)\(\$2\)'
.*:28: Error: operand 2 must be constant `pref 3,%lo\(bar\)\(\$2\)'
.*:30: Error: operand 3 must be constant `mfc0 \$3,\$2,%lo\(bar\)'
.*:31: Error: operand 3 must be constant `mtc0 \$3,\$2,%lo\(bar\)'
