        .text
        F         ADD       FX.0,D0Re0,D0Re0
        F         ADDLT     FX.0,D0Re0,D0.7
        F         ADDVS     FX.0,D0Re0,RD
        F         ADDHI     FX.0,D0.7,A1LbP
        F         ADD       FX.0,D0.7,D1.7
        F         ADDLE     FX.0,D0.7,A0FrP
        F         ADDEQ     FX.1,D0Re0,D0.7
        F         ADD       FX.1,D0Re0,RD
        F         ADDLE     FX.1,D0.7,D0Re0
        F         ADDMI     FX.1,D0.7,D1Re0
        F         ADD       FX.1,D0.7,A0FrP
        F         ADDLE     FX.2,D0Re0,A1LbP
        F         ADDEQ     FX.2,D0Re0,D1.7
        F         ADD       FX.2,D0.7,D0Re0
        F         ADDPL     FX.2,D0.7,D0.7
        F         ADDEQ     FX.2,D0.7,RD
        F         ADD       FX.3,D0Re0,A1LbP
        F         ADDLE     FX.3,D0Re0,D1Re0
        F         ADDEQ     FX.3,D0Re0,A0FrP
        F         ADD       FX.3,D0.7,D0.7
        F         ADDLE     FX.3,D0.7,D1.7
        F         ADDEQ     FX.4,D0Re0,D0Re0
        F         ADD       FX.4,D0Re0,D1Re0
        F         ADDLE     FX.4,D0Re0,RD
        F         ADDEQ     FX.4,D0.7,A1LbP
        F         ADD       FX.4,D0.7,D1.7
        F         ADDLE     FX.4,D0.7,A0FrP
        F         ADDEQ     FX.5,D0Re0,D0.7
        F         ADD       FX.5,D0Re0,RD
        F         ADDLE     FX.5,D0.7,D0Re0
        F         ADDHI     FX.5,D0.7,D1Re0
        F         ADD       FX.5,D0.7,A0FrP
        F         ADDLE     FX.7,D0Re0,A1LbP
        F         ADDEQ     FX.7,D0Re0,D1.7
        F         ADD       FX.7,D0.7,D0Re0
        F         ADDLE     FX.7,D0.7,D0.7
        F         ADDMI     FX.7,D0.7,RD
        F         ADD       FX.10,D0Re0,A1LbP
        F         ADDLE     FX.10,D0Re0,D1Re0
        F         ADDEQ     FX.10,D0Re0,A0FrP
        F         ADD       FX.10,D0.7,D0.7
        F         ADDLE     FX.10,D0.7,D1.7
        F         ADDEQ     FX.15,D0Re0,D0Re0
        F         ADD       FX.15,D0Re0,D1Re0
        F         ADDLE     FX.15,D0Re0,RD
        F         ADDEQ     FX.15,D0.7,A1LbP
        F         ADD       FX.15,D0.7,D1.7
        F         ADDLE     FX.15,D0.7,A0FrP
        F         ADDEQ     FX.0,D1Re0,D1.7
        F         ADD       FX.0,D1Re0,RD
        F         ADDLE     FX.0,D1.7,D1Re0
        F         ADDMI     FX.0,D1.7,D0Re0
        F         ADD       FX.0,D1.7,A0FrP
        F         ADDLE     FX.1,D1Re0,A1LbP
        F         ADDEQ     FX.1,D1Re0,D0.7
        F         ADD       FX.1,D1.7,D1Re0
        F         ADDPL     FX.1,D1.7,D1.7
        F         ADDMI     FX.1,D1.7,RD
        F         ADD       FX.2,D1Re0,A1LbP
        F         ADDLE     FX.2,D1Re0,D0Re0
        F         ADDEQ     FX.2,D1Re0,A0FrP
        F         ADD       FX.2,D1.7,D1.7
        F         ADDLE     FX.2,D1.7,D0.7
        F         ADDEQ     FX.3,D1Re0,D1Re0
        F         ADD       FX.3,D1Re0,D0Re0
        F         ADDLE     FX.3,D1Re0,RD
        F         ADDEQ     FX.3,D1.7,A1LbP
        F         ADD       FX.3,D1.7,D0.7
        F         ADDLE     FX.3,D1.7,A0FrP
        F         ADDEQ     FX.4,D1Re0,D1.7
        F         ADD       FX.4,D1Re0,RD
        F         ADDPL     FX.4,D1.7,D1Re0
        F         ADDEQ     FX.4,D1.7,D0Re0
        F         ADD       FX.4,D1.7,A0FrP
        F         ADDLE     FX.5,D1Re0,A1LbP
        F         ADDEQ     FX.5,D1Re0,D0.7
        F         ADD       FX.5,D1.7,D1Re0
        F         ADDPL     FX.5,D1.7,D1.7
        F         ADDHI     FX.5,D1.7,RD
        F         ADD       FX.7,D1Re0,A1LbP
        F         ADDLE     FX.7,D1Re0,D0Re0
        F         ADDEQ     FX.7,D1Re0,A0FrP
        F         ADD       FX.7,D1.7,D1.7
        F         ADDLE     FX.7,D1.7,D0.7
        F         ADDEQ     FX.10,D1Re0,D1Re0
        F         ADD       FX.10,D1Re0,D0Re0
        F         ADDLE     FX.10,D1Re0,RD
        F         ADDEQ     FX.10,D1.7,A1LbP
        F         ADD       FX.10,D1.7,D0.7
        F         ADDLE     FX.10,D1.7,A0FrP
        F         ADDEQ     FX.15,D1Re0,D1.7
        F         ADD       FX.15,D1Re0,RD
        F         ADDLE     FX.15,D1.7,D1Re0
        F         ADDHI     FX.15,D1.7,D0Re0
        F         ADD       FX.15,D1.7,A0FrP
        F         ADD       FX.0,D0.7,#0xff
        F         ADD       FX.2,D0Re0,#0x80
        F         ADD       FX.3,D0.7,#0x7f
        F         ADD       FX.4,D0.7,#0xff
        F         ADD       FX.7,D0Re0,#0x80
        F         ADD       FX.10,D0.7,#0x7f
        F         ADD       FX.15,D0.7,#0xff
        F         ADD       FX.1,D1Re0,#0x80
        F         ADD       FX.2,D1.7,#0x7f
        F         ADD       FX.3,D1.7,#0xff
        F         ADD       FX.5,D1Re0,#0x80
        F         ADD       FX.7,D1.7,#0x7f
        F         ADD       FX.10,D1.7,#0xff
        F         MOVL      D0Re0,FX.0
        F         MOVL      D0Re0,FX.4
        F         MOVD      FX.1,D0Re0
        F         MOVD      FX.4,D0Re0
        F         MOVD      FX.7,D0Re0
        F         MOVD      D0.7,FX.7
        F         MOVL      FX.0,D1Re0
        F         MOVD      D1Re0,FX.7
        F         MOVD      FX.2,D1Re0
        F         MOVD      FX.4,D1.7
        F         MOVD      D1.7,FX.2
        F         MOVD      D1.7,FX.10
        F         ADDSLE    FX.0,D0Re0,A1LbP
        F         ADDSGT    FX.0,D0Re0,D1.7
        F         ADDS      FX.0,D0.7,D0Re0
        F         ADDSPL    FX.0,D0.7,D0.7
        F         ADDSMI    FX.0,D0.7,RD
        F         ADDS      FX.1,D0Re0,A1LbP
        F         ADDSLE    FX.1,D0Re0,D1Re0
        F         ADDSHI    FX.1,D0Re0,A0FrP
        F         ADDS      FX.1,D0.7,D0.7
        F         ADDSLE    FX.1,D0.7,D1.7
        F         ADDSEQ    FX.2,D0Re0,D0Re0
        F         ADDS      FX.2,D0Re0,D1Re0
        F         ADDSLE    FX.2,D0Re0,RD
        F         ADDSEQ    FX.2,D0.7,A1LbP
        F         ADDS      FX.2,D0.7,D1.7
        F         ADDSLE    FX.2,D0.7,A0FrP
        F         ADDSEQ    FX.3,D0Re0,D0.7
        F         ADDS      FX.3,D0Re0,RD
        F         ADDSPL    FX.3,D0.7,D0Re0
        F         ADDSEQ    FX.3,D0.7,D1Re0
        F         ADDS      FX.3,D0.7,A0FrP
        F         ADDSLE    FX.4,D0Re0,A1LbP
        F         ADDSEQ    FX.4,D0Re0,D1.7
        F         ADDS      FX.4,D0.7,D0Re0
        F         ADDSPL    FX.4,D0.7,D0.7
        F         ADDSEQ    FX.4,D0.7,RD
        F         ADDS      FX.5,D0Re0,A1LbP
        F         ADDSLE    FX.5,D0Re0,D1Re0
        F         ADDSEQ    FX.5,D0Re0,A0FrP
        F         ADDS      FX.5,D0.7,D0.7
        F         ADDSLE    FX.5,D0.7,D1.7
        F         ADDSEQ    FX.7,D0Re0,D0Re0
        F         ADDS      FX.7,D0Re0,D1Re0
        F         ADDSLE    FX.7,D0Re0,RD
        F         ADDSEQ    FX.7,D0.7,A1LbP
        F         ADDS      FX.7,D0.7,D1.7
        F         ADDSLE    FX.7,D0.7,A0FrP
        F         ADDSEQ    FX.10,D0Re0,D0.7
        F         ADDS      FX.10,D0Re0,RD
        F         ADDSLE    FX.10,D0.7,D0Re0
        F         ADDSHI    FX.10,D0.7,D1Re0
        F         ADDS      FX.10,D0.7,A0FrP
        F         ADDSLE    FX.15,D0Re0,A1LbP
        F         ADDSEQ    FX.15,D0Re0,D1.7
        F         ADDS      FX.15,D0.7,D0Re0
        F         ADDSPL    FX.15,D0.7,D0.7
        F         ADDSHI    FX.15,D0.7,RD
        F         ADDS      FX.0,D1Re0,A1LbP
        F         ADDSLE    FX.0,D1Re0,D0Re0
        F         ADDSEQ    FX.0,D1Re0,A0FrP
        F         ADDS      FX.0,D1.7,D1.7
        F         ADDSLE    FX.0,D1.7,D0.7
        F         ADDSEQ    FX.1,D1Re0,D1Re0
        F         ADDS      FX.1,D1Re0,D0Re0
        F         ADDSLE    FX.1,D1Re0,RD
        F         ADDSHI    FX.1,D1.7,A1LbP
        F         ADDS      FX.1,D1.7,D0.7
        F         ADDSLE    FX.1,D1.7,A0FrP
        F         ADDSEQ    FX.2,D1Re0,D1.7
        F         ADDS      FX.2,D1Re0,RD
        F         ADDSPL    FX.2,D1.7,D1Re0
        F         ADDSEQ    FX.2,D1.7,D0Re0
        F         ADDS      FX.2,D1.7,A0FrP
        F         ADDSLE    FX.3,D1Re0,A1LbP
        F         ADDSEQ    FX.3,D1Re0,D0.7
        F         ADDS      FX.3,D1.7,D1Re0
        F         ADDSPL    FX.3,D1.7,D1.7
        F         ADDSEQ    FX.3,D1.7,RD
        F         ADDS      FX.4,D1Re0,A1LbP
        F         ADDSLE    FX.4,D1Re0,D0Re0
        F         ADDSEQ    FX.4,D1Re0,A0FrP
        F         ADDS      FX.4,D1.7,D1.7
        F         ADDSLE    FX.4,D1.7,D0.7
        F         ADDSEQ    FX.5,D1Re0,D1Re0
        F         ADDS      FX.5,D1Re0,D0Re0
        F         ADDSLE    FX.5,D1Re0,RD
        F         ADDSEQ    FX.5,D1.7,A1LbP
        F         ADDS      FX.5,D1.7,D0.7
        F         ADDSLE    FX.5,D1.7,A0FrP
        F         ADDSEQ    FX.7,D1Re0,D1.7
        F         ADDS      FX.7,D1Re0,RD
        F         ADDSLE    FX.7,D1.7,D1Re0
        F         ADDSMI    FX.7,D1.7,D0Re0
        F         ADDS      FX.7,D1.7,A0FrP
        F         ADDSLE    FX.10,D1Re0,A1LbP
        F         ADDSEQ    FX.10,D1Re0,D0.7
        F         ADDS      FX.10,D1.7,D1Re0
        F         ADDSPL    FX.10,D1.7,D1.7
        F         ADDSHI    FX.10,D1.7,RD
        F         ADDS      FX.15,D1Re0,A1LbP
        F         ADDSLE    FX.15,D1Re0,D0Re0
        F         ADDSEQ    FX.15,D1Re0,A0FrP
        F         ADDS      FX.15,D1.7,D1.7
        F         ADDSLE    FX.15,D1.7,D0.7
        F         ADDS      FX.0,D0Re0,#0x80
        F         ADDS      FX.1,D0.7,#0x7f
        F         ADDS      FX.2,D0.7,#0xff
        F         ADDS      FX.4,D0Re0,#0x80
        F         ADDS      FX.5,D0.7,#0x7f
        F         ADDS      FX.7,D0.7,#0xff
        F         ADDS      FX.15,D0Re0,#0x80
        F         ADDS      FX.0,D1.7,#0x7f
        F         ADDS      FX.1,D1.7,#0xff
        F         ADDS      FX.3,D1Re0,#0x80
        F         ADDS      FX.4,D1.7,#0x7f
        F         ADDS      FX.5,D1.7,#0xff
        F         ADDS      FX.10,D1Re0,#0x80
        F         ADDS      FX.15,D1.7,#0x7f
        F         SUBLE     FX.0,D0Re0,A1LbP
        F         SUBGT     FX.0,D0Re0,D1.7
        F         SUB       FX.0,D0.7,D0Re0
        F         SUBPL     FX.0,D0.7,D0.7
        F         SUBMI     FX.0,D0.7,RD
        F         SUB       FX.1,D0Re0,A1LbP
        F         SUBLE     FX.1,D0Re0,D1Re0
        F         SUBHI     FX.1,D0Re0,A0FrP
        F         SUB       FX.1,D0.7,D0.7
        F         SUBLE     FX.1,D0.7,D1.7
        F         SUBEQ     FX.2,D0Re0,D0Re0
        F         SUB       FX.2,D0Re0,D1Re0
        F         SUBLE     FX.2,D0Re0,RD
        F         SUBEQ     FX.2,D0.7,A1LbP
        F         SUB       FX.2,D0.7,D1.7
        F         SUBLE     FX.2,D0.7,A0FrP
        F         SUBEQ     FX.3,D0Re0,D0.7
        F         SUB       FX.3,D0Re0,RD
        F         SUBPL     FX.3,D0.7,D0Re0
        F         SUBEQ     FX.3,D0.7,D1Re0
        F         SUB       FX.3,D0.7,A0FrP
        F         SUBLE     FX.4,D0Re0,A1LbP
        F         SUBEQ     FX.4,D0Re0,D1.7
        F         SUB       FX.4,D0.7,D0Re0
        F         SUBPL     FX.4,D0.7,D0.7
        F         SUBEQ     FX.4,D0.7,RD
        F         SUB       FX.5,D0Re0,A1LbP
        F         SUBLE     FX.5,D0Re0,D1Re0
        F         SUBEQ     FX.5,D0Re0,A0FrP
        F         SUB       FX.5,D0.7,D0.7
        F         SUBLE     FX.5,D0.7,D1.7
        F         SUBEQ     FX.7,D0Re0,D0Re0
        F         SUB       FX.7,D0Re0,D1Re0
        F         SUBLE     FX.7,D0Re0,RD
        F         SUBEQ     FX.7,D0.7,A1LbP
        F         SUB       FX.7,D0.7,D1.7
        F         SUBLE     FX.7,D0.7,A0FrP
        F         SUBEQ     FX.10,D0Re0,D0.7
        F         SUB       FX.10,D0Re0,RD
        F         SUBLE     FX.10,D0.7,D0Re0
        F         SUBHI     FX.10,D0.7,D1Re0
        F         SUB       FX.10,D0.7,A0FrP
        F         SUBLE     FX.15,D0Re0,A1LbP
        F         SUBEQ     FX.15,D0Re0,D1.7
        F         SUB       FX.15,D0.7,D0Re0
        F         SUBPL     FX.15,D0.7,D0.7
        F         SUBHI     FX.15,D0.7,RD
        F         SUB       FX.0,D1Re0,A1LbP
        F         SUBLE     FX.0,D1Re0,D0Re0
        F         SUBHI     FX.0,D1Re0,A0FrP
        F         SUB       FX.0,D1.7,D1.7
        F         SUBLE     FX.0,D1.7,D0.7
        F         SUBEQ     FX.1,D1Re0,D1Re0
        F         SUB       FX.1,D1Re0,D0Re0
        F         SUBLE     FX.1,D1Re0,RD
        F         SUBHI     FX.1,D1.7,A1LbP
        F         SUB       FX.1,D1.7,D0.7
        F         SUBLE     FX.1,D1.7,A0FrP
        F         SUBEQ     FX.2,D1Re0,D1.7
        F         SUB       FX.2,D1Re0,RD
        F         SUBPL     FX.2,D1.7,D1Re0
        F         SUBEQ     FX.2,D1.7,D0Re0
        F         SUB       FX.2,D1.7,A0FrP
        F         SUBLE     FX.3,D1Re0,A1LbP
        F         SUBEQ     FX.3,D1Re0,D0.7
        F         SUB       FX.3,D1.7,D1Re0
        F         SUBPL     FX.3,D1.7,D1.7
        F         SUBEQ     FX.3,D1.7,RD
        F         SUB       FX.4,D1Re0,A1LbP
        F         SUBLE     FX.4,D1Re0,D0Re0
        F         SUBEQ     FX.4,D1Re0,A0FrP
        F         SUB       FX.4,D1.7,D1.7
        F         SUBLE     FX.4,D1.7,D0.7
        F         SUBEQ     FX.5,D1Re0,D1Re0
        F         SUB       FX.5,D1Re0,D0Re0
        F         SUBLE     FX.5,D1Re0,RD
        F         SUBEQ     FX.5,D1.7,A1LbP
        F         SUB       FX.5,D1.7,D0.7
        F         SUBLE     FX.5,D1.7,A0FrP
        F         SUBEQ     FX.7,D1Re0,D1.7
        F         SUB       FX.7,D1Re0,RD
        F         SUBLE     FX.7,D1.7,D1Re0
        F         SUBMI     FX.7,D1.7,D0Re0
        F         SUB       FX.7,D1.7,A0FrP
        F         SUBLE     FX.10,D1Re0,A1LbP
        F         SUBEQ     FX.10,D1Re0,D0.7
        F         SUB       FX.10,D1.7,D1Re0
        F         SUBPL     FX.10,D1.7,D1.7
        F         SUBHI     FX.10,D1.7,RD
        F         SUB       FX.15,D1Re0,A1LbP
        F         SUBLE     FX.15,D1Re0,D0Re0
        F         SUBEQ     FX.15,D1Re0,A0FrP
        F         SUB       FX.15,D1.7,D1.7
        F         SUBLE     FX.15,D1.7,D0.7
        F         SUB       FX.0,D0Re0,#0x80
        F         SUB       FX.1,D0.7,#0x7f
        F         SUB       FX.2,D0.7,#0xff
        F         SUB       FX.4,D0Re0,#0x80
        F         SUB       FX.5,D0.7,#0x7f
        F         SUB       FX.7,D0.7,#0xff
        F         SUB       FX.15,D0Re0,#0x80
        F         SUB       FX.0,D1.7,#0x7f
        F         SUB       FX.1,D1.7,#0xff
        F         SUB       FX.3,D1Re0,#0x80
        F         SUB       FX.4,D1.7,#0x7f
        F         SUB       FX.5,D1.7,#0xff
        F         SUB       FX.10,D1Re0,#0x80
        F         SUB       FX.15,D1.7,#0x7f
        F         SUBSLE    FX.0,D0Re0,A1LbP
        F         SUBSEQ    FX.0,D0Re0,D1.7
        F         SUBS      FX.0,D0.7,D0Re0
        F         SUBSPL    FX.0,D0.7,D0.7
        F         SUBSMI    FX.0,D0.7,RD
        F         SUBS      FX.1,D0Re0,A1LbP
        F         SUBSLE    FX.1,D0Re0,D1Re0
        F         SUBSHI    FX.1,D0Re0,A0FrP
        F         SUBS      FX.1,D0.7,D0.7
        F         SUBSLE    FX.1,D0.7,D1.7
        F         SUBSEQ    FX.2,D0Re0,D0Re0
        F         SUBS      FX.2,D0Re0,D1Re0
        F         SUBSLE    FX.2,D0Re0,RD
        F         SUBSEQ    FX.2,D0.7,A1LbP
        F         SUBS      FX.2,D0.7,D1.7
        F         SUBSLE    FX.2,D0.7,A0FrP
        F         SUBSEQ    FX.3,D0Re0,D0.7
        F         SUBS      FX.3,D0Re0,RD
        F         SUBSPL    FX.3,D0.7,D0Re0
        F         SUBSEQ    FX.3,D0.7,D1Re0
        F         SUBS      FX.3,D0.7,A0FrP
        F         SUBSLE    FX.4,D0Re0,A1LbP
        F         SUBSEQ    FX.4,D0Re0,D1.7
        F         SUBS      FX.4,D0.7,D0Re0
        F         SUBSPL    FX.4,D0.7,D0.7
        F         SUBSEQ    FX.4,D0.7,RD
        F         SUBS      FX.5,D0Re0,A1LbP
        F         SUBSLE    FX.5,D0Re0,D1Re0
        F         SUBSEQ    FX.5,D0Re0,A0FrP
        F         SUBS      FX.5,D0.7,D0.7
        F         SUBSLE    FX.5,D0.7,D1.7
        F         SUBSEQ    FX.7,D0Re0,D0Re0
        F         SUBS      FX.7,D0Re0,D1Re0
        F         SUBSLE    FX.7,D0Re0,RD
        F         SUBSEQ    FX.7,D0.7,A1LbP
        F         SUBS      FX.7,D0.7,D1.7
        F         SUBSLE    FX.7,D0.7,A0FrP
        F         SUBSEQ    FX.10,D0Re0,D0.7
        F         SUBS      FX.10,D0Re0,RD
        F         SUBSLE    FX.10,D0.7,D0Re0
        F         SUBSHI    FX.10,D0.7,D1Re0
        F         SUBS      FX.10,D0.7,A0FrP
        F         SUBSLE    FX.15,D0Re0,A1LbP
        F         SUBSEQ    FX.15,D0Re0,D1.7
        F         SUBS      FX.15,D0.7,D0Re0
        F         SUBSPL    FX.15,D0.7,D0.7
        F         SUBSHI    FX.15,D0.7,RD
        F         SUBS      FX.0,D1Re0,A1LbP
        F         SUBSLE    FX.0,D1Re0,D0Re0
        F         SUBSHI    FX.0,D1Re0,A0FrP
        F         SUBS      FX.0,D1.7,D1.7
        F         SUBSLE    FX.0,D1.7,D0.7
        F         SUBSEQ    FX.1,D1Re0,D1Re0
        F         SUBS      FX.1,D1Re0,D0Re0
        F         SUBSLE    FX.1,D1Re0,RD
        F         SUBSHI    FX.1,D1.7,A1LbP
        F         SUBS      FX.1,D1.7,D0.7
        F         SUBSLE    FX.1,D1.7,A0FrP
        F         SUBSEQ    FX.2,D1Re0,D1.7
        F         SUBS      FX.2,D1Re0,RD
        F         SUBSPL    FX.2,D1.7,D1Re0
        F         SUBSEQ    FX.2,D1.7,D0Re0
        F         SUBS      FX.2,D1.7,A0FrP
        F         SUBSLE    FX.3,D1Re0,A1LbP
        F         SUBSEQ    FX.3,D1Re0,D0.7
        F         SUBS      FX.3,D1.7,D1Re0
        F         SUBSPL    FX.3,D1.7,D1.7
        F         SUBSEQ    FX.3,D1.7,RD
        F         SUBS      FX.4,D1Re0,A1LbP
        F         SUBSLE    FX.4,D1Re0,D0Re0
        F         SUBSEQ    FX.4,D1Re0,A0FrP
        F         SUBS      FX.4,D1.7,D1.7
        F         SUBSLE    FX.4,D1.7,D0.7
        F         SUBSEQ    FX.5,D1Re0,D1Re0
        F         SUBS      FX.5,D1Re0,D0Re0
        F         SUBSLE    FX.5,D1Re0,RD
        F         SUBSEQ    FX.5,D1.7,A1LbP
        F         SUBS      FX.5,D1.7,D0.7
        F         SUBSLE    FX.5,D1.7,A0FrP
        F         SUBSEQ    FX.7,D1Re0,D1.7
        F         SUBS      FX.7,D1Re0,RD
        F         SUBSLE    FX.7,D1.7,D1Re0
        F         SUBSMI    FX.7,D1.7,D0Re0
        F         SUBS      FX.7,D1.7,A0FrP
        F         SUBSLE    FX.10,D1Re0,A1LbP
        F         SUBSEQ    FX.10,D1Re0,D0.7
        F         SUBS      FX.10,D1.7,D1Re0
        F         SUBSPL    FX.10,D1.7,D1.7
        F         SUBSHI    FX.10,D1.7,RD
        F         SUBS      FX.15,D1Re0,A1LbP
        F         SUBSLE    FX.15,D1Re0,D0Re0
        F         SUBSEQ    FX.15,D1Re0,A0FrP
        F         SUBS      FX.15,D1.7,D1.7
        F         SUBSLE    FX.15,D1.7,D0.7
        F         SUBS      FX.0,D0Re0,#0x80
        F         SUBS      FX.1,D0.7,#0x7f
        F         SUBS      FX.2,D0.7,#0xff
        F         SUBS      FX.4,D0Re0,#0x80
        F         SUBS      FX.5,D0.7,#0x7f
        F         SUBS      FX.7,D0.7,#0xff
        F         SUBS      FX.15,D0Re0,#0x80
        F         SUBS      FX.0,D1.7,#0x7f
        F         SUBS      FX.1,D1.7,#0xff
        F         SUBS      FX.3,D1Re0,#0x80
        F         SUBS      FX.4,D1.7,#0x7f
        F         SUBS      FX.5,D1.7,#0xff
        F         SUBS      FX.10,D1Re0,#0x80
        F         SUBS      FX.15,D1.7,#0x7f
        F         ANDLE     FX.0,D0Re0,A1LbP
        F         ANDMI     FX.0,D0Re0,D1Re0
        F         AND       FX.0,D0Re0,A0FrP
        F         ANDLE     FX.0,D0.7,D0Re0
        F         ANDEQ     FX.0,D0.7,D0.7
        F         AND       FX.0,D0.7,RD
        F         ANDLE     FX.0,D0.7,A0.2
        F         ANDEQ     FX.1,D0Re0,A1.3
        F         AND       FX.1,D0Re0,D1.7
        F         ANDLE     FX.1,D0Re0,A0FrP
        F         ANDHI     FX.1,D0.7,A1LbP
        F         AND       FX.1,D0.7,D1Re0
        F         ANDLE     FX.1,D0.7,RD
        F         ANDEQ     FX.2,D0Re0,D0Re0
        F         AND       FX.2,D0Re0,D0.7
        F         ANDLE     FX.2,D0Re0,D1.7
        F         ANDEQ     FX.2,D0Re0,A0.2
        F         AND       FX.2,D0.7,A1.3
        F         ANDLE     FX.2,D0.7,D1Re0
        F         ANDEQ     FX.2,D0.7,A0FrP
        F         AND       FX.3,D0Re0,A1LbP
        F         ANDPL     FX.3,D0Re0,D0.7
        F         ANDEQ     FX.3,D0Re0,RD
        F         AND       FX.3,D0.7,D0Re0
        F         ANDLE     FX.3,D0.7,A1.3
        F         ANDEQ     FX.3,D0.7,D1.7
        F         AND       FX.3,D0.7,A0.2
        F         ANDLE     FX.4,D0Re0,A1LbP
        F         ANDEQ     FX.4,D0Re0,D1Re0
        F         AND       FX.4,D0Re0,A0FrP
        F         ANDPL     FX.4,D0.7,D0Re0
        F         ANDEQ     FX.4,D0.7,D0.7
        F         AND       FX.4,D0.7,RD
        F         ANDLE     FX.4,D0.7,A0.2
        F         ANDEQ     FX.5,D0Re0,A1.3
        F         AND       FX.5,D0Re0,D1.7
        F         ANDLE     FX.5,D0Re0,A0FrP
        F         ANDEQ     FX.5,D0.7,A1LbP
        F         AND       FX.5,D0.7,D1Re0
        F         ANDLE     FX.5,D0.7,RD
        F         ANDEQ     FX.7,D0Re0,D0Re0
        F         AND       FX.7,D0Re0,D0.7
        F         ANDLE     FX.7,D0Re0,D1.7
        F         ANDGT     FX.7,D0Re0,A0.2
        F         AND       FX.7,D0.7,A1.3
        F         ANDLE     FX.7,D0.7,D1Re0
        F         ANDHI     FX.7,D0.7,A0FrP
        F         AND       FX.10,D0Re0,A1LbP
        F         ANDPL     FX.10,D0Re0,D0.7
        F         ANDHI     FX.10,D0Re0,RD
        F         AND       FX.10,D0.7,D0Re0
        F         ANDLE     FX.10,D0.7,A1.3
        F         ANDEQ     FX.10,D0.7,D1.7
        F         AND       FX.10,D0.7,A0.2
        F         ANDLE     FX.15,D0Re0,A1LbP
        F         ANDHI     FX.15,D0Re0,D1Re0
        F         AND       FX.15,D0Re0,A0FrP
        F         ANDLE     FX.15,D0.7,D0Re0
        F         ANDEQ     FX.15,D0.7,D0.7
        F         AND       FX.15,D0.7,RD
        F         ANDLE     FX.15,D0.7,A0.2
        F         ANDEQ     FX.0,D1Re0,A1.3
        F         AND       FX.0,D1Re0,D0.7
        F         ANDLE     FX.0,D1Re0,A0FrP
        F         ANDHI     FX.0,D1.7,A1LbP
        F         AND       FX.0,D1.7,D0Re0
        F         ANDLE     FX.0,D1.7,RD
        F         ANDEQ     FX.1,D1Re0,D1Re0
        F         AND       FX.1,D1Re0,D1.7
        F         ANDLE     FX.1,D1Re0,D0.7
        F         ANDGT     FX.1,D1Re0,A0.2
        F         AND       FX.1,D1.7,A1.3
        F         ANDLE     FX.1,D1.7,D0Re0
        F         ANDHI     FX.1,D1.7,A0FrP
        F         AND       FX.2,D1Re0,A1LbP
        F         ANDPL     FX.2,D1Re0,D1.7
        F         ANDEQ     FX.2,D1Re0,RD
        F         AND       FX.2,D1.7,D1Re0
        F         ANDLE     FX.2,D1.7,A1.3
        F         ANDEQ     FX.2,D1.7,D0.7
        F         AND       FX.2,D1.7,A0.2
        F         ANDLE     FX.3,D1Re0,A1LbP
        F         ANDEQ     FX.3,D1Re0,D0Re0
        F         AND       FX.3,D1Re0,A0FrP
        F         ANDPL     FX.3,D1.7,D1Re0
        F         ANDEQ     FX.3,D1.7,D1.7
        F         AND       FX.3,D1.7,RD
        F         ANDLE     FX.3,D1.7,A0.2
        F         ANDEQ     FX.4,D1Re0,A1.3
        F         AND       FX.4,D1Re0,D0.7
        F         ANDLE     FX.4,D1Re0,A0FrP
        F         ANDEQ     FX.4,D1.7,A1LbP
        F         AND       FX.4,D1.7,D0Re0
        F         ANDLE     FX.4,D1.7,RD
        F         ANDEQ     FX.5,D1Re0,D1Re0
        F         AND       FX.5,D1Re0,D1.7
        F         ANDLE     FX.5,D1Re0,D0.7
        F         ANDHI     FX.5,D1Re0,A0.2
        F         AND       FX.5,D1.7,A1.3
        F         ANDLE     FX.5,D1.7,D0Re0
        F         ANDEQ     FX.5,D1.7,A0FrP
        F         AND       FX.7,D1Re0,A1LbP
        F         ANDPL     FX.7,D1Re0,D1.7
        F         ANDGT     FX.7,D1Re0,RD
        F         AND       FX.7,D1.7,D1Re0
        F         ANDLE     FX.7,D1.7,A1.3
        F         ANDHI     FX.7,D1.7,D0.7
        F         AND       FX.7,D1.7,A0.2
        F         ANDLE     FX.10,D1Re0,A1LbP
        F         ANDHI     FX.10,D1Re0,D0Re0
        F         AND       FX.10,D1Re0,A0FrP
        F         ANDLE     FX.10,D1.7,D1Re0
        F         ANDEQ     FX.10,D1.7,D1.7
        F         AND       FX.10,D1.7,RD
        F         ANDLE     FX.10,D1.7,A0.2
        F         ANDEQ     FX.15,D1Re0,A1.3
        F         AND       FX.15,D1Re0,D0.7
        F         ANDLE     FX.15,D1Re0,A0FrP
        F         ANDEQ     FX.15,D1.7,A1LbP
        F         AND       FX.15,D1.7,D0Re0
        F         ANDLE     FX.15,D1.7,RD
        F         AND       FX.0,D0Re0,#0x80
        F         AND       FX.1,D0.7,#0x7f
        F         AND       FX.2,D0.7,#0xff
        F         AND       FX.4,D0Re0,#0x80
        F         AND       FX.5,D0.7,#0x7f
        F         AND       FX.7,D0.7,#0xff
        F         AND       FX.15,D0Re0,#0x80
        F         AND       FX.0,D1.7,#0x7f
        F         AND       FX.1,D1.7,#0xff
        F         AND       FX.3,D1Re0,#0x80
        F         AND       FX.4,D1.7,#0x7f
        F         AND       FX.5,D1.7,#0xff
        F         AND       FX.10,D1Re0,#0x80
        F         AND       FX.15,D1.7,#0x7f
        F         ANDSLE    FX.0,D0Re0,A1LbP
        F         ANDSMI    FX.0,D0Re0,D1Re0
        F         ANDS      FX.0,D0Re0,A0FrP
        F         ANDSLE    FX.0,D0.7,D0Re0
        F         ANDSEQ    FX.0,D0.7,D0.7
        F         ANDS      FX.0,D0.7,RD
        F         ANDSLE    FX.0,D0.7,A0.2
        F         ANDSEQ    FX.1,D0Re0,A1.3
        F         ANDS      FX.1,D0Re0,D1.7
        F         ANDSLE    FX.1,D0Re0,A0FrP
        F         ANDSHI    FX.1,D0.7,A1LbP
        F         ANDS      FX.1,D0.7,D1Re0
        F         ANDSLE    FX.1,D0.7,RD
        F         ANDSEQ    FX.2,D0Re0,D0Re0
        F         ANDS      FX.2,D0Re0,D0.7
        F         ANDSLE    FX.2,D0Re0,D1.7
        F         ANDSEQ    FX.2,D0Re0,A0.2
        F         ANDS      FX.2,D0.7,A1.3
        F         ANDSLE    FX.2,D0.7,D1Re0
        F         ANDSEQ    FX.2,D0.7,A0FrP
        F         ANDS      FX.3,D0Re0,A1LbP
        F         ANDSPL    FX.3,D0Re0,D0.7
        F         ANDSEQ    FX.3,D0Re0,RD
        F         ANDS      FX.3,D0.7,D0Re0
        F         ANDSLE    FX.3,D0.7,A1.3
        F         ANDSEQ    FX.3,D0.7,D1.7
        F         ANDS      FX.3,D0.7,A0.2
        F         ANDSLE    FX.4,D0Re0,A1LbP
        F         ANDSEQ    FX.4,D0Re0,D1Re0
        F         ANDS      FX.4,D0Re0,A0FrP
        F         ANDSPL    FX.4,D0.7,D0Re0
        F         ANDSEQ    FX.4,D0.7,D0.7
        F         ANDS      FX.4,D0.7,RD
        F         ANDSLE    FX.4,D0.7,A0.2
        F         ANDSEQ    FX.5,D0Re0,A1.3
        F         ANDS      FX.5,D0Re0,D1.7
        F         ANDSLE    FX.5,D0Re0,A0FrP
        F         ANDSEQ    FX.5,D0.7,A1LbP
        F         ANDS      FX.5,D0.7,D1Re0
        F         ANDSLE    FX.5,D0.7,RD
        F         ANDSEQ    FX.7,D0Re0,D0Re0
        F         ANDS      FX.7,D0Re0,D0.7
        F         ANDSLE    FX.7,D0Re0,D1.7
        F         ANDSGT    FX.7,D0Re0,A0.2
        F         ANDS      FX.7,D0.7,A1.3
        F         ANDSLE    FX.7,D0.7,D1Re0
        F         ANDSHI    FX.7,D0.7,A0FrP
        F         ANDS      FX.10,D0Re0,A1LbP
        F         ANDSPL    FX.10,D0Re0,D0.7
        F         ANDSHI    FX.10,D0Re0,RD
        F         ANDS      FX.10,D0.7,D0Re0
        F         ANDSLE    FX.10,D0.7,A1.3
        F         ANDSEQ    FX.10,D0.7,D1.7
        F         ANDS      FX.10,D0.7,A0.2
        F         ANDSLE    FX.15,D0Re0,A1LbP
        F         ANDSHI    FX.15,D0Re0,D1Re0
        F         ANDS      FX.15,D0Re0,A0FrP
        F         ANDSLE    FX.15,D0.7,D0Re0
        F         ANDSEQ    FX.15,D0.7,D0.7
        F         ANDS      FX.15,D0.7,RD
        F         ANDSLE    FX.15,D0.7,A0.2
        F         ANDSEQ    FX.0,D1Re0,A1.3
        F         ANDS      FX.0,D1Re0,D0.7
        F         ANDSLE    FX.0,D1Re0,A0FrP
        F         ANDSHI    FX.0,D1.7,A1LbP
        F         ANDS      FX.0,D1.7,D0Re0
        F         ANDSLE    FX.0,D1.7,RD
        F         ANDSEQ    FX.1,D1Re0,D1Re0
        F         ANDS      FX.1,D1Re0,D1.7
        F         ANDSLE    FX.1,D1Re0,D0.7
        F         ANDSGT    FX.1,D1Re0,A0.2
        F         ANDS      FX.1,D1.7,A1.3
        F         ANDSLE    FX.1,D1.7,D0Re0
        F         ANDSHI    FX.1,D1.7,A0FrP
        F         ANDS      FX.2,D1Re0,A1LbP
        F         ANDSPL    FX.2,D1Re0,D1.7
        F         ANDSEQ    FX.2,D1Re0,RD
        F         ANDS      FX.2,D1.7,D1Re0
        F         ANDSLE    FX.2,D1.7,A1.3
        F         ANDSEQ    FX.2,D1.7,D0.7
        F         ANDS      FX.2,D1.7,A0.2
        F         ANDSLE    FX.3,D1Re0,A1LbP
        F         ANDSEQ    FX.3,D1Re0,D0Re0
        F         ANDS      FX.3,D1Re0,A0FrP
        F         ANDSPL    FX.3,D1.7,D1Re0
        F         ANDSEQ    FX.3,D1.7,D1.7
        F         ANDS      FX.3,D1.7,RD
        F         ANDSLE    FX.3,D1.7,A0.2
        F         ANDSEQ    FX.4,D1Re0,A1.3
        F         ANDS      FX.4,D1Re0,D0.7
        F         ANDSLE    FX.4,D1Re0,A0FrP
        F         ANDSEQ    FX.4,D1.7,A1LbP
        F         ANDS      FX.4,D1.7,D0Re0
        F         ANDSLE    FX.4,D1.7,RD
        F         ANDSEQ    FX.5,D1Re0,D1Re0
        F         ANDS      FX.5,D1Re0,D1.7
        F         ANDSLE    FX.5,D1Re0,D0.7
        F         ANDSHI    FX.5,D1Re0,A0.2
        F         ANDS      FX.5,D1.7,A1.3
        F         ANDSLE    FX.5,D1.7,D0Re0
        F         ANDSEQ    FX.5,D1.7,A0FrP
        F         ANDS      FX.7,D1Re0,A1LbP
        F         ANDSPL    FX.7,D1Re0,D1.7
        F         ANDSGT    FX.7,D1Re0,RD
        F         ANDS      FX.7,D1.7,D1Re0
        F         ANDSLE    FX.7,D1.7,A1.3
        F         ANDSHI    FX.7,D1.7,D0.7
        F         ANDS      FX.7,D1.7,A0.2
        F         ANDSLE    FX.10,D1Re0,A1LbP
        F         ANDSHI    FX.10,D1Re0,D0Re0
        F         ANDS      FX.10,D1Re0,A0FrP
        F         ANDSLE    FX.10,D1.7,D1Re0
        F         ANDSEQ    FX.10,D1.7,D1.7
        F         ANDS      FX.10,D1.7,RD
        F         ANDSLE    FX.10,D1.7,A0.2
        F         ANDSEQ    FX.15,D1Re0,A1.3
        F         ANDS      FX.15,D1Re0,D0.7
        F         ANDSLE    FX.15,D1Re0,A0FrP
        F         ANDSEQ    FX.15,D1.7,A1LbP
        F         ANDS      FX.15,D1.7,D0Re0
        F         ANDSLE    FX.15,D1.7,RD
        F         ANDS      FX.0,D0Re0,#0x80
        F         ANDS      FX.1,D0.7,#0x7f
        F         ANDS      FX.2,D0.7,#0xff
        F         ANDS      FX.4,D0Re0,#0x80
        F         ANDS      FX.5,D0.7,#0x7f
        F         ANDS      FX.7,D0.7,#0xff
        F         ANDS      FX.15,D0Re0,#0x80
        F         ANDS      FX.0,D1.7,#0x7f
        F         ANDS      FX.1,D1.7,#0xff
        F         ANDS      FX.3,D1Re0,#0x80
        F         ANDS      FX.4,D1.7,#0x7f
        F         ANDS      FX.5,D1.7,#0xff
        F         ANDS      FX.10,D1Re0,#0x80
        F         ANDS      FX.15,D1.7,#0x7f
        F         ORLE      FX.0,D0Re0,A1LbP
        F         ORMI      FX.0,D0Re0,D1Re0
        F         OR        FX.0,D0Re0,A0FrP
        F         ORLE      FX.0,D0.7,D0Re0
        F         OREQ      FX.0,D0.7,D0.7
        F         OR        FX.0,D0.7,RD
        F         ORLE      FX.0,D0.7,A0.2
        F         OREQ      FX.1,D0Re0,A1.3
        F         OR        FX.1,D0Re0,D1.7
        F         ORLE      FX.1,D0Re0,A0FrP
        F         ORHI      FX.1,D0.7,A1LbP
        F         OR        FX.1,D0.7,D1Re0
        F         ORLE      FX.1,D0.7,RD
        F         OREQ      FX.2,D0Re0,D0Re0
        F         OR        FX.2,D0Re0,D0.7
        F         ORLE      FX.2,D0Re0,D1.7
        F         OREQ      FX.2,D0Re0,A0.2
        F         OR        FX.2,D0.7,A1.3
        F         ORLE      FX.2,D0.7,D1Re0
        F         OREQ      FX.2,D0.7,A0FrP
        F         OR        FX.3,D0Re0,A1LbP
        F         ORPL      FX.3,D0Re0,D0.7
        F         OREQ      FX.3,D0Re0,RD
        F         OR        FX.3,D0.7,D0Re0
        F         ORLE      FX.3,D0.7,A1.3
        F         OREQ      FX.3,D0.7,D1.7
        F         OR        FX.3,D0.7,A0.2
        F         ORLE      FX.4,D0Re0,A1LbP
        F         OREQ      FX.4,D0Re0,D1Re0
        F         OR        FX.4,D0Re0,A0FrP
        F         ORPL      FX.4,D0.7,D0Re0
        F         OREQ      FX.4,D0.7,D0.7
        F         OR        FX.4,D0.7,RD
        F         ORLE      FX.4,D0.7,A0.2
        F         OREQ      FX.5,D0Re0,A1.3
        F         OR        FX.5,D0Re0,D1.7
        F         ORLE      FX.5,D0Re0,A0FrP
        F         OREQ      FX.5,D0.7,A1LbP
        F         OR        FX.5,D0.7,D1Re0
        F         ORLE      FX.5,D0.7,RD
        F         OREQ      FX.7,D0Re0,D0Re0
        F         OR        FX.7,D0Re0,D0.7
        F         ORLE      FX.7,D0Re0,D1.7
        F         ORGT      FX.7,D0Re0,A0.2
        F         OR        FX.7,D0.7,A1.3
        F         ORLE      FX.7,D0.7,D1Re0
        F         ORHI      FX.7,D0.7,A0FrP
        F         OR        FX.10,D0Re0,A1LbP
        F         ORPL      FX.10,D0Re0,D0.7
        F         ORHI      FX.10,D0Re0,RD
        F         OR        FX.10,D0.7,D0Re0
        F         ORLE      FX.10,D0.7,A1.3
        F         OREQ      FX.10,D0.7,D1.7
        F         OR        FX.10,D0.7,A0.2
        F         ORLE      FX.15,D0Re0,A1LbP
        F         ORHI      FX.15,D0Re0,D1Re0
        F         OR        FX.15,D0Re0,A0FrP
        F         ORLE      FX.15,D0.7,D0Re0
        F         OREQ      FX.15,D0.7,D0.7
        F         OR        FX.15,D0.7,RD
        F         ORLE      FX.15,D0.7,A0.2
        F         OREQ      FX.0,D1Re0,A1.3
        F         OR        FX.0,D1Re0,D0.7
        F         ORLE      FX.0,D1Re0,A0FrP
        F         ORHI      FX.0,D1.7,A1LbP
        F         OR        FX.0,D1.7,D0Re0
        F         ORLE      FX.0,D1.7,RD
        F         OREQ      FX.1,D1Re0,D1Re0
        F         OR        FX.1,D1Re0,D1.7
        F         ORLE      FX.1,D1Re0,D0.7
        F         ORGT      FX.1,D1Re0,A0.2
        F         OR        FX.1,D1.7,A1.3
        F         ORLE      FX.1,D1.7,D0Re0
        F         ORHI      FX.1,D1.7,A0FrP
        F         OR        FX.2,D1Re0,A1LbP
        F         ORPL      FX.2,D1Re0,D1.7
        F         OREQ      FX.2,D1Re0,RD
        F         OR        FX.2,D1.7,D1Re0
        F         ORLE      FX.2,D1.7,A1.3
        F         OREQ      FX.2,D1.7,D0.7
        F         OR        FX.2,D1.7,A0.2
        F         ORLE      FX.3,D1Re0,A1LbP
        F         OREQ      FX.3,D1Re0,D0Re0
        F         OR        FX.3,D1Re0,A0FrP
        F         ORPL      FX.3,D1.7,D1Re0
        F         OREQ      FX.3,D1.7,D1.7
        F         OR        FX.3,D1.7,RD
        F         ORLE      FX.3,D1.7,A0.2
        F         OREQ      FX.4,D1Re0,A1.3
        F         OR        FX.4,D1Re0,D0.7
        F         ORLE      FX.4,D1Re0,A0FrP
        F         OREQ      FX.4,D1.7,A1LbP
        F         OR        FX.4,D1.7,D0Re0
        F         ORLE      FX.4,D1.7,RD
        F         OREQ      FX.5,D1Re0,D1Re0
        F         OR        FX.5,D1Re0,D1.7
        F         ORLE      FX.5,D1Re0,D0.7
        F         ORHI      FX.5,D1Re0,A0.2
        F         OR        FX.5,D1.7,A1.3
        F         ORLE      FX.5,D1.7,D0Re0
        F         OREQ      FX.5,D1.7,A0FrP
        F         OR        FX.7,D1Re0,A1LbP
        F         ORPL      FX.7,D1Re0,D1.7
        F         ORGT      FX.7,D1Re0,RD
        F         OR        FX.7,D1.7,D1Re0
        F         ORLE      FX.7,D1.7,A1.3
        F         ORHI      FX.7,D1.7,D0.7
        F         OR        FX.7,D1.7,A0.2
        F         ORLE      FX.10,D1Re0,A1LbP
        F         ORHI      FX.10,D1Re0,D0Re0
        F         OR        FX.10,D1Re0,A0FrP
        F         ORLE      FX.10,D1.7,D1Re0
        F         OREQ      FX.10,D1.7,D1.7
        F         OR        FX.10,D1.7,RD
        F         ORLE      FX.10,D1.7,A0.2
        F         OREQ      FX.15,D1Re0,A1.3
        F         OR        FX.15,D1Re0,D0.7
        F         ORLE      FX.15,D1Re0,A0FrP
        F         OREQ      FX.15,D1.7,A1LbP
        F         OR        FX.15,D1.7,D0Re0
        F         ORLE      FX.15,D1.7,RD
        F         OR        FX.0,D0Re0,#0x80
        F         OR        FX.1,D0.7,#0x7f
        F         OR        FX.2,D0.7,#0xff
        F         OR        FX.4,D0Re0,#0x80
        F         OR        FX.5,D0.7,#0x7f
        F         OR        FX.7,D0.7,#0xff
        F         OR        FX.15,D0Re0,#0x80
        F         OR        FX.0,D1.7,#0x7f
        F         OR        FX.1,D1.7,#0xff
        F         OR        FX.3,D1Re0,#0x80
        F         OR        FX.4,D1.7,#0x7f
        F         OR        FX.5,D1.7,#0xff
        F         OR        FX.10,D1Re0,#0x80
        F         OR        FX.15,D1.7,#0x7f
        F         ORSLE     FX.0,D0Re0,A1LbP
        F         ORSMI     FX.0,D0Re0,D1Re0
        F         ORS       FX.0,D0Re0,A0FrP
        F         ORSLE     FX.0,D0.7,D0Re0
        F         ORSEQ     FX.0,D0.7,D0.7
        F         ORS       FX.0,D0.7,RD
        F         ORSLE     FX.0,D0.7,A0.2
        F         ORSEQ     FX.1,D0Re0,A1.3
        F         ORS       FX.1,D0Re0,D1.7
        F         ORSLE     FX.1,D0Re0,A0FrP
        F         ORSHI     FX.1,D0.7,A1LbP
        F         ORS       FX.1,D0.7,D1Re0
        F         ORSLE     FX.1,D0.7,RD
        F         ORSEQ     FX.2,D0Re0,D0Re0
        F         ORS       FX.2,D0Re0,D0.7
        F         ORSLE     FX.2,D0Re0,D1.7
        F         ORSEQ     FX.2,D0Re0,A0.2
        F         ORS       FX.2,D0.7,A1.3
        F         ORSLE     FX.2,D0.7,D1Re0
        F         ORSEQ     FX.2,D0.7,A0FrP
        F         ORS       FX.3,D0Re0,A1LbP
        F         ORSPL     FX.3,D0Re0,D0.7
        F         ORSEQ     FX.3,D0Re0,RD
        F         ORS       FX.3,D0.7,D0Re0
        F         ORSLE     FX.3,D0.7,A1.3
        F         ORSEQ     FX.3,D0.7,D1.7
        F         ORS       FX.3,D0.7,A0.2
        F         ORSLE     FX.4,D0Re0,A1LbP
        F         ORSEQ     FX.4,D0Re0,D1Re0
        F         ORS       FX.4,D0Re0,A0FrP
        F         ORSPL     FX.4,D0.7,D0Re0
        F         ORSEQ     FX.4,D0.7,D0.7
        F         ORS       FX.4,D0.7,RD
        F         ORSLE     FX.4,D0.7,A0.2
        F         ORSEQ     FX.5,D0Re0,A1.3
        F         ORS       FX.5,D0Re0,D1.7
        F         ORSLE     FX.5,D0Re0,A0FrP
        F         ORSEQ     FX.5,D0.7,A1LbP
        F         ORS       FX.5,D0.7,D1Re0
        F         ORSLE     FX.5,D0.7,RD
        F         ORSEQ     FX.7,D0Re0,D0Re0
        F         ORS       FX.7,D0Re0,D0.7
        F         ORSLE     FX.7,D0Re0,D1.7
        F         ORSGT     FX.7,D0Re0,A0.2
        F         ORS       FX.7,D0.7,A1.3
        F         ORSLE     FX.7,D0.7,D1Re0
        F         ORSHI     FX.7,D0.7,A0FrP
        F         ORS       FX.10,D0Re0,A1LbP
        F         ORSPL     FX.10,D0Re0,D0.7
        F         ORSHI     FX.10,D0Re0,RD
        F         ORS       FX.10,D0.7,D0Re0
        F         ORSLE     FX.10,D0.7,A1.3
        F         ORSEQ     FX.10,D0.7,D1.7
        F         ORS       FX.10,D0.7,A0.2
        F         ORSLE     FX.15,D0Re0,A1LbP
        F         ORSHI     FX.15,D0Re0,D1Re0
        F         ORS       FX.15,D0Re0,A0FrP
        F         ORSLE     FX.15,D0.7,D0Re0
        F         ORSEQ     FX.15,D0.7,D0.7
        F         ORS       FX.15,D0.7,RD
        F         ORSLE     FX.15,D0.7,A0.2
        F         ORSEQ     FX.0,D1Re0,A1.3
        F         ORS       FX.0,D1Re0,D0.7
        F         ORSLE     FX.0,D1Re0,A0FrP
        F         ORSHI     FX.0,D1.7,A1LbP
        F         ORS       FX.0,D1.7,D0Re0
        F         ORSLE     FX.0,D1.7,RD
        F         ORSEQ     FX.1,D1Re0,D1Re0
        F         ORS       FX.1,D1Re0,D1.7
        F         ORSLE     FX.1,D1Re0,D0.7
        F         ORSGT     FX.1,D1Re0,A0.2
        F         ORS       FX.1,D1.7,A1.3
        F         ORSLE     FX.1,D1.7,D0Re0
        F         ORSHI     FX.1,D1.7,A0FrP
        F         ORS       FX.2,D1Re0,A1LbP
        F         ORSPL     FX.2,D1Re0,D1.7
        F         ORSEQ     FX.2,D1Re0,RD
        F         ORS       FX.2,D1.7,D1Re0
        F         ORSLE     FX.2,D1.7,A1.3
        F         ORSEQ     FX.2,D1.7,D0.7
        F         ORS       FX.2,D1.7,A0.2
        F         ORSLE     FX.3,D1Re0,A1LbP
        F         ORSEQ     FX.3,D1Re0,D0Re0
        F         ORS       FX.3,D1Re0,A0FrP
        F         ORSPL     FX.3,D1.7,D1Re0
        F         ORSEQ     FX.3,D1.7,D1.7
        F         ORS       FX.3,D1.7,RD
        F         ORSLE     FX.3,D1.7,A0.2
        F         ORSEQ     FX.4,D1Re0,A1.3
        F         ORS       FX.4,D1Re0,D0.7
        F         ORSLE     FX.4,D1Re0,A0FrP
        F         ORSEQ     FX.4,D1.7,A1LbP
        F         ORS       FX.4,D1.7,D0Re0
        F         ORSLE     FX.4,D1.7,RD
        F         ORSEQ     FX.5,D1Re0,D1Re0
        F         ORS       FX.5,D1Re0,D1.7
        F         ORSLE     FX.5,D1Re0,D0.7
        F         ORSHI     FX.5,D1Re0,A0.2
        F         ORS       FX.5,D1.7,A1.3
        F         ORSLE     FX.5,D1.7,D0Re0
        F         ORSEQ     FX.5,D1.7,A0FrP
        F         ORS       FX.7,D1Re0,A1LbP
        F         ORSPL     FX.7,D1Re0,D1.7
        F         ORSGT     FX.7,D1Re0,RD
        F         ORS       FX.7,D1.7,D1Re0
        F         ORSLE     FX.7,D1.7,A1.3
        F         ORSHI     FX.7,D1.7,D0.7
        F         ORS       FX.7,D1.7,A0.2
        F         ORSLE     FX.10,D1Re0,A1LbP
        F         ORSHI     FX.10,D1Re0,D0Re0
        F         ORS       FX.10,D1Re0,A0FrP
        F         ORSLE     FX.10,D1.7,D1Re0
        F         ORSEQ     FX.10,D1.7,D1.7
        F         ORS       FX.10,D1.7,RD
        F         ORSLE     FX.10,D1.7,A0.2
        F         ORSEQ     FX.15,D1Re0,A1.3
        F         ORS       FX.15,D1Re0,D0.7
        F         ORSLE     FX.15,D1Re0,A0FrP
        F         ORSEQ     FX.15,D1.7,A1LbP
        F         ORS       FX.15,D1.7,D0Re0
        F         ORSLE     FX.15,D1.7,RD
        F         ORS       FX.0,D0Re0,#0x80
        F         ORS       FX.1,D0.7,#0x7f
        F         ORS       FX.2,D0.7,#0xff
        F         ORS       FX.4,D0Re0,#0x80
        F         ORS       FX.5,D0.7,#0x7f
        F         ORS       FX.7,D0.7,#0xff
        F         ORS       FX.15,D0Re0,#0x80
        F         ORS       FX.0,D1.7,#0x7f
        F         ORS       FX.1,D1.7,#0xff
        F         ORS       FX.3,D1Re0,#0x80
        F         ORS       FX.4,D1.7,#0x7f
        F         ORS       FX.5,D1.7,#0xff
        F         ORS       FX.10,D1Re0,#0x80
        F         ORS       FX.15,D1.7,#0x7f
        F         XORLE     FX.0,D0Re0,A1LbP
        F         XORMI     FX.0,D0Re0,D1Re0
        F         XOR       FX.0,D0Re0,A0FrP
        F         XORLE     FX.0,D0.7,D0Re0
        F         XOREQ     FX.0,D0.7,D0.7
        F         XOR       FX.0,D0.7,RD
        F         XORLE     FX.0,D0.7,A0.2
        F         XOREQ     FX.1,D0Re0,A1.3
        F         XOR       FX.1,D0Re0,D1.7
        F         XORLE     FX.1,D0Re0,A0FrP
        F         XORHI     FX.1,D0.7,A1LbP
        F         XOR       FX.1,D0.7,D1Re0
        F         XORLE     FX.1,D0.7,RD
        F         XOREQ     FX.2,D0Re0,D0Re0
        F         XOR       FX.2,D0Re0,D0.7
        F         XORLE     FX.2,D0Re0,D1.7
        F         XOREQ     FX.2,D0Re0,A0.2
        F         XOR       FX.2,D0.7,A1.3
        F         XORLE     FX.2,D0.7,D1Re0
        F         XOREQ     FX.2,D0.7,A0FrP
        F         XOR       FX.3,D0Re0,A1LbP
        F         XORPL     FX.3,D0Re0,D0.7
        F         XOREQ     FX.3,D0Re0,RD
        F         XOR       FX.3,D0.7,D0Re0
        F         XORLE     FX.3,D0.7,A1.3
        F         XOREQ     FX.3,D0.7,D1.7
        F         XOR       FX.3,D0.7,A0.2
        F         XORLE     FX.4,D0Re0,A1LbP
        F         XOREQ     FX.4,D0Re0,D1Re0
        F         XOR       FX.4,D0Re0,A0FrP
        F         XORPL     FX.4,D0.7,D0Re0
        F         XOREQ     FX.4,D0.7,D0.7
        F         XOR       FX.4,D0.7,RD
        F         XORLE     FX.4,D0.7,A0.2
        F         XOREQ     FX.5,D0Re0,A1.3
        F         XOR       FX.5,D0Re0,D1.7
        F         XORLE     FX.5,D0Re0,A0FrP
        F         XOREQ     FX.5,D0.7,A1LbP
        F         XOR       FX.5,D0.7,D1Re0
        F         XORLE     FX.5,D0.7,RD
        F         XOREQ     FX.7,D0Re0,D0Re0
        F         XOR       FX.7,D0Re0,D0.7
        F         XORLE     FX.7,D0Re0,D1.7
        F         XORGT     FX.7,D0Re0,A0.2
        F         XOR       FX.7,D0.7,A1.3
        F         XORLE     FX.7,D0.7,D1Re0
        F         XORHI     FX.7,D0.7,A0FrP
        F         XOR       FX.10,D0Re0,A1LbP
        F         XORPL     FX.10,D0Re0,D0.7
        F         XORHI     FX.10,D0Re0,RD
        F         XOR       FX.10,D0.7,D0Re0
        F         XORLE     FX.10,D0.7,A1.3
        F         XOREQ     FX.10,D0.7,D1.7
        F         XOR       FX.10,D0.7,A0.2
        F         XORLE     FX.15,D0Re0,A1LbP
        F         XORHI     FX.15,D0Re0,D1Re0
        F         XOR       FX.15,D0Re0,A0FrP
        F         XORLE     FX.15,D0.7,D0Re0
        F         XOREQ     FX.15,D0.7,D0.7
        F         XOR       FX.15,D0.7,RD
        F         XORLE     FX.15,D0.7,A0.2
        F         XOREQ     FX.0,D1Re0,A1.3
        F         XOR       FX.0,D1Re0,D0.7
        F         XORLE     FX.0,D1Re0,A0FrP
        F         XORHI     FX.0,D1.7,A1LbP
        F         XOR       FX.0,D1.7,D0Re0
        F         XORLE     FX.0,D1.7,RD
        F         XOREQ     FX.1,D1Re0,D1Re0
        F         XOR       FX.1,D1Re0,D1.7
        F         XORLE     FX.1,D1Re0,D0.7
        F         XORGT     FX.1,D1Re0,A0.2
        F         XOR       FX.1,D1.7,A1.3
        F         XORLE     FX.1,D1.7,D0Re0
        F         XORHI     FX.1,D1.7,A0FrP
        F         XOR       FX.2,D1Re0,A1LbP
        F         XORPL     FX.2,D1Re0,D1.7
        F         XOREQ     FX.2,D1Re0,RD
        F         XOR       FX.2,D1.7,D1Re0
        F         XORLE     FX.2,D1.7,A1.3
        F         XOREQ     FX.2,D1.7,D0.7
        F         XOR       FX.2,D1.7,A0.2
        F         XORLE     FX.3,D1Re0,A1LbP
        F         XOREQ     FX.3,D1Re0,D0Re0
        F         XOR       FX.3,D1Re0,A0FrP
        F         XORPL     FX.3,D1.7,D1Re0
        F         XOREQ     FX.3,D1.7,D1.7
        F         XOR       FX.3,D1.7,RD
        F         XORLE     FX.3,D1.7,A0.2
        F         XOREQ     FX.4,D1Re0,A1.3
        F         XOR       FX.4,D1Re0,D0.7
        F         XORLE     FX.4,D1Re0,A0FrP
        F         XOREQ     FX.4,D1.7,A1LbP
        F         XOR       FX.4,D1.7,D0Re0
        F         XORLE     FX.4,D1.7,RD
        F         XOREQ     FX.5,D1Re0,D1Re0
        F         XOR       FX.5,D1Re0,D1.7
        F         XORLE     FX.5,D1Re0,D0.7
        F         XORHI     FX.5,D1Re0,A0.2
        F         XOR       FX.5,D1.7,A1.3
        F         XORLE     FX.5,D1.7,D0Re0
        F         XOREQ     FX.5,D1.7,A0FrP
        F         XOR       FX.7,D1Re0,A1LbP
        F         XORPL     FX.7,D1Re0,D1.7
        F         XORGT     FX.7,D1Re0,RD
        F         XOR       FX.7,D1.7,D1Re0
        F         XORLE     FX.7,D1.7,A1.3
        F         XORHI     FX.7,D1.7,D0.7
        F         XOR       FX.7,D1.7,A0.2
        F         XORLE     FX.10,D1Re0,A1LbP
        F         XORHI     FX.10,D1Re0,D0Re0
        F         XOR       FX.10,D1Re0,A0FrP
        F         XORLE     FX.10,D1.7,D1Re0
        F         XOREQ     FX.10,D1.7,D1.7
        F         XOR       FX.10,D1.7,RD
        F         XORLE     FX.10,D1.7,A0.2
        F         XOREQ     FX.15,D1Re0,A1.3
        F         XOR       FX.15,D1Re0,D0.7
        F         XORLE     FX.15,D1Re0,A0FrP
        F         XOREQ     FX.15,D1.7,A1LbP
        F         XOR       FX.15,D1.7,D0Re0
        F         XORLE     FX.15,D1.7,RD
        F         XOR       FX.0,D0Re0,#0x80
        F         XOR       FX.1,D0.7,#0x7f
        F         XOR       FX.2,D0.7,#0xff
        F         XOR       FX.4,D0Re0,#0x80
        F         XOR       FX.5,D0.7,#0x7f
        F         XOR       FX.7,D0.7,#0xff
        F         XOR       FX.15,D0Re0,#0x80
        F         XOR       FX.0,D1.7,#0x7f
        F         XOR       FX.1,D1.7,#0xff
        F         XOR       FX.3,D1Re0,#0x80
        F         XOR       FX.4,D1.7,#0x7f
        F         XOR       FX.5,D1.7,#0xff
        F         XOR       FX.10,D1Re0,#0x80
        F         XOR       FX.15,D1.7,#0x7f
        F         XORSLE    FX.0,D0Re0,A1LbP
        F         XORSMI    FX.0,D0Re0,D1Re0
        F         XORS      FX.0,D0Re0,A0FrP
        F         XORSLE    FX.0,D0.7,D0Re0
        F         XORSEQ    FX.0,D0.7,D0.7
        F         XORS      FX.0,D0.7,RD
        F         XORSLE    FX.0,D0.7,A0.2
        F         XORSEQ    FX.1,D0Re0,A1.3
        F         XORS      FX.1,D0Re0,D1.7
        F         XORSLE    FX.1,D0Re0,A0FrP
        F         XORSHI    FX.1,D0.7,A1LbP
        F         XORS      FX.1,D0.7,D1Re0
        F         XORSLE    FX.1,D0.7,RD
        F         XORSEQ    FX.2,D0Re0,D0Re0
        F         XORS      FX.2,D0Re0,D0.7
        F         XORSLE    FX.2,D0Re0,D1.7
        F         XORSEQ    FX.2,D0Re0,A0.2
        F         XORS      FX.2,D0.7,A1.3
        F         XORSLE    FX.2,D0.7,D1Re0
        F         XORSEQ    FX.2,D0.7,A0FrP
        F         XORS      FX.3,D0Re0,A1LbP
        F         XORSPL    FX.3,D0Re0,D0.7
        F         XORSEQ    FX.3,D0Re0,RD
        F         XORS      FX.3,D0.7,D0Re0
        F         XORSLE    FX.3,D0.7,A1.3
        F         XORSEQ    FX.3,D0.7,D1.7
        F         XORS      FX.3,D0.7,A0.2
        F         XORSLE    FX.4,D0Re0,A1LbP
        F         XORSEQ    FX.4,D0Re0,D1Re0
        F         XORS      FX.4,D0Re0,A0FrP
        F         XORSPL    FX.4,D0.7,D0Re0
        F         XORSEQ    FX.4,D0.7,D0.7
        F         XORS      FX.4,D0.7,RD
        F         XORSLE    FX.4,D0.7,A0.2
        F         XORSEQ    FX.5,D0Re0,A1.3
        F         XORS      FX.5,D0Re0,D1.7
        F         XORSLE    FX.5,D0Re0,A0FrP
        F         XORSEQ    FX.5,D0.7,A1LbP
        F         XORS      FX.5,D0.7,D1Re0
        F         XORSLE    FX.5,D0.7,RD
        F         XORSEQ    FX.7,D0Re0,D0Re0
        F         XORS      FX.7,D0Re0,D0.7
        F         XORSLE    FX.7,D0Re0,D1.7
        F         XORSGT    FX.7,D0Re0,A0.2
        F         XORS      FX.7,D0.7,A1.3
        F         XORSLE    FX.7,D0.7,D1Re0
        F         XORSHI    FX.7,D0.7,A0FrP
        F         XORS      FX.10,D0Re0,A1LbP
        F         XORSPL    FX.10,D0Re0,D0.7
        F         XORSHI    FX.10,D0Re0,RD
        F         XORS      FX.10,D0.7,D0Re0
        F         XORSLE    FX.10,D0.7,A1.3
        F         XORSEQ    FX.10,D0.7,D1.7
        F         XORS      FX.10,D0.7,A0.2
        F         XORSLE    FX.15,D0Re0,A1LbP
        F         XORSHI    FX.15,D0Re0,D1Re0
        F         XORS      FX.15,D0Re0,A0FrP
        F         XORSLE    FX.15,D0.7,D0Re0
        F         XORSEQ    FX.15,D0.7,D0.7
        F         XORS      FX.15,D0.7,RD
        F         XORSLE    FX.15,D0.7,A0.2
        F         XORSEQ    FX.0,D1Re0,A1.3
        F         XORS      FX.0,D1Re0,D0.7
        F         XORSLE    FX.0,D1Re0,A0FrP
        F         XORSHI    FX.0,D1.7,A1LbP
        F         XORS      FX.0,D1.7,D0Re0
        F         XORSLE    FX.0,D1.7,RD
        F         XORSEQ    FX.1,D1Re0,D1Re0
        F         XORS      FX.1,D1Re0,D1.7
        F         XORSLE    FX.1,D1Re0,D0.7
        F         XORSGT    FX.1,D1Re0,A0.2
        F         XORS      FX.1,D1.7,A1.3
        F         XORSLE    FX.1,D1.7,D0Re0
        F         XORSHI    FX.1,D1.7,A0FrP
        F         XORS      FX.2,D1Re0,A1LbP
        F         XORSPL    FX.2,D1Re0,D1.7
        F         XORSEQ    FX.2,D1Re0,RD
        F         XORS      FX.2,D1.7,D1Re0
        F         XORSLE    FX.2,D1.7,A1.3
        F         XORSEQ    FX.2,D1.7,D0.7
        F         XORS      FX.2,D1.7,A0.2
        F         XORSLE    FX.3,D1Re0,A1LbP
        F         XORSEQ    FX.3,D1Re0,D0Re0
        F         XORS      FX.3,D1Re0,A0FrP
        F         XORSPL    FX.3,D1.7,D1Re0
        F         XORSEQ    FX.3,D1.7,D1.7
        F         XORS      FX.3,D1.7,RD
        F         XORSLE    FX.3,D1.7,A0.2
        F         XORSEQ    FX.4,D1Re0,A1.3
        F         XORS      FX.4,D1Re0,D0.7
        F         XORSLE    FX.4,D1Re0,A0FrP
        F         XORSEQ    FX.4,D1.7,A1LbP
        F         XORS      FX.4,D1.7,D0Re0
        F         XORSLE    FX.4,D1.7,RD
        F         XORSEQ    FX.5,D1Re0,D1Re0
        F         XORS      FX.5,D1Re0,D1.7
        F         XORSLE    FX.5,D1Re0,D0.7
        F         XORSHI    FX.5,D1Re0,A0.2
        F         XORS      FX.5,D1.7,A1.3
        F         XORSLE    FX.5,D1.7,D0Re0
        F         XORSEQ    FX.5,D1.7,A0FrP
        F         XORS      FX.7,D1Re0,A1LbP
        F         XORSPL    FX.7,D1Re0,D1.7
        F         XORSGT    FX.7,D1Re0,RD
        F         XORS      FX.7,D1.7,D1Re0
        F         XORSLE    FX.7,D1.7,A1.3
        F         XORSHI    FX.7,D1.7,D0.7
        F         XORS      FX.7,D1.7,A0.2
        F         XORSLE    FX.10,D1Re0,A1LbP
        F         XORSHI    FX.10,D1Re0,D0Re0
        F         XORS      FX.10,D1Re0,A0FrP
        F         XORSLE    FX.10,D1.7,D1Re0
        F         XORSEQ    FX.10,D1.7,D1.7
        F         XORS      FX.10,D1.7,RD
        F         XORSLE    FX.10,D1.7,A0.2
        F         XORSEQ    FX.15,D1Re0,A1.3
        F         XORS      FX.15,D1Re0,D0.7
        F         XORSLE    FX.15,D1Re0,A0FrP
        F         XORSEQ    FX.15,D1.7,A1LbP
        F         XORS      FX.15,D1.7,D0Re0
        F         XORSLE    FX.15,D1.7,RD
        F         XORS      FX.0,D0Re0,#0x80
        F         XORS      FX.1,D0.7,#0x7f
        F         XORS      FX.2,D0.7,#0xff
        F         XORS      FX.4,D0Re0,#0x80
        F         XORS      FX.5,D0.7,#0x7f
        F         XORS      FX.7,D0.7,#0xff
        F         XORS      FX.15,D0Re0,#0x80
        F         XORS      FX.0,D1.7,#0x7f
        F         XORS      FX.1,D1.7,#0xff
        F         XORS      FX.3,D1Re0,#0x80
        F         XORS      FX.4,D1.7,#0x7f
        F         XORS      FX.5,D1.7,#0xff
        F         XORS      FX.10,D1Re0,#0x80
        F         XORS      FX.15,D1.7,#0x7f
        F         ASR       FX.0,D0Re0,D0.7
        F         LSR       FX.1,D0Re0,D0Re0
        F         LSL       FX.1,D0.7,D0.7
        F         ASR       FX.2,D0Re0,D0.7
        F         LSR       FX.3,D0Re0,D0Re0
        F         LSL       FX.3,D0.7,D0.7
        F         ASR       FX.4,D0Re0,D0.7
        F         LSR       FX.5,D0Re0,D0Re0
        F         LSL       FX.5,D0.7,D0.7
        F         ASR       FX.7,D0Re0,D0.7
        F         LSR       FX.10,D0Re0,D0Re0
        F         LSL       FX.10,D0.7,D0.7
        F         ASR       FX.15,D0Re0,D0.7
        F         LSR       FX.0,D1Re0,D1Re0
        F         LSL       FX.0,D1.7,D1.7
        F         ASR       FX.1,D1Re0,D1.7
        F         LSR       FX.2,D1Re0,D1Re0
        F         LSL       FX.2,D1.7,D1.7
        F         ASR       FX.3,D1Re0,D1.7
        F         LSR       FX.4,D1Re0,D1Re0
        F         LSL       FX.4,D1.7,D1.7
        F         ASR       FX.5,D1Re0,D1.7
        F         LSR       FX.7,D1Re0,D1Re0
        F         LSL       FX.7,D1.7,D1.7
        F         ASR       FX.10,D1Re0,D1.7
        F         LSR       FX.15,D1Re0,D1Re0
        F         LSL       FX.15,D1.7,D1.7
        F         ASR       FX.0,D0Re0,#0x10
        F         LSR       FX.0,D0.7,#0x10
        F         LSL       FX.1,D0Re0,#0x10
        F         ASR       FX.1,D0.7,#0xf
        F         LSR       FX.2,D0Re0,#0xf
        F         LSL       FX.2,D0.7,#0xf
        F         ASR       FX.2,D0.7,#0x1f
        F         LSR       FX.3,D0Re0,#0x1f
        F         LSL       FX.3,D0.7,#0x1f
        F         ASR       FX.4,D0Re0,#0x10
        F         LSR       FX.4,D0.7,#0x10
        F         LSL       FX.5,D0Re0,#0x10
        F         ASR       FX.5,D0.7,#0xf
        F         LSR       FX.7,D0Re0,#0xf
        F         LSL       FX.7,D0.7,#0xf
        F         ASR       FX.7,D0.7,#0x1f
        F         LSR       FX.10,D0Re0,#0x1f
        F         LSL       FX.10,D0.7,#0x1f
        F         ASR       FX.15,D0Re0,#0x10
        F         LSR       FX.15,D0.7,#0x10
        F         LSL       FX.0,D1Re0,#0x10
        F         ASR       FX.0,D1.7,#0xf
        F         LSR       FX.1,D1Re0,#0xf
        F         LSL       FX.1,D1.7,#0xf
        F         ASR       FX.1,D1.7,#0x1f
        F         LSR       FX.2,D1Re0,#0x1f
        F         LSL       FX.2,D1.7,#0x1f
        F         ASR       FX.3,D1Re0,#0x10
        F         LSR       FX.3,D1.7,#0x10
        F         LSL       FX.4,D1Re0,#0x10
        F         ASR       FX.4,D1.7,#0xf
        F         LSR       FX.5,D1Re0,#0xf
        F         LSL       FX.5,D1.7,#0xf
        F         ASR       FX.5,D1.7,#0x1f
        F         LSR       FX.7,D1Re0,#0x1f
        F         LSL       FX.7,D1.7,#0x1f
        F         ASR       FX.10,D1Re0,#0x10
        F         LSR       FX.10,D1.7,#0x10
        F         LSL       FX.15,D1Re0,#0x10
        F         ASR       FX.15,D1.7,#0xf
        F         LSRS      FX.0,D0Re0,D0Re0
        F         LSLS      FX.0,D0.7,D0.7
        F         ASRS      FX.1,D0Re0,D0.7
        F         LSRS      FX.2,D0Re0,D0Re0
        F         LSLS      FX.2,D0.7,D0.7
        F         ASRS      FX.3,D0Re0,D0.7
        F         LSRS      FX.4,D0Re0,D0Re0
        F         LSLS      FX.4,D0.7,D0.7
        F         ASRS      FX.5,D0Re0,D0.7
        F         LSRS      FX.7,D0Re0,D0Re0
        F         LSLS      FX.7,D0.7,D0.7
        F         ASRS      FX.10,D0Re0,D0.7
        F         LSRS      FX.15,D0Re0,D0Re0
        F         LSLS      FX.15,D0.7,D0.7
        F         ASRS      FX.0,D1Re0,D1.7
        F         LSRS      FX.1,D1Re0,D1Re0
        F         LSLS      FX.1,D1.7,D1.7
        F         ASRS      FX.2,D1Re0,D1.7
        F         LSRS      FX.3,D1Re0,D1Re0
        F         LSLS      FX.3,D1.7,D1.7
        F         ASRS      FX.4,D1Re0,D1.7
        F         LSRS      FX.5,D1Re0,D1Re0
        F         LSLS      FX.5,D1.7,D1.7
        F         ASRS      FX.7,D1Re0,D1.7
        F         LSRS      FX.10,D1Re0,D1Re0
        F         LSLS      FX.10,D1.7,D1.7
        F         ASRS      FX.15,D1Re0,D1.7
        F         LSRS      FX.0,D0Re0,#0xf
        F         LSLS      FX.0,D0.7,#0xf
        F         ASRS      FX.0,D0.7,#0x1f
        F         LSRS      FX.1,D0Re0,#0x1f
        F         LSLS      FX.1,D0.7,#0x1f
        F         ASRS      FX.2,D0Re0,#0x10
        F         LSRS      FX.2,D0.7,#0x10
        F         LSLS      FX.3,D0Re0,#0x10
        F         ASRS      FX.3,D0.7,#0xf
        F         LSRS      FX.4,D0Re0,#0xf
        F         LSLS      FX.4,D0.7,#0xf
        F         ASRS      FX.4,D0.7,#0x1f
        F         LSRS      FX.5,D0Re0,#0x1f
        F         LSLS      FX.5,D0.7,#0x1f
        F         ASRS      FX.7,D0Re0,#0x10
        F         LSRS      FX.7,D0.7,#0x10
        F         LSLS      FX.10,D0Re0,#0x10
        F         ASRS      FX.10,D0.7,#0xf
        F         LSRS      FX.15,D0Re0,#0xf
        F         LSLS      FX.15,D0.7,#0xf
        F         ASRS      FX.15,D0.7,#0x1f
        F         LSRS      FX.0,D1Re0,#0x1f
        F         LSLS      FX.0,D1.7,#0x1f
        F         ASRS      FX.1,D1Re0,#0x10
        F         LSRS      FX.1,D1.7,#0x10
        F         LSLS      FX.2,D1Re0,#0x10
        F         ASRS      FX.2,D1.7,#0xf
        F         LSRS      FX.3,D1Re0,#0xf
        F         LSLS      FX.3,D1.7,#0xf
        F         ASRS      FX.3,D1.7,#0x1f
        F         LSRS      FX.4,D1Re0,#0x1f
        F         LSLS      FX.4,D1.7,#0x1f
        F         ASRS      FX.5,D1Re0,#0x10
        F         LSRS      FX.5,D1.7,#0x10
        F         LSLS      FX.7,D1Re0,#0x10
        F         ASRS      FX.7,D1.7,#0xf
        F         LSRS      FX.10,D1Re0,#0xf
        F         LSLS      FX.10,D1.7,#0xf
        F         ASRS      FX.10,D1.7,#0x1f
        F         LSRS      FX.15,D1Re0,#0x1f
        F         LSLS      FX.15,D1.7,#0x1f
        F         MOVWLE    FX.0,RD
        F         MOVW      FX.1,RD
        F         MOVW      FX.2,RD
        F         MOVW      FX.3,RD
        F         MOVDGT    FX.3,RD
        F         MOVWLE    FX.4,RD
        F         MOVWHI    FX.5,RD
        F         MOVBEQ    FX.7,RD
        F         MOVCC     FX.0,D0Re0
        F         MOVEQ     FX.0,D1Re0
        F         MOV       D0Re0,FX.0
        F         SWAPLT    D0Re0,FX.0
        F         MOVEQ     FX.1,D0Re0
        F         SWAPPL    FX.1,D1Re0
        F         MOVEQ     A1LbP,FX.0
        F         SWAPLE    A1LbP,FX.0
        F         SWAPVC    FX.2,D0Re0
        F         SWAP      FX.2,D1Re0
        F         SWAPNE    FX.3,D0Re0
        F         MOVNV     FX.3,D1Re0
        F         MOVLE     A0.3,FX.0
        F         SWAPEQ    A1.3,FX.0
        F         SWAP      FX.4,D0Re0
        F         MOVGT     FX.4,D1Re0
        F         MOVLE     FX.5,D0Re0
        F         MOVPL     FX.5,D1Re0
        F         MOVGT     FX.7,D0Re0
        F         MOVPL     FX.7,D1Re0
        F         MOVEQ     D1.7,FX.0
        F         SWAPCC    D0.7,FX.0
        F         MOVEQ     FX.10,D0Re0
        F         MOVEQ     FX.10,D1Re0
        F         SWAP      FX.15,D0Re0
        F         SWAP      FX.15,D1Re0
        F         MOV       FX.0,A1LbP
        F         SWAPEQ    FX.0,A1LbP
        F         MOVEQ     D1Re0,FX.1
        F         SWAP      D1Re0,FX.1
        F         SWAPLE    FX.1,A0FrP
        F         SWAPEQ    FX.1,A1LbP
        F         SWAPEQ    A0FrP,FX.1
        F         SWAPPL    A1LbP,FX.1
        F         MOV       FX.2,A1LbP
        F         SWAPPL    FX.2,A1LbP
        F         MOVEQ     FX.3,A1LbP
        F         MOVGT     A0.3,FX.1
        F         SWAP      A1.3,FX.1
        F         SWAP      FX.4,A0FrP
        F         MOVGT     FX.4,A1LbP
        F         SWAP      FX.5,A0FrP
        F         SWAPVC    FX.5,A1LbP
        F         SWAPEQ    FX.7,A0FrP
        F         MOV       D0.7,FX.1
        F         MOVLE     D1.7,FX.1
        F         SWAP      D1.7,FX.1
        F         MOV       FX.10,A1LbP
        F         SWAPLE    FX.10,A1LbP
        F         MOVEQ     FX.15,A1LbP
        F         SWAPNV    FX.15,A1LbP
        F         MOVEQ     D1Re0,FX.2
        F         SWAPLE    D1Re0,FX.2
        F         MOVNV     A0FrP,FX.2
        F         SWAPEQ    A1LbP,FX.2
        F         MOVVC     A0.3,FX.2
        F         SWAP      A0.3,FX.2
        F         SWAPLE    A1.3,FX.2
        F         SWAPEQ    D0.7,FX.2
        F         SWAPPL    D1.7,FX.2
        F         MOVEQ     FX.0,A1.3
        F         MOV       D0Re0,FX.3
        F         SWAPLT    D0Re0,FX.3
        F         MOVEQ     FX.1,A0.3
        F         MOVGT     FX.1,A1.3
        F         MOVCC     A0FrP,FX.3
        F         SWAPEQ    A0FrP,FX.3
        F         MOVEQ     FX.2,A0.3
        F         MOVCC     FX.2,A1.3
        F         MOVEQ     FX.3,A0.3
        F         MOVCC     FX.3,A1.3
        F         MOVEQ     A0.3,FX.3
        F         SWAPEQ    A0.3,FX.3
        F         SWAPNE    FX.4,A0.3
        F         MOVNV     FX.4,A1.3
        F         MOVGT     FX.5,A0.3
        F         MOVLE     FX.5,A1.3
        F         MOV       FX.7,A0.3
        F         SWAPEQ    FX.7,A0.3
        F         MOV       D0.7,FX.3
        F         SWAPLT    D0.7,FX.3
        F         MOVEQ     FX.10,A0.3
        F         SWAPEQ    FX.10,A1.3
        F         SWAP      FX.15,A0.3
        F         SWAPVC    FX.15,A1.3
        F         MOV       D1Re0,FX.4
        F         SWAPNV    D0Re0,FX.4
        F         MOVLE     A0FrP,FX.4
        F         SWAPEQ    A1LbP,FX.4
        F         MOV       A1.3,FX.4
        F         SWAPNV    A0.3,FX.4
        F         MOVEQ     D1.7,FX.4
        F         SWAP      D1.7,FX.4
        F         MOVVC     D1Re0,FX.5
        F         SWAPGT    D0Re0,FX.5
        F         MOVPL     A0FrP,FX.5
        F         SWAPLE    A0FrP,FX.5
        F         MOVEQ     A1.3,FX.5
        F         SWAP      A1.3,FX.5
        F         MOVLE     D1.7,FX.5
        F         MOVEQ     FX.0,D0.7
        F         MOVGT     FX.0,D1.7
        F         MOVLE     D0Re0,FX.7
        F         SWAP      D0Re0,FX.7
        F         SWAPLE    D1Re0,FX.7
        F         MOVEQ     FX.1,D1.7
        F         MOV       A0FrP,FX.7
        F         SWAPLT    A0FrP,FX.7
        F         MOVEQ     FX.2,D0.7
        F         MOV       FX.2,D1.7
        F         MOVCC     FX.3,D0.7
        F         MOVEQ     FX.3,D1.7
        F         MOVEQ     A1.3,FX.7
        F         SWAP      A1.3,FX.7
        F         SWAP      FX.4,D0.7
        F         SWAPLE    FX.4,D1.7
        F         MOVEQ     FX.5,D1.7
        F         SWAPEQ    FX.7,D0.7
        F         SWAPLE    FX.7,D1.7
        F         MOVNV     D1.7,FX.7
        F         MOVPL     FX.10,D0.7
        F         SWAPEQ    FX.10,D1.7
        F         MOV       FX.15,D1.7
        F         MOVCC     D0Re0,FX.10
        F         MOVVC     D1Re0,FX.10
        F         SWAP      D1Re0,FX.10
        F         MOVNV     A0FrP,FX.10
        F         SWAPCC    A1LbP,FX.10
        F         MOVCC     A1.3,FX.10
        F         SWAPEQ    A1.3,FX.10
        F         MOV       D1.7,FX.10
        F         SWAPGT    D0.7,FX.10
        F         MOVCC     D0Re0,FX.15
        F         MOVVC     D1Re0,FX.15
        F         SWAP      D1Re0,FX.15
        F         MOVNV     A0FrP,FX.15
        F         SWAPCC    A1LbP,FX.15
        F         MOVCC     A1.3,FX.15
        F         SWAPEQ    A1.3,FX.15
        F         MOV       D1.7,FX.15
        F         SWAPGT    D0.7,FX.15
        F         SETBLE    [D0Re0],FX.0
        F         SETDLE    [D0Re0],FX.0
        F         SETBEQ    [A0FrP],FX.0
        F         SETDEQ    [A0FrP],FX.0
        F         SETBPL    [A0.3],FX.0
        F         SETDPL    [A0.3],FX.0
        F         SETBLE    [D1.7],FX.0
        F         SETDLE    [D1.7],FX.0
        F         SETBLE    [D1Re0],FX.1
        F         SETBEQ    [A1LbP],FX.1
        F         SETDEQ    [A0FrP],FX.1
        F         SETDEQ    [A1.3],FX.1
        F         SETBEQ    [D1.7],FX.1
        F         SETDLE    [D1.7],FX.1
        F         SETBLE    [D1Re0],FX.2
        F         SETDLE    [D1Re0],FX.2
        F         SETDEQ    [A1LbP],FX.2
        F         SETBEQ    [A1.3],FX.2
        F         SETDLE    [A1.3],FX.2
        F         SETBLE    [D0.7],FX.2
        F         SETDLE    [D0.7],FX.2
        F         SETBLE    [D0Re0],FX.3
        F         SETDCC    [D1Re0],FX.3
        F         SETBPL    [A0FrP],FX.3
        F         SETBEQ    [A0.3],FX.3
        F         SETBEQ    [D0.7],FX.3
        F         SETDEQ    [D0.7],FX.3
        F         SETBLE    [D0Re0],FX.4
        F         SETDLE    [D0Re0],FX.4
        F         SETBEQ    [A0FrP],FX.4
        F         SETDEQ    [A0FrP],FX.4
        F         SETBPL    [A0.3],FX.4
        F         SETDPL    [A0.3],FX.4
        F         SETBLE    [D1.7],FX.4
        F         SETDLE    [D1.7],FX.4
        F         SETBLT    [D1Re0],FX.5
        F         SETDLE    [D1Re0],FX.5
        F         SETDEQ    [A1LbP],FX.5
        F         SETWCS    [A1.3],FX.5
        F         SETDEQ    [A0.3],FX.5
        F         SETBVC    [D1.7],FX.5
        F         SETDVC    [D1.7],FX.5
        F         SETBVC    [D1Re0],FX.7
        F         SETDVC    [D1Re0],FX.7
        F         SETBEQ    [A0FrP],FX.7
        F         SETDGE    [A0FrP],FX.7
        F         SETDLS    [A1.3],FX.7
        F         SETBEQ    [D1.7],FX.7
        F         SETDEQ    [D1.7],FX.7
        F         SETBPL    [D0Re0],FX.10
        F         SETDEQ    [D1Re0],FX.10
        F         SETDEQ    [A1LbP],FX.10
        F         SETBLE    [A0.3],FX.10
        F         SETBPL    [D0.7],FX.10
        F         SETDEQ    [D1.7],FX.10
        F         SETBLE    [D1Re0],FX.15
        F         SETDEQ    [D1Re0],FX.15
        F         SETDEQ    [A1LbP],FX.15
        F         SETBPL    [A0.3],FX.15
        F         SETBLE    [D0.7],FX.15
        F         SETDCC    [D1.7],FX.15
        F         SETB      [D1Re0++D1Re0],FX.0
        F         SETB      [A1LbP+A1LbP],FX.0
        F         SETB      [D0.7++D0Re0],FX.0
        F         SETB      [D1.7++D1.7],FX.0
        F         SETB      [D0Re0+D0.7],FX.1
        F         SETB      [A1LbP++A1LbP],FX.1
        F         SETB      [D1.7++D1Re0],FX.1
        F         SETB      [D0Re0+D0Re0],FX.2
        F         SETB      [D0Re0++D0.7],FX.2
        F         SETB      [A0FrP++A0FrP],FX.2
        F         SETB      [D0.7+D0.7],FX.2
        F         SETB      [D0Re0++D0Re0],FX.3
        F         SETB      [D1Re0++D1.7],FX.3
        F         SETB      [D0.7+D0Re0],FX.3
        F         SETB      [D0.7++D0.7],FX.3
        F         SETB      [D1Re0++D1Re0],FX.4
        F         SETB      [A1LbP+A1LbP],FX.4
        F         SETB      [D0.7++D0Re0],FX.4
        F         SETB      [D1.7++D1.7],FX.4
        F         SETB      [D0Re0+D0.7],FX.5
        F         SETB      [A1LbP++A1LbP],FX.5
        F         SETB      [D1.7++D1Re0],FX.5
        F         SETB      [D0Re0+D0Re0],FX.7
        F         SETB      [D0Re0++D0.7],FX.7
        F         SETB      [A0FrP++A0FrP],FX.7
        F         SETB      [D0.7+D0.7],FX.7
        F         SETB      [D0Re0++D0Re0],FX.10
        F         SETB      [D1Re0++D1.7],FX.10
        F         SETB      [D0.7+D0Re0],FX.10
        F         SETB      [D0.7++D0.7],FX.10
        F         SETB      [D1Re0++D1Re0],FX.15
        F         SETB      [A1LbP+A1LbP],FX.15
        F         SETB      [D0.7++D0Re0],FX.15
        F         SETB      [D1.7++D1.7],FX.15
        F         SETW      [D0Re0+D0.7],FX.0
        F         SETW      [A1LbP++A1LbP],FX.0
        F         SETW      [D1.7++D1Re0],FX.0
        F         SETW      [D0Re0+D0Re0],FX.1
        F         SETW      [D0Re0++D0.7],FX.1
        F         SETW      [A0FrP++A0FrP],FX.1
        F         SETW      [D0.7+D0.7],FX.1
        F         SETW      [D0Re0++D0Re0],FX.2
        F         SETW      [D1Re0++D1.7],FX.2
        F         SETW      [D0.7+D0Re0],FX.2
        F         SETW      [D0.7++D0.7],FX.2
        F         SETW      [D1Re0++D1Re0],FX.3
        F         SETW      [A1LbP+A1LbP],FX.3
        F         SETW      [D0.7++D0Re0],FX.3
        F         SETW      [D1.7++D1.7],FX.3
        F         SETW      [D0Re0+D0.7],FX.4
        F         SETW      [A1LbP++A1LbP],FX.4
        F         SETW      [D1.7++D1Re0],FX.4
        F         SETW      [D0Re0+D0Re0],FX.5
        F         SETW      [D0Re0++D0.7],FX.5
        F         SETW      [A0FrP++A0FrP],FX.5
        F         SETW      [D0.7+D0.7],FX.5
        F         SETW      [D0Re0++D0Re0],FX.7
        F         SETW      [D1Re0++D1.7],FX.7
        F         SETW      [D0.7+D0Re0],FX.7
        F         SETW      [D0.7++D0.7],FX.7
        F         SETW      [D1Re0++D1Re0],FX.10
        F         SETW      [A1LbP+A1LbP],FX.10
        F         SETW      [D0.7++D0Re0],FX.10
        F         SETW      [D1.7++D1.7],FX.10
        F         SETW      [D0Re0+D0.7],FX.15
        F         SETW      [A1LbP++A1LbP],FX.15
        F         SETW      [D1.7++D1Re0],FX.15
        F         SETB      [D0Re0+#0x1f],FX.0
        F         SETB      [D0Re0++#-0x20],FX.0
        F         SETB      [--D1Re0],FX.0
        F         SETB      [A1LbP+#-0x20],FX.0
        F         SETB      [--A1LbP],FX.0
        F         SETB      [D1.7++#0x1f],FX.0
        F         SETB      [D0.7+#-0x1],FX.0
        F         SETB      [D0Re0++#0x1f],FX.1
        F         SETB      [D1Re0++#-0x20],FX.1
        F         SETB      [A1LbP+#0x1f],FX.1
        F         SETB      [A1LbP++#-0x20],FX.1
        F         SETB      [--A0FrP],FX.1
        F         SETB      [D0.7+#-0x20],FX.1
        F         SETB      [--D0.7],FX.1
        F         SETB      [D1Re0++#0x1f],FX.2
        F         SETB      [D0Re0+#-0x1],FX.2
        F         SETB      [A1LbP++#0x1f],FX.2
        F         SETB      [A0FrP++#-0x20],FX.2
        F         SETB      [D0.7+#0x1f],FX.2
        F         SETB      [D0.7++#-0x20],FX.2
        F         SETB      [--D1.7],FX.2
        F         SETB      [D0Re0+#-0x20],FX.3
        F         SETB      [--D0Re0],FX.3
        F         SETB      [A0FrP++#0x1f],FX.3
        F         SETB      [A1LbP+#-0x1],FX.3
        F         SETB      [D0.7++#0x1f],FX.3
        F         SETB      [D1.7++#-0x20],FX.3
        F         SETB      [D0Re0+#0x1f],FX.4
        F         SETB      [D0Re0++#-0x20],FX.4
        F         SETB      [--D1Re0],FX.4
        F         SETB      [A1LbP+#-0x20],FX.4
        F         SETB      [--A1LbP],FX.4
        F         SETB      [D1.7++#0x1f],FX.4
        F         SETB      [D0.7+#-0x1],FX.4
        F         SETB      [D0Re0++#0x1f],FX.5
        F         SETB      [D1Re0++#-0x20],FX.5
        F         SETB      [A1LbP+#0x1f],FX.5
        F         SETB      [A1LbP++#-0x20],FX.5
        F         SETB      [--A0FrP],FX.5
        F         SETB      [D0.7+#-0x20],FX.5
        F         SETB      [--D0.7],FX.5
        F         SETB      [D1Re0++#0x1f],FX.7
        F         SETB      [D0Re0+#-0x1],FX.7
        F         SETB      [A1LbP++#0x1f],FX.7
        F         SETB      [A0FrP++#-0x20],FX.7
        F         SETB      [D0.7+#0x1f],FX.7
        F         SETB      [D0.7++#-0x20],FX.7
        F         SETB      [--D1.7],FX.7
        F         SETB      [D0Re0+#-0x20],FX.10
        F         SETB      [--D0Re0],FX.10
        F         SETB      [A0FrP++#0x1f],FX.10
        F         SETB      [A1LbP+#-0x1],FX.10
        F         SETB      [D0.7++#0x1f],FX.10
        F         SETB      [D1.7++#-0x20],FX.10
        F         SETB      [D0Re0+#0x1f],FX.15
        F         SETB      [D0Re0++#-0x20],FX.15
        F         SETB      [--D1Re0],FX.15
        F         SETB      [A1LbP+#-0x20],FX.15
        F         SETB      [--A1LbP],FX.15
        F         SETB      [D1.7++#0x1f],FX.15
        F         SETB      [D0.7+#-0x1],FX.15
        F         SETW      [D0Re0++#0x3e],FX.0
        F         SETW      [D1Re0++#-0x40],FX.0
        F         SETW      [A1LbP+#0x3e],FX.0
        F         SETW      [A1LbP++#-0x40],FX.0
        F         SETW      [--A0FrP],FX.0
        F         SETW      [D0.7+#-0x40],FX.0
        F         SETW      [--D0.7],FX.0
        F         SETW      [D1Re0++#0x3e],FX.1
        F         SETW      [D0Re0+#-0x2],FX.1
        F         SETW      [A1LbP++#0x3e],FX.1
        F         SETW      [A0FrP++#-0x40],FX.1
        F         SETW      [D0.7+#0x3e],FX.1
        F         SETW      [D0.7++#-0x40],FX.1
        F         SETW      [--D1.7],FX.1
        F         SETW      [D0Re0+#-0x40],FX.2
        F         SETW      [--D0Re0],FX.2
        F         SETW      [A0FrP++#0x3e],FX.2
        F         SETW      [A1LbP+#-0x2],FX.2
        F         SETW      [D0.7++#0x3e],FX.2
        F         SETW      [D1.7++#-0x40],FX.2
        F         SETW      [D0Re0+#0x3e],FX.3
        F         SETW      [D0Re0++#-0x40],FX.3
        F         SETW      [--D1Re0],FX.3
        F         SETW      [A1LbP+#-0x40],FX.3
        F         SETW      [--A1LbP],FX.3
        F         SETW      [D1.7++#0x3e],FX.3
        F         SETW      [D0.7+#-0x2],FX.3
        F         SETW      [D0Re0++#0x3e],FX.4
        F         SETW      [D1Re0++#-0x40],FX.4
        F         SETW      [A1LbP+#0x3e],FX.4
        F         SETW      [A1LbP++#-0x40],FX.4
        F         SETW      [--A0FrP],FX.4
        F         SETW      [D0.7+#-0x40],FX.4
        F         SETW      [--D0.7],FX.4
        F         SETW      [D1Re0++#0x3e],FX.5
        F         SETW      [D0Re0+#-0x2],FX.5
        F         SETW      [A1LbP++#0x3e],FX.5
        F         SETW      [A0FrP++#-0x40],FX.5
        F         SETW      [D0.7+#0x3e],FX.5
        F         SETW      [D0.7++#-0x40],FX.5
        F         SETW      [--D1.7],FX.5
        F         SETW      [D0Re0+#-0x40],FX.7
        F         SETW      [--D0Re0],FX.7
        F         SETW      [A0FrP++#0x3e],FX.7
        F         SETW      [A1LbP+#-0x2],FX.7
        F         SETW      [D0.7++#0x3e],FX.7
        F         SETW      [D1.7++#-0x40],FX.7
        F         SETW      [D0Re0+#0x3e],FX.10
        F         SETW      [D0Re0++#-0x40],FX.10
        F         SETW      [--D1Re0],FX.10
        F         SETW      [A1LbP+#-0x40],FX.10
        F         SETW      [--A1LbP],FX.10
        F         SETW      [D1.7++#0x3e],FX.10
        F         SETW      [D0.7+#-0x2],FX.10
        F         SETW      [D0Re0++#0x3e],FX.15
        F         SETW      [D1Re0++#-0x40],FX.15
        F         SETW      [A1LbP+#0x3e],FX.15
        F         SETW      [A1LbP++#-0x40],FX.15
        F         SETW      [--A0FrP],FX.15
        F         SETW      [D0.7+#-0x40],FX.15
        F         SETW      [--D0.7],FX.15
        F         SETD      [D1Re0++D1Re0],FX.0
        F         SETD      [A1LbP+A1LbP],FX.0
        F         SETD      [D0.7++D0Re0],FX.0
        F         SETD      [D1.7++D1.7],FX.0
        F         SETD      [D0Re0+D0.7],FX.1
        F         SETD      [A1LbP++A1LbP],FX.1
        F         SETD      [D1.7++D1Re0],FX.1
        F         SETD      [D0Re0+D0Re0],FX.2
        F         SETD      [D0Re0++D0.7],FX.2
        F         SETD      [A0FrP++A0FrP],FX.2
        F         SETD      [D0.7+D0.7],FX.2
        F         SETD      [D0Re0++D0Re0],FX.3
        F         SETD      [D1Re0++D1.7],FX.3
        F         SETD      [D0.7+D0Re0],FX.3
        F         SETD      [D0.7++D0.7],FX.3
        F         SETD      [D1Re0++D1Re0],FX.4
        F         SETD      [A1LbP+A1LbP],FX.4
        F         SETD      [D0.7++D0Re0],FX.4
        F         SETD      [D1.7++D1.7],FX.4
        F         SETD      [D0Re0+D0.7],FX.5
        F         SETD      [A1LbP++A1LbP],FX.5
        F         SETD      [D1.7++D1Re0],FX.5
        F         SETD      [D0Re0+D0Re0],FX.7
        F         SETD      [D0Re0++D0.7],FX.7
        F         SETD      [A0FrP++A0FrP],FX.7
        F         SETD      [D0.7+D0.7],FX.7
        F         SETD      [D0Re0++D0Re0],FX.10
        F         SETD      [D1Re0++D1.7],FX.10
        F         SETD      [D0.7+D0Re0],FX.10
        F         SETD      [D0.7++D0.7],FX.10
        F         SETD      [D1Re0++D1Re0],FX.15
        F         SETD      [A1LbP+A1LbP],FX.15
        F         SETD      [D0.7++D0Re0],FX.15
        F         SETD      [D1.7++D1.7],FX.15
        F         SETL      [D0Re0+D0.7],FX.0,FX.1
        F         SETL      [A1LbP++A1LbP],FX.0,FX.1
        F         SETL      [D1.7++D1Re0],FX.0,FX.1
        F         SETL      [D0Re0+D0Re0],FX.2,FX.3
        F         SETL      [D0Re0++D0.7],FX.2,FX.3
        F         SETL      [A0FrP++A0FrP],FX.2,FX.3
        F         SETL      [D0.7+D0.7],FX.2,FX.3
        F         SETL      [D0Re0++D0Re0],FX.4,FX.5
        F         SETL      [D1Re0++D1.7],FX.4,FX.5
        F         SETL      [D0.7+D0Re0],FX.4,FX.5
        F         SETL      [D0.7++D0.7],FX.4,FX.5
        F         SETD      [D1Re0++#0x7c],FX.0
        F         SETD      [D0Re0+#-0x4],FX.0
        F         SETD      [A1LbP++#0x7c],FX.0
        F         SETD      [A0FrP++#-0x80],FX.0
        F         SETD      [D0.7+#0x7c],FX.0
        F         SETD      [D0.7++#-0x80],FX.0
        F         SETD      [--D1.7],FX.0
        F         SETD      [D0Re0+#-0x80],FX.1
        F         SETD      [--D0Re0],FX.1
        F         SETD      [A0FrP++#0x7c],FX.1
        F         SETD      [A1LbP+#-0x4],FX.1
        F         SETD      [D0.7++#0x7c],FX.1
        F         SETD      [D1.7++#-0x80],FX.1
        F         SETD      [D0Re0+#0x7c],FX.2
        F         SETD      [D0Re0++#-0x80],FX.2
        F         SETD      [--D1Re0],FX.2
        F         SETD      [A1LbP+#-0x80],FX.2
        F         SETD      [--A1LbP],FX.2
        F         SETD      [D1.7++#0x7c],FX.2
        F         SETD      [D0.7+#-0x4],FX.2
        F         SETD      [D0Re0++#0x7c],FX.3
        F         SETD      [D1Re0++#-0x80],FX.3
        F         SETD      [A1LbP+#0x7c],FX.3
        F         SETD      [A1LbP++#-0x80],FX.3
        F         SETD      [--A0FrP],FX.3
        F         SETD      [D0.7+#-0x80],FX.3
        F         SETD      [--D0.7],FX.3
        F         SETD      [D1Re0++#0x7c],FX.4
        F         SETD      [D0Re0+#-0x4],FX.4
        F         SETD      [A1LbP++#0x7c],FX.4
        F         SETD      [A0FrP++#-0x80],FX.4
        F         SETD      [D0.7+#0x7c],FX.4
        F         SETD      [D0.7++#-0x80],FX.4
        F         SETD      [--D1.7],FX.4
        F         SETD      [D0Re0+#-0x80],FX.5
        F         SETD      [--D0Re0],FX.5
        F         SETD      [A0FrP++#0x7c],FX.5
        F         SETD      [A1LbP+#-0x4],FX.5
        F         SETD      [D0.7++#0x7c],FX.5
        F         SETD      [D1.7++#-0x80],FX.5
        F         SETD      [D0Re0+#0x7c],FX.7
        F         SETD      [D0Re0++#-0x80],FX.7
        F         SETD      [--D1Re0],FX.7
        F         SETD      [A1LbP+#-0x80],FX.7
        F         SETD      [--A1LbP],FX.7
        F         SETD      [D1.7++#0x7c],FX.7
        F         SETD      [D0.7+#-0x4],FX.7
        F         SETD      [D0Re0++#0x7c],FX.10
        F         SETD      [D1Re0++#-0x80],FX.10
        F         SETD      [A1LbP+#0x7c],FX.10
        F         SETD      [A1LbP++#-0x80],FX.10
        F         SETD      [--A0FrP],FX.10
        F         SETD      [D0.7+#-0x80],FX.10
        F         SETD      [--D0.7],FX.10
        F         SETD      [D1Re0++#0x7c],FX.15
        F         SETD      [D0Re0+#-0x4],FX.15
        F         SETD      [A1LbP++#0x7c],FX.15
        F         SETD      [A0FrP++#-0x80],FX.15
        F         SETD      [D0.7+#0x7c],FX.15
        F         SETD      [D0.7++#-0x80],FX.15
        F         SETD      [--D1.7],FX.15
        F         SETL      [D0Re0+#-0x100],FX.0,FX.1
        F         SETL      [--D0Re0],FX.0,FX.1
        F         SETL      [A0FrP++#0xf8],FX.0,FX.1
        F         SETL      [A1LbP+#-0x8],FX.0,FX.1
        F         SETL      [D0.7++#0xf8],FX.0,FX.1
        F         SETL      [D1.7++#-0x100],FX.0,FX.1
        F         SETL      [D0Re0+#0xf8],FX.2,FX.3
        F         SETL      [D0Re0++#-0x100],FX.2,FX.3
        F         SETL      [--D1Re0],FX.2,FX.3
        F         SETL      [A1LbP+#-0x100],FX.2,FX.3
        F         SETL      [--A1LbP],FX.2,FX.3
        F         SETL      [D1.7++#0xf8],FX.2,FX.3
        F         SETL      [D0.7+#-0x8],FX.2,FX.3
        F         SETL      [D0Re0++#0xf8],FX.4,FX.5
        F         SETL      [D1Re0++#-0x100],FX.4,FX.5
        F         SETL      [A1LbP+#0xf8],FX.4,FX.5
        F         SETL      [A1LbP++#-0x100],FX.4,FX.5
        F         SETL      [--A0FrP],FX.4,FX.5
        F         SETL      [D0.7+#-0x100],FX.4,FX.5
        F         SETL      [--D0.7],FX.4,FX.5
        F         GETB      FX.0,[D1Re0++D1Re0]
        F         GETB      FX.0,[A1LbP+A1LbP]
        F         GETB      FX.0,[D0.7++D0Re0]
        F         GETB      FX.0,[D1.7++D1.7]
        F         GETB      FX.1,[D0Re0+D0.7]
        F         GETB      FX.1,[A1LbP++A1LbP]
        F         GETB      FX.1,[D1.7++D1Re0]
        F         GETB      FX.2,[D0Re0+D0Re0]
        F         GETB      FX.2,[D0Re0++D0.7]
        F         GETB      FX.2,[A0FrP++A0FrP]
        F         GETB      FX.2,[D0.7+D0.7]
        F         GETB      FX.3,[D0Re0++D0Re0]
        F         GETB      FX.3,[D1Re0++D1.7]
        F         GETB      FX.3,[D0.7+D0Re0]
        F         GETB      FX.3,[D0.7++D0.7]
        F         GETB      FX.4,[D1Re0++D1Re0]
        F         GETB      FX.4,[A1LbP+A1LbP]
        F         GETB      FX.4,[D0.7++D0Re0]
        F         GETB      FX.4,[D1.7++D1.7]
        F         GETB      FX.5,[D0Re0+D0.7]
        F         GETB      FX.5,[A1LbP++A1LbP]
        F         GETB      FX.5,[D1.7++D1Re0]
        F         GETB      FX.7,[D0Re0+D0Re0]
        F         GETB      FX.7,[D0Re0++D0.7]
        F         GETB      FX.7,[A0FrP++A0FrP]
        F         GETB      FX.7,[D0.7+D0.7]
        F         GETB      FX.10,[D0Re0++D0Re0]
        F         GETB      FX.10,[D1Re0++D1.7]
        F         GETB      FX.10,[D0.7+D0Re0]
        F         GETB      FX.10,[D0.7++D0.7]
        F         GETB      FX.15,[D1Re0++D1Re0]
        F         GETB      FX.15,[A1LbP+A1LbP]
        F         GETB      FX.15,[D0.7++D0Re0]
        F         GETB      FX.15,[D1.7++D1.7]
        F         GETW      FX.0,[D0Re0+D0.7]
        F         GETW      FX.0,[A1LbP++A1LbP]
        F         GETW      FX.0,[D1.7++D1Re0]
        F         GETW      FX.1,[D0Re0+D0Re0]
        F         GETW      FX.1,[D0Re0++D0.7]
        F         GETW      FX.1,[A0FrP++A0FrP]
        F         GETW      FX.1,[D0.7+D0.7]
        F         GETW      FX.2,[D0Re0++D0Re0]
        F         GETW      FX.2,[D1Re0++D1.7]
        F         GETW      FX.2,[D0.7+D0Re0]
        F         GETW      FX.2,[D0.7++D0.7]
        F         GETW      FX.3,[D1Re0++D1Re0]
        F         GETW      FX.3,[A1LbP+A1LbP]
        F         GETW      FX.3,[D0.7++D0Re0]
        F         GETW      FX.3,[D1.7++D1.7]
        F         GETW      FX.4,[D0Re0+D0.7]
        F         GETW      FX.4,[A1LbP++A1LbP]
        F         GETW      FX.4,[D1.7++D1Re0]
        F         GETW      FX.5,[D0Re0+D0Re0]
        F         GETW      FX.5,[D0Re0++D0.7]
        F         GETW      FX.5,[A0FrP++A0FrP]
        F         GETW      FX.5,[D0.7+D0.7]
        F         GETW      FX.7,[D0Re0++D0Re0]
        F         GETW      FX.7,[D1Re0++D1.7]
        F         GETW      FX.7,[D0.7+D0Re0]
        F         GETW      FX.7,[D0.7++D0.7]
        F         GETW      FX.10,[D1Re0++D1Re0]
        F         GETW      FX.10,[A1LbP+A1LbP]
        F         GETW      FX.10,[D0.7++D0Re0]
        F         GETW      FX.10,[D1.7++D1.7]
        F         GETW      FX.15,[D0Re0+D0.7]
        F         GETW      FX.15,[A1LbP++A1LbP]
        F         GETW      FX.15,[D1.7++D1Re0]
        F         GETB      FX.0,[D0Re0+#0x1f]
        F         GETB      FX.0,[D0Re0++#-0x20]
        F         GETB      FX.0,[--D1Re0]
        F         GETB      FX.0,[A1LbP+#-0x20]
        F         GETB      FX.0,[--A1LbP]
        F         GETB      FX.0,[D1.7++#0x1f]
        F         GETB      FX.0,[D0.7+#-0x1]
        F         GETB      FX.1,[D0Re0++#0x1f]
        F         GETB      FX.1,[D1Re0++#-0x20]
        F         GETB      FX.1,[A1LbP+#0x1f]
        F         GETB      FX.1,[A1LbP++#-0x20]
        F         GETB      FX.1,[--A0FrP]
        F         GETB      FX.1,[D0.7+#-0x20]
        F         GETB      FX.1,[--D0.7]
        F         GETB      FX.2,[D1Re0++#0x1f]
        F         GETB      FX.2,[D0Re0+#-0x1]
        F         GETB      FX.2,[A1LbP++#0x1f]
        F         GETB      FX.2,[A0FrP++#-0x20]
        F         GETB      FX.2,[D0.7+#0x1f]
        F         GETB      FX.2,[D0.7++#-0x20]
        F         GETB      FX.2,[--D1.7]
        F         GETB      FX.3,[D0Re0+#-0x20]
        F         GETB      FX.3,[--D0Re0]
        F         GETB      FX.3,[A0FrP++#0x1f]
        F         GETB      FX.3,[A1LbP+#-0x1]
        F         GETB      FX.3,[D0.7++#0x1f]
        F         GETB      FX.3,[D1.7++#-0x20]
        F         GETB      FX.4,[D0Re0+#0x1f]
        F         GETB      FX.4,[D0Re0++#-0x20]
        F         GETB      FX.4,[--D1Re0]
        F         GETB      FX.4,[A1LbP+#-0x20]
        F         GETB      FX.4,[--A1LbP]
        F         GETB      FX.4,[D1.7++#0x1f]
        F         GETB      FX.4,[D0.7+#-0x1]
        F         GETB      FX.5,[D0Re0++#0x1f]
        F         GETB      FX.5,[D1Re0++#-0x20]
        F         GETB      FX.5,[A1LbP+#0x1f]
        F         GETB      FX.5,[A1LbP++#-0x20]
        F         GETB      FX.5,[--A0FrP]
        F         GETB      FX.5,[D0.7+#-0x20]
        F         GETB      FX.5,[--D0.7]
        F         GETB      FX.7,[D1Re0++#0x1f]
        F         GETB      FX.7,[D0Re0+#-0x1]
        F         GETB      FX.7,[A1LbP++#0x1f]
        F         GETB      FX.7,[A0FrP++#-0x20]
        F         GETB      FX.7,[D0.7+#0x1f]
        F         GETB      FX.7,[D0.7++#-0x20]
        F         GETB      FX.7,[--D1.7]
        F         GETB      FX.10,[D0Re0+#-0x20]
        F         GETB      FX.10,[--D0Re0]
        F         GETB      FX.10,[A0FrP++#0x1f]
        F         GETB      FX.10,[A1LbP+#-0x1]
        F         GETB      FX.10,[D0.7++#0x1f]
        F         GETB      FX.10,[D1.7++#-0x20]
        F         GETB      FX.15,[D0Re0+#0x1f]
        F         GETB      FX.15,[D0Re0++#-0x20]
        F         GETB      FX.15,[--D1Re0]
        F         GETB      FX.15,[A1LbP+#-0x20]
        F         GETB      FX.15,[--A1LbP]
        F         GETB      FX.15,[D1.7++#0x1f]
        F         GETB      FX.15,[D0.7+#-0x1]
        F         GETW      FX.0,[D0Re0++#0x3e]
        F         GETW      FX.0,[D1Re0++#-0x40]
        F         GETW      FX.0,[A1LbP+#0x3e]
        F         GETW      FX.0,[A1LbP++#-0x40]
        F         GETW      FX.0,[--A0FrP]
        F         GETW      FX.0,[D0.7+#-0x40]
        F         GETW      FX.0,[--D0.7]
        F         GETW      FX.1,[D1Re0++#0x3e]
        F         GETW      FX.1,[D0Re0+#-0x2]
        F         GETW      FX.1,[A1LbP++#0x3e]
        F         GETW      FX.1,[A0FrP++#-0x40]
        F         GETW      FX.1,[D0.7+#0x3e]
        F         GETW      FX.1,[D0.7++#-0x40]
        F         GETW      FX.1,[--D1.7]
        F         GETW      FX.2,[D0Re0+#-0x40]
        F         GETW      FX.2,[--D0Re0]
        F         GETW      FX.2,[A0FrP++#0x3e]
        F         GETW      FX.2,[A1LbP+#-0x2]
        F         GETW      FX.2,[D0.7++#0x3e]
        F         GETW      FX.2,[D1.7++#-0x40]
        F         GETW      FX.3,[D0Re0+#0x3e]
        F         GETW      FX.3,[D0Re0++#-0x40]
        F         GETW      FX.3,[--D1Re0]
        F         GETW      FX.3,[A1LbP+#-0x40]
        F         GETW      FX.3,[--A1LbP]
        F         GETW      FX.3,[D1.7++#0x3e]
        F         GETW      FX.3,[D0.7+#-0x2]
        F         GETW      FX.4,[D0Re0++#0x3e]
        F         GETW      FX.4,[D1Re0++#-0x40]
        F         GETW      FX.4,[A1LbP+#0x3e]
        F         GETW      FX.4,[A1LbP++#-0x40]
        F         GETW      FX.4,[--A0FrP]
        F         GETW      FX.4,[D0.7+#-0x40]
        F         GETW      FX.4,[--D0.7]
        F         GETW      FX.5,[D1Re0++#0x3e]
        F         GETW      FX.5,[D0Re0+#-0x2]
        F         GETW      FX.5,[A1LbP++#0x3e]
        F         GETW      FX.5,[A0FrP++#-0x40]
        F         GETW      FX.5,[D0.7+#0x3e]
        F         GETW      FX.5,[D0.7++#-0x40]
        F         GETW      FX.5,[--D1.7]
        F         GETW      FX.7,[D0Re0+#-0x40]
        F         GETW      FX.7,[--D0Re0]
        F         GETW      FX.7,[A0FrP++#0x3e]
        F         GETW      FX.7,[A1LbP+#-0x2]
        F         GETW      FX.7,[D0.7++#0x3e]
        F         GETW      FX.7,[D1.7++#-0x40]
        F         GETW      FX.10,[D0Re0+#0x3e]
        F         GETW      FX.10,[D0Re0++#-0x40]
        F         GETW      FX.10,[--D1Re0]
        F         GETW      FX.10,[A1LbP+#-0x40]
        F         GETW      FX.10,[--A1LbP]
        F         GETW      FX.10,[D1.7++#0x3e]
        F         GETW      FX.10,[D0.7+#-0x2]
        F         GETW      FX.15,[D0Re0++#0x3e]
        F         GETW      FX.15,[D1Re0++#-0x40]
        F         GETW      FX.15,[A1LbP+#0x3e]
        F         GETW      FX.15,[A1LbP++#-0x40]
        F         GETW      FX.15,[--A0FrP]
        F         GETW      FX.15,[D0.7+#-0x40]
        F         GETW      FX.15,[--D0.7]
        F         GETD      FX.0,[D1Re0++D1Re0]
        F         GETD      FX.0,[A1LbP+A1LbP]
        F         GETD      FX.0,[D0.7++D0Re0]
        F         GETD      FX.0,[D1.7++D1.7]
        F         GETD      FX.1,[D0Re0+D0.7]
        F         GETD      FX.1,[A1LbP++A1LbP]
        F         GETD      FX.1,[D1.7++D1Re0]
        F         GETD      FX.2,[D0Re0+D0Re0]
        F         GETD      FX.2,[D0Re0++D0.7]
        F         GETD      FX.2,[A0FrP++A0FrP]
        F         GETD      FX.2,[D0.7+D0.7]
        F         GETD      FX.3,[D0Re0++D0Re0]
        F         GETD      FX.3,[D1Re0++D1.7]
        F         GETD      FX.3,[D0.7+D0Re0]
        F         GETD      FX.3,[D0.7++D0.7]
        F         GETD      FX.4,[D1Re0++D1Re0]
        F         GETD      FX.4,[A1LbP+A1LbP]
        F         GETD      FX.4,[D0.7++D0Re0]
        F         GETD      FX.4,[D1.7++D1.7]
        F         GETD      FX.5,[D0Re0+D0.7]
        F         GETD      FX.5,[A1LbP++A1LbP]
        F         GETD      FX.5,[D1.7++D1Re0]
        F         GETD      FX.7,[D0Re0+D0Re0]
        F         GETD      FX.7,[D0Re0++D0.7]
        F         GETD      FX.7,[A0FrP++A0FrP]
        F         GETD      FX.7,[D0.7+D0.7]
        F         GETD      FX.10,[D0Re0++D0Re0]
        F         GETD      FX.10,[D1Re0++D1.7]
        F         GETD      FX.10,[D0.7+D0Re0]
        F         GETD      FX.10,[D0.7++D0.7]
        F         GETD      FX.15,[D1Re0++D1Re0]
        F         GETD      FX.15,[A1LbP+A1LbP]
        F         GETD      FX.15,[D0.7++D0Re0]
        F         GETD      FX.15,[D1.7++D1.7]
        F         GETL      FX.0,FX.1,[D0Re0+D0.7]
        F         GETL      FX.0,FX.1,[A1LbP++A1LbP]
        F         GETL      FX.0,FX.1,[D1.7++D1Re0]
        F         GETL      FX.2,FX.3,[D0Re0+D0Re0]
        F         GETL      FX.2,FX.3,[D0Re0++D0.7]
        F         GETL      FX.2,FX.3,[A0FrP++A0FrP]
        F         GETL      FX.2,FX.3,[D0.7+D0.7]
        F         GETL      FX.4,FX.5,[D0Re0++D0Re0]
        F         GETL      FX.4,FX.5,[D1Re0++D1.7]
        F         GETL      FX.4,FX.5,[D0.7+D0Re0]
        F         GETL      FX.4,FX.5,[D0.7++D0.7]
        F         GETD      FX.0,[D1Re0++#0x7c]
        F         GETD      FX.0,[D0Re0+#-0x4]
        F         GETD      FX.0,[A1LbP++#0x7c]
        F         GETD      FX.0,[A0FrP++#-0x80]
        F         GETD      FX.0,[D0.7+#0x7c]
        F         GETD      FX.0,[D0.7++#-0x80]
        F         GETD      FX.0,[--D1.7]
        F         GETD      FX.1,[D0Re0+#-0x80]
        F         GETD      FX.1,[--D0Re0]
        F         GETD      FX.1,[A0FrP++#0x7c]
        F         GETD      FX.1,[A1LbP+#-0x4]
        F         GETD      FX.1,[D0.7++#0x7c]
        F         GETD      FX.1,[D1.7++#-0x80]
        F         GETD      FX.2,[D0Re0+#0x7c]
        F         GETD      FX.2,[D0Re0++#-0x80]
        F         GETD      FX.2,[--D1Re0]
        F         GETD      FX.2,[A1LbP+#-0x80]
        F         GETD      FX.2,[--A1LbP]
        F         GETD      FX.2,[D1.7++#0x7c]
        F         GETD      FX.2,[D0.7+#-0x4]
        F         GETD      FX.3,[D0Re0++#0x7c]
        F         GETD      FX.3,[D1Re0++#-0x80]
        F         GETD      FX.3,[A1LbP+#0x7c]
        F         GETD      FX.3,[A1LbP++#-0x80]
        F         GETD      FX.3,[--A0FrP]
        F         GETD      FX.3,[D0.7+#-0x80]
        F         GETD      FX.3,[--D0.7]
        F         GETD      FX.4,[D1Re0++#0x7c]
        F         GETD      FX.4,[D0Re0+#-0x4]
        F         GETD      FX.4,[A1LbP++#0x7c]
        F         GETD      FX.4,[A0FrP++#-0x80]
        F         GETD      FX.4,[D0.7+#0x7c]
        F         GETD      FX.4,[D0.7++#-0x80]
        F         GETD      FX.4,[--D1.7]
        F         GETD      FX.5,[D0Re0+#-0x80]
        F         GETD      FX.5,[--D0Re0]
        F         GETD      FX.5,[A0FrP++#0x7c]
        F         GETD      FX.5,[A1LbP+#-0x4]
        F         GETD      FX.5,[D0.7++#0x7c]
        F         GETD      FX.5,[D1.7++#-0x80]
        F         GETD      FX.7,[D0Re0+#0x7c]
        F         GETD      FX.7,[D0Re0++#-0x80]
        F         GETD      FX.7,[--D1Re0]
        F         GETD      FX.7,[A1LbP+#-0x80]
        F         GETD      FX.7,[--A1LbP]
        F         GETD      FX.7,[D1.7++#0x7c]
        F         GETD      FX.7,[D0.7+#-0x4]
        F         GETD      FX.10,[D0Re0++#0x7c]
        F         GETD      FX.10,[D1Re0++#-0x80]
        F         GETD      FX.10,[A1LbP+#0x7c]
        F         GETD      FX.10,[A1LbP++#-0x80]
        F         GETD      FX.10,[--A0FrP]
        F         GETD      FX.10,[D0.7+#-0x80]
        F         GETD      FX.10,[--D0.7]
        F         GETD      FX.15,[D1Re0++#0x7c]
        F         GETD      FX.15,[D0Re0+#-0x4]
        F         GETD      FX.15,[A1LbP++#0x7c]
        F         GETD      FX.15,[A0FrP++#-0x80]
        F         GETD      FX.15,[D0.7+#0x7c]
        F         GETD      FX.15,[D0.7++#-0x80]
        F         GETD      FX.15,[--D1.7]
        F         GETL      FX.0,FX.1,[D0Re0+#-0x100]
        F         GETL      FX.0,FX.1,[--D0Re0]
        F         GETL      FX.0,FX.1,[A0FrP++#0xf8]
        F         GETL      FX.0,FX.1,[A1LbP+#-0x8]
        F         GETL      FX.0,FX.1,[D0.7++#0xf8]
        F         GETL      FX.0,FX.1,[D1.7++#-0x100]
        F         GETL      FX.2,FX.3,[D0Re0+#0xf8]
        F         GETL      FX.2,FX.3,[D0Re0++#-0x100]
        F         GETL      FX.2,FX.3,[--D1Re0]
        F         GETL      FX.2,FX.3,[A1LbP+#-0x100]
        F         GETL      FX.2,FX.3,[--A1LbP]
        F         GETL      FX.2,FX.3,[D1.7++#0xf8]
        F         GETL      FX.2,FX.3,[D0.7+#-0x8]
        F         GETL      FX.4,FX.5,[D0Re0++#0xf8]
        F         GETL      FX.4,FX.5,[D1Re0++#-0x100]
        F         GETL      FX.4,FX.5,[A1LbP+#0xf8]
        F         GETL      FX.4,FX.5,[A1LbP++#-0x100]
        F         GETL      FX.4,FX.5,[--A0FrP]
        F         GETL      FX.4,FX.5,[D0.7+#-0x100]
        F         GETL      FX.4,FX.5,[--D0.7]
