LIBRARY VERSION.dll
EXPORTS
GetFileVersionInfoA1
GetFileVersionInfoSizeA2
GetFileVersionInfoSizeW3
GetFileVersionInfoW4
VerFindFileA5
VerFindFileW6
VerInstallFileA7
VerInstallFileW8
VerLanguageNameA9
VerLanguageNameW10
VerQueryValueA11
VerQueryValueIndexA12
VerQueryValueIndexW13
VerQueryValueW14

