.*: Assembler messages:
.*:5: Error: opcode not supported on this processor: .* \(.*\) `ldc1 \$f2,d'
.*:6: Error: opcode not supported on this processor: .* \(.*\) `ldc1 \$22,d'
.*:7: Error: opcode not supported on this processor: .* \(.*\) `l.d \$f2,d'
.*:8: Error: opcode not supported on this processor: .* \(.*\) `li.d \$f2,1.2'
.*:9: Error: opcode not supported on this processor: .* \(.*\) `li.d \$22,1.2'
.*:11: Error: opcode not supported on this processor: .* \(.*\) `sdc1 \$f2,d'
.*:12: Error: opcode not supported on this processor: .* \(.*\) `sdc1 \$22,d'
.*:13: Error: opcode not supported on this processor: .* \(.*\) `s.d \$f2,d'
.*:15: Error: opcode not supported on this processor: .* \(.*\) `trunc.w.d \$f4,\$f6,\$4'
.*:18: Error: opcode not supported on this processor: .* \(.*\) `lwc1 \$f2,d'
.*:19: Error: opcode not supported on this processor: .* \(.*\) `lwc1 \$22,d'
.*:20: Error: opcode not supported on this processor: .* \(.*\) `l.s \$f2,d'
.*:21: Error: opcode not supported on this processor: .* \(.*\) `li.s \$f2,1.2'
.*:22: Error: opcode not supported on this processor: .* \(.*\) `li.s \$22,1.2'
.*:24: Error: opcode not supported on this processor: .* \(.*\) `sdc1 \$f2,d'
.*:25: Error: opcode not supported on this processor: .* \(.*\) `sdc1 \$22,d'
.*:26: Error: opcode not supported on this processor: .* \(.*\) `s.d \$f2,d'
.*:28: Error: opcode not supported on this processor: .* \(.*\) `trunc.w.s \$f4,\$f6,\$4'
