.*: Assembler messages:
.*:7: Error: operand 2 must be constant `lui \$2,bar-foo'
.*:8: Error: operand 2 must be constant `lui \$2,baz-bar'
.*:9: Error: operand 2 must be constant `lui \$2,foo-baz'
.*:10: Error: operand 2 must be constant `lui \$2,bar/baz'
