.*: Assembler messages:
.*:49: Error: opcode not supported in the `insn32' mode `nop16'
.*:108: Error: opcode not supported in the `insn32' mode `move16 \$2,\$22'
.*:109: Error: opcode not supported in the `insn32' mode `move16 \$22,\$2'
.*:116: Error: opcode not supported in the `insn32' mode `b16 test'
.*:123: Error: opcode not supported in the `insn32' mode `b16 1f'
.*:131: Error: opcode not supported in the `insn32' mode `b16 1b'
.*:292: Error: opcode not supported in the `insn32' mode `and16 \$2,\$2,\$3'
.*:330: Error: opcode not supported in the `insn32' mode `andi16 \$7,65535'
.*:426: Error: opcode not supported in the `insn32' mode `beqz16 \$16,test2'
.*:543: Error: opcode not supported in the `insn32' mode `bnez16 \$16,test3'
.*:649: Warning: divide by zero
.*:652: Warning: divide by zero
.*:665: Warning: divide by zero
.*:1649: Warning: divide by zero
.*:1652: Warning: divide by zero
.*:1665: Warning: divide by zero
.*:2712: Warning: branch bge is always true
.*:2715: Warning: branch bgeu is always true
.*:2724: Warning: branch bgeu is always true
.*:2799: Warning: branch ble is always true
.*:2814: Warning: branch bleu is always true
.*:2820: Warning: branch bleu is always true
.*:2823: Warning: branch bleu is always true
.*:2922: Warning: branch bgel is always true
.*:2925: Warning: branch bgeul is always true
.*:2934: Warning: branch bgeul is always true
.*:3009: Warning: branch blel is always true
.*:3024: Warning: branch bleul is always true
.*:3030: Warning: branch bleul is always true
.*:3033: Warning: branch bleul is always true
.*:3100: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,0'
.*:3101: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,1<<2'
.*:3102: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,2<<2'
.*:3103: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,3<<2'
.*:3104: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,4<<2'
.*:3105: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,63<<2'
.*:3106: Error: opcode not supported in the `insn32' mode `addiur1sp \$3,63<<2'
.*:3107: Error: opcode not supported in the `insn32' mode `addiur1sp \$4,63<<2'
.*:3108: Error: opcode not supported in the `insn32' mode `addiur1sp \$5,63<<2'
.*:3109: Error: opcode not supported in the `insn32' mode `addiur1sp \$6,63<<2'
.*:3110: Error: opcode not supported in the `insn32' mode `addiur1sp \$7,63<<2'
.*:3111: Error: opcode not supported in the `insn32' mode `addiur1sp \$16,63<<2'
.*:3112: Error: opcode not supported in the `insn32' mode `addiur1sp \$17,63<<2'
.*:3114: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$2,-1'
.*:3115: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$3,-1'
.*:3116: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$4,-1'
.*:3117: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$5,-1'
.*:3118: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$6,-1'
.*:3119: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$7,-1'
.*:3120: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$16,-1'
.*:3121: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$17,-1'
.*:3122: Error: opcode not supported in the `insn32' mode `addiur2 \$3,\$17,-1'
.*:3123: Error: opcode not supported in the `insn32' mode `addiur2 \$4,\$17,-1'
.*:3124: Error: opcode not supported in the `insn32' mode `addiur2 \$5,\$17,-1'
.*:3125: Error: opcode not supported in the `insn32' mode `addiur2 \$6,\$17,-1'
.*:3126: Error: opcode not supported in the `insn32' mode `addiur2 \$7,\$17,-1'
.*:3127: Error: opcode not supported in the `insn32' mode `addiur2 \$16,\$17,-1'
.*:3128: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,-1'
.*:3129: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,1'
.*:3130: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,4'
.*:3131: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,8'
.*:3132: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,12'
.*:3133: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,16'
.*:3134: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,20'
.*:3135: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,24'
.*:3137: Error: opcode not supported in the `insn32' mode `addiusp 2<<2'
.*:3138: Error: opcode not supported in the `insn32' mode `addiusp 3<<2'
.*:3139: Error: opcode not supported in the `insn32' mode `addiusp 254<<2'
.*:3140: Error: opcode not supported in the `insn32' mode `addiusp 255<<2'
.*:3141: Error: opcode not supported in the `insn32' mode `addiusp 256<<2'
.*:3142: Error: opcode not supported in the `insn32' mode `addiusp 257<<2'
.*:3143: Error: opcode not supported in the `insn32' mode `addiusp -3<<2'
.*:3144: Error: opcode not supported in the `insn32' mode `addiusp -4<<2'
.*:3145: Error: opcode not supported in the `insn32' mode `addiusp -255<<2'
.*:3146: Error: opcode not supported in the `insn32' mode `addiusp -256<<2'
.*:3147: Error: opcode not supported in the `insn32' mode `addiusp -257<<2'
.*:3148: Error: opcode not supported in the `insn32' mode `addiusp -258<<2'
.*:3150: Error: opcode not supported in the `insn32' mode `addius5 \$0,0'
.*:3151: Error: opcode not supported in the `insn32' mode `addius5 \$2,0'
.*:3152: Error: opcode not supported in the `insn32' mode `addius5 \$3,0'
.*:3153: Error: opcode not supported in the `insn32' mode `addius5 \$30,0'
.*:3154: Error: opcode not supported in the `insn32' mode `addius5 \$31,0'
.*:3155: Error: opcode not supported in the `insn32' mode `addius5 \$31,1'
.*:3156: Error: opcode not supported in the `insn32' mode `addius5 \$31,2'
.*:3157: Error: opcode not supported in the `insn32' mode `addius5 \$31,3'
.*:3158: Error: opcode not supported in the `insn32' mode `addius5 \$31,7'
.*:3159: Error: opcode not supported in the `insn32' mode `addius5 \$31,-6'
.*:3160: Error: opcode not supported in the `insn32' mode `addius5 \$31,-7'
.*:3161: Error: opcode not supported in the `insn32' mode `addius5 \$31,-8'
.*:4849: Warning: divide by zero
.*:4852: Warning: divide by zero
.*:4865: Warning: divide by zero
.*:5270: Warning: divide by zero
.*:5280: Warning: divide by zero
.*:5290: Warning: divide by zero
.*:5658: Error: opcode not supported in the `insn32' mode `jalr16 \$2'
.*:5663: Error: opcode not supported in the `insn32' mode `jr16 \$2'
.*:5670: Error: opcode not supported in the `insn32' mode `jals test_delay_slot'
.*:5671: Error: opcode not supported in the `insn32' mode `jalrs16 \$2'
.*:5672: Error: opcode not supported in the `insn32' mode `jalrs32 \$2'
.*:5673: Error: opcode not supported in the `insn32' mode `jrs \$2'
.*:5674: Error: opcode not supported in the `insn32' mode `jalrs\.hb \$2'
.*:5675: Error: opcode not supported in the `insn32' mode `jrs\.hb \$2'
.*:5756: Error: opcode not supported in the `insn32' mode `bals test_spec107'
.*:5758: Error: opcode not supported in the `insn32' mode `bgezals \$2,test_spec107'
.*:5760: Error: opcode not supported in the `insn32' mode `bltzals \$2,test_spec107'
