#objdump: -d
#name:    
#source:  inh.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	ff          	swi
   1:	05          	rts
   2:	00          	bgnd
   3:	01          	nop
