#source: b-twoinsn.s
#source: b-post1.s
#source: b-widec.s
#ld: --oformat binary
#objcopy_linked_file:
#objdump: -t

.*:     file format mmo

SYMBOL TABLE:
0+4 g       \.text Main
0+4 g       \.text a
