SCRIPT_NAME=elf
TEMPLATE_NAME=elf
OUTPUT_FORMAT="elf32-bigmoxie"
BIG_OUTPUT_FORMAT="elf32-bigmoxie"
LITTLE_OUTPUT_FORMAT="elf32-littlemoxie"
TEXT_START_ADDR=0x1000
MAXPAGESIZE="CONSTANT (MAXPAGESIZE)"
ARCH=moxie
EMBEDDED=yes
STACK_ADDR=0x400000
