.*sparc6-diag.s: Assembler messages:
.*sparc6-diag.s:4: Error: Illegal operands
.*sparc6-diag.s:5: Error: Illegal operands
.*sparc6-diag.s:6: Error: Illegal operands
.*sparc6-diag.s:7: Error: Illegal operands
.*sparc6-diag.s:8: Error: Illegal operands
.*sparc6-diag.s:3: Error: relocation overflow
