#as: -mdsp=metac21
#objdump: -dr
#name: metadsp21ext

.*: +file format .*

Disassembly of section \.text:

00000000 <.text>:
.*:	9002cee0 	D         T0        #0x0,#0xb,#0x7,#0xe
.*:	9082cee0 	D         T0        #0x10,#0xb,#0x7,#0xe
