hook called: all symbols read.
Input: pr20070b.c \(tmpdir/libpr20070.a\)
Sym: 'def' Resolution: LDPR_PREVAILING_DEF_IRONLY
Sym: 'weakdef' Resolution: LDPR_PREVAILING_DEF_IRONLY
Sym: 'undef' Resolution: LDPR_UNDEF
Sym: 'weakundef' Resolution: LDPR_UNDEF
Sym: 'common' Resolution: LDPR_PREVAILING_DEF_IRONLY
hook called: cleanup.
#...
