	.text
	FD        ABS       FX.0,FX.2
	F         ABS       FX.3,FX.0
	FL        ABS       FX.6,FX.4
	F         MMOVD     D1.0,D1.3,D1.7,FX.0,FX.1,FX.2
	F         MMOVD     D0.0,D0.1,FX.8,FX.9
	F         MMOVL     D0.0,D0.1,D0.7,FX.2,FX.4,FX.6
	F         MMOVL     D1.3,D1.4,FX.0,FX.2
	F         MMOVD     FX.0,FX.1,FX.2,D1.0,D1.3,D1.7
	F         MMOVD     FX.8,FX.9,D0.0,D0.1
	F         MMOVL     FX.2,FX.4,FX.6,D0.0,D0.1,D0.7
	F         MMOVL     FX.0,FX.2,D1.3,D1.4
	FD        MOV       FX.0,FX.2
	F         MOV       FX.3,FX.0
	FL        MOV       FX.6,FX.4
	FD        MOV       FX.0,#0xffff
	F         MOV       FX.3,#0x10
	FL        MOV       FX.6,#0xf00
	FD        NEG       FX.0,FX.2
	F         NEG       FX.3,FX.0
	FL        NEG       FX.6,FX.4
	F         PACK      FX.6,FX.1,FX.8
	FL        SWAP      FX.6,FX.0
	FD        CMP       FX.6,FX.0
	F         CMP       FX.6,FX.0
	FL        CMP       FX.6,FX.0
	FDA       CMP       FX.6,FX.0
	FA        CMP       FX.6,FX.0
	FLA       CMP       FX.6,FX.0
	FDQ       CMP       FX.6,FX.0
	FQ        CMP       FX.6,FX.0
	FLQ       CMP       FX.6,FX.0
	FDAQ      CMP       FX.6,FX.0
	FAQ       CMP       FX.6,FX.0
	FLAQ      CMP       FX.6,FX.0
	FD        CMP       FX.6,#0x0
	F         CMP       FX.6,#0x0
	FL        CMP       FX.6,#0x0
	FD        MAX       FX.6,FX.0,FX.2
	F         MAX       FX.3,FX.4,FX.5
	FL        MAX       FX.2,FX.4,FX.6
	FD        MIN       FX.6,FX.0,FX.2
	F         MIN       FX.3,FX.4,FX.5
	FL        MIN       FX.2,FX.4,FX.6
	F         DTOF      FX.6,FX.1
	F         FTOD      FX.0,FX.2
	FL        FTOH      FX.6,FX.0
	F         FTOH      FX.3,FX.5
	F         DTOH      FX.2,FX.0
	FZ        FTOI      FX.6,FX.1
	F         FTOI      FX.2,FX.4
	FL        FTOI      FX.4,FX.0
	FLZ       FTOI      FX.3,FX.5
	F         DTOI      FX.6,FX.1
	FZ        DTOI      FX.6,FX.1
	F         DTOL      FX.2,FX.4
	FZ        DTOL      FX.2,FX.4
	F         FTOX      FX.6,FX.3,#3
	FL        FTOX      FX.4,FX.0,#4
	F         DTOX      FX.2,FX.4,#8
	F         DTOXL     FX.2,FX.4,#6
	F         HTOD      FX.6,FX.4
	FL        HTOF      FX.6,FX.2
	F         HTOF      FX.2,FX.4
	F         ITOF      FX.6,FX.1
	FL        ITOF      FX.4,FX.0
	F         ITOD      FX.2,FX.4
	F         LTOD      FX.2,FX.4
	F         XTOF      FX.2,FX.3,#2
	FL        XTOF      FX.6,FX.0,#3
	F         XTOD      FX.2,FX.4,#4
	F         XLTOD     FX.2,FX.4,#7
	FD        ADD       FX.0,FX.2,FX.4
	F         ADD       FX.3,FX.1,FX.0
	FL        ADD       FX.6,FX.4,FX.2
	FDI       ADD       FX.0,FX.2,FX.4
	FI        ADD       FX.3,FX.1,FX.0
	FLI       ADD       FX.6,FX.4,FX.2
	FD        MUL       FX.0,FX.2,FX.4
	F         MUL       FX.3,FX.1,FX.0
	FL        MUL       FX.6,FX.4,FX.2
	FDI       MUL       FX.0,FX.2,FX.4
	FI        MUL       FX.3,FX.1,FX.0
	FLI       MUL       FX.6,FX.4,FX.2
	FD        SUB       FX.0,FX.2,FX.4
	F         SUB       FX.3,FX.1,FX.0
	FL        SUB       FX.6,FX.4,FX.2
	FDI       SUB       FX.0,FX.2,FX.4
	FI        SUB       FX.3,FX.1,FX.0
	FLI       SUB       FX.6,FX.4,FX.2
	FD        MAC       ACF.0,FX.2,FX.4
	F         MAC       ACF.0,FX.1,FX.0
	FD        MAR       FX.0,FX.2,FX.4
	F         MAR       FX.3,FX.1,FX.0
	FD        MARS      FX.0,FX.2,FX.4
	F         MARS      FX.3,FX.1,FX.0
	FD        MAW       FX.2,FX.4,FX.6
	F         MAW       FX.1,FX.0,FX.6
	FD        MAWS      FX.2,FX.4,FX.6
	F         MAWS      FX.1,FX.0,FX.6
	FD        MAW1      FX.4,FX.6
	F         MAW1      FX.0,FX.6
	FD        MAWS1     FX.4,FX.6
	F         MAWS1     FX.0,FX.6
	FD        MXA       FX.0,FX.2,FX.4
	F         MXA       FX.3,FX.1,FX.0
	FL        MXA       FX.6,FX.4,FX.2
	FDI       MXA       FX.0,FX.2,FX.4
	FI        MXA       FX.3,FX.1,FX.0
	FLI       MXA       FX.6,FX.4,FX.2
	FD        MXAS      FX.0,FX.2,FX.4
	F         MXAS      FX.3,FX.1,FX.0
	FL        MXAS      FX.6,FX.4,FX.2
	FDI       MXAS      FX.0,FX.2,FX.4
	FI        MXAS      FX.3,FX.1,FX.0
	FLI       MXAS      FX.6,FX.4,FX.2
	FD        MXA1      FX.0,FX.2,FX.4
	F         MXA1      FX.3,FX.1,FX.0
	FL        MXA1      FX.6,FX.4,FX.2
	FDI       MXA1      FX.0,FX.2,FX.4
	FI        MXA1      FX.3,FX.1,FX.0
	FLI       MXA1      FX.6,FX.4,FX.2
	FD        MXAS1     FX.0,FX.2,FX.4
	F         MXAS1     FX.3,FX.1,FX.0
	FL        MXAS1     FX.6,FX.4,FX.2
	FDI       MXAS1     FX.0,FX.2,FX.4
	FI        MXAS1     FX.3,FX.1,FX.0
	FLI       MXAS1     FX.6,FX.4,FX.2
	FD        MUZ       FX.0,FX.2,FX.4
	F         MUZ       FX.4,FX.5,FX.6
	FL        MUZ       FX.6,FX.4,FX.2
	FDI       MUZ       FX.0,FX.2,FX.4
	FI        MUZ       FX.4,FX.5,FX.6
	FLI       MUZ       FX.6,FX.4,FX.2
	FDQ       MUZ       FX.0,FX.2,FX.4
	FQ        MUZ       FX.4,FX.5,FX.6
	FLQ       MUZ       FX.6,FX.4,FX.2
	FDIQ      MUZ       FX.0,FX.2,FX.4
	FIQ       MUZ       FX.4,FX.5,FX.6
	FLIQ      MUZ       FX.6,FX.4,FX.2
	FD        MUZS      FX.0,FX.2,FX.4
	F         MUZS      FX.4,FX.5,FX.6
	FL        MUZS      FX.6,FX.4,FX.2
	FD        MUZ1      FX.0,FX.2,FX.4
	F         MUZ1      FX.4,FX.5,FX.6
	FL        MUZ1      FX.6,FX.4,FX.2
	FD        MUZS1     FX.0,FX.2,FX.4
	F         MUZS1     FX.4,FX.5,FX.6
	FL        MUZS1     FX.6,FX.4,FX.2
	FD        RCP       FX.0,FX.2
	F         RCP       FX.3,FX.1
	FL        RCP       FX.6,FX.4
	FDI       RCP       FX.0,FX.2
	FI        RCP       FX.3,FX.1
	FLI       RCP       FX.6,FX.4
	FDZ       RCP       FX.0,FX.2
	FZ        RCP       FX.3,FX.1
	FLZ       RCP       FX.6,FX.4
	FDIZ      RCP       FX.0,FX.2
	FIZ       RCP       FX.3,FX.1
	FLIZ      RCP       FX.6,FX.4
	FDQ       RCP       FX.0,FX.2
	FQ        RCP       FX.3,FX.1
	FLQ       RCP       FX.6,FX.4
	FDIQ      RCP       FX.0,FX.2
	FIQ       RCP       FX.3,FX.1
	FLIQ      RCP       FX.6,FX.4
	FD        RSQ       FX.0,FX.2
	F         RSQ       FX.3,FX.1
	FL        RSQ       FX.6,FX.4
	FDI       RSQ       FX.0,FX.2
	FI        RSQ       FX.3,FX.1
	FLI       RSQ       FX.6,FX.4
	FDZ       RSQ       FX.0,FX.2
	FZ        RSQ       FX.3,FX.1
	FLZ       RSQ       FX.6,FX.4
	FDIZ      RSQ       FX.0,FX.2
	FIZ       RSQ       FX.3,FX.1
	FLIZ      RSQ       FX.6,FX.4
	FDQ       RSQ       FX.0,FX.2
	FQ        RSQ       FX.3,FX.1
	FLQ       RSQ       FX.6,FX.4
	FDIQ      RSQ       FX.0,FX.2
	FIQ       RSQ       FX.3,FX.1
	FLIQ      RSQ       FX.6,FX.4
	FL        ADDRE     FX.6,FX.4,FX.2
	FLI       ADDRE     FX.6,FX.4,FX.2
	FL        MULRE     FX.6,FX.4,FX.2
	FLI       MULRE     FX.6,FX.4,FX.2
	FL        SUBRE     FX.6,FX.4,FX.2
	FLI       SUBRE     FX.6,FX.4,FX.2
