main:
_main:
	nop

	.comm   _test_equiv.eq.1_, 16, 4
	.comm   _test_equiv.eq.100, 16, 5
	.comm   _test_equiv.eq._, 16, 6
	.comm   _test_equiv.eq., 16, 7

	.comm   _test$equiv.eq.1_, 16, 4
	.comm   _test$equiv.eq.100, 16, 5
	.comm   _test$equiv.eq._, 16, 6
	.comm   _test$equiv.eq., 16, 7

