source_sh ${srcdir}/emulparams/elf32ltsmip.sh
source_sh ${srcdir}/emulparams/elf_fbsd.sh
OUTPUT_FORMAT="elf32-tradlittlemips-freebsd"
BIG_OUTPUT_FORMAT="elf32-tradbigmips-freebsd"
LITTLE_OUTPUT_FORMAT="elf32-tradlittlemips-freebsd"
