only_in_803_807:
   flrws    fr2, 3.14
   fmovis   fr2, 1.5
   fmovis   fr2, -1.5
   fmovis   fr2, 2.5
only_in_807:
   flrwd    fr2, 3.14
   fmovid   fr2, 2.5
   fmovid   fr2, -2.5
   fmovid   fr2, -1.5
