[^:]*: Assembler messages:
[^:]+:[0-9]+: Error: selected processor does not support `aese v7\.16b,v31\.16b'
[^:]+:[0-9]+: Error: selected processor does not support `aesd v7\.16b,v31\.16b'
[^:]+:[0-9]+: Error: selected processor does not support `aesmc v7\.16b,v31\.16b'
[^:]+:[0-9]+: Error: selected processor does not support `aesimc v7\.16b,v31\.16b'
[^:]+:[0-9]+: Error: selected processor does not support `sha1h s7,s31'
[^:]+:[0-9]+: Error: selected processor does not support `sha1su1 v7\.4s,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha256su0 v7\.4s,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha1c q7,s15,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha1p q7,s15,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha1m q7,s15,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha1su0 v7\.4s,v15\.4s,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha256h q7,q15,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha256h2 q7,q15,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `sha256su1 v7\.4s,v15\.4s,v31\.4s'
[^:]+:[0-9]+: Error: selected processor does not support `pmull v7\.8h,v15\.8b,v31\.8b'
[^:]+:[0-9]+: Error: selected processor does not support `pmull v7\.1q,v15\.1d,v31\.1d'
[^:]+:[0-9]+: Error: selected processor does not support `pmull2 v7\.8h,v15\.16b,v31\.16b'
[^:]+:[0-9]+: Error: selected processor does not support `pmull2 v7\.1q,v15\.2d,v31\.2d'
