[^:]*: Assembler messages:
[^:]*:5: Error: predication on A0 not supported on this architecture
[^:]*:5: Error: instruction 'nop' cannot be predicated
[^:]*:6: Error: instruction 'nop' cannot be predicated
[^:]*:7: Error: instruction 'nop' cannot be predicated
[^:]*:8: Error: instruction 'nop' cannot be predicated
[^:]*:9: Error: instruction 'nop' cannot be predicated
[^:]*:10: Error: instruction 'nop' cannot be predicated
[^:]*:11: Error: predication on A0 not supported on this architecture
[^:]*:11: Error: instruction 'nop' cannot be predicated
[^:]*:12: Error: instruction 'nop' cannot be predicated
[^:]*:13: Error: instruction 'nop' cannot be predicated
[^:]*:14: Error: instruction 'nop' cannot be predicated
[^:]*:15: Error: instruction 'nop' cannot be predicated
[^:]*:16: Error: instruction 'nop' cannot be predicated
[^:]*:18: Error: instruction 'nop' cannot be predicated
[^:]*:19: Error: instruction 'nop' cannot be predicated
[^:]*:20: Error: instruction 'nop' cannot be predicated
[^:]*:21: Error: instruction 'nop' cannot be predicated
[^:]*:22: Error: instruction 'nop' cannot be predicated
[^:]*:23: Error: instruction 'nop' cannot be predicated
[^:]*:24: Error: instruction 'nop' cannot be predicated
[^:]*:25: Error: instruction 'nop' cannot be predicated
[^:]*:26: Error: instruction 'nop' cannot be predicated
[^:]*:27: Error: instruction 'nop' cannot be predicated
[^:]*:28: Error: instruction 'nop' cannot be predicated
[^:]*:29: Error: instruction 'nop' cannot be predicated
[^:]*:31: Error: instruction 'nop' cannot be predicated
[^:]*:32: Error: instruction 'nop' cannot be predicated
[^:]*:33: Error: instruction 'nop' cannot be predicated
[^:]*:34: Error: instruction 'nop' cannot be predicated
[^:]*:35: Error: instruction 'nop' cannot be predicated
[^:]*:36: Error: instruction 'nop' cannot be predicated
[^:]*:37: Error: instruction 'nop' cannot be predicated
[^:]*:38: Error: instruction 'nop' cannot be predicated
[^:]*:39: Error: instruction 'nop' cannot be predicated
[^:]*:40: Error: instruction 'nop' cannot be predicated
[^:]*:41: Error: instruction 'nop' cannot be predicated
[^:]*:42: Error: instruction 'nop' cannot be predicated
[^:]*:44: Error: predication on A0 not supported on this architecture
[^:]*:44: Error: instruction 'nop' cannot be predicated
[^:]*:45: Error: instruction 'nop' cannot be predicated
[^:]*:46: Error: instruction 'nop' cannot be predicated
[^:]*:47: Error: instruction 'nop' cannot be predicated
[^:]*:48: Error: instruction 'nop' cannot be predicated
[^:]*:49: Error: instruction 'nop' cannot be predicated
[^:]*:50: Error: predication on A0 not supported on this architecture
[^:]*:50: Error: instruction 'nop' cannot be predicated
[^:]*:51: Error: instruction 'nop' cannot be predicated
[^:]*:52: Error: instruction 'nop' cannot be predicated
[^:]*:53: Error: instruction 'nop' cannot be predicated
[^:]*:54: Error: instruction 'nop' cannot be predicated
[^:]*:55: Error: instruction 'nop' cannot be predicated
[^:]*:57: Error: predication on A0 not supported on this architecture
[^:]*:57: Error: instruction 'nop' cannot be predicated
[^:]*:58: Error: instruction 'nop' cannot be predicated
[^:]*:59: Error: instruction 'nop' cannot be predicated
[^:]*:60: Error: instruction 'nop' cannot be predicated
[^:]*:61: Error: instruction 'nop' cannot be predicated
[^:]*:62: Error: instruction 'nop' cannot be predicated
[^:]*:63: Error: predication on A0 not supported on this architecture
[^:]*:63: Error: instruction 'nop' cannot be predicated
[^:]*:64: Error: instruction 'nop' cannot be predicated
[^:]*:65: Error: instruction 'nop' cannot be predicated
[^:]*:66: Error: instruction 'nop' cannot be predicated
[^:]*:67: Error: instruction 'nop' cannot be predicated
[^:]*:68: Error: instruction 'nop' cannot be predicated
[^:]*:70: Error: instruction 'nop' cannot be predicated
[^:]*:71: Error: instruction 'nop' cannot be predicated
[^:]*:72: Error: instruction 'nop' cannot be predicated
[^:]*:73: Error: instruction 'nop' cannot be predicated
[^:]*:74: Error: instruction 'nop' cannot be predicated
[^:]*:75: Error: instruction 'nop' cannot be predicated
[^:]*:76: Error: instruction 'nop' cannot be predicated
[^:]*:77: Error: instruction 'nop' cannot be predicated
[^:]*:78: Error: instruction 'nop' cannot be predicated
[^:]*:79: Error: instruction 'nop' cannot be predicated
[^:]*:80: Error: instruction 'nop' cannot be predicated
[^:]*:81: Error: instruction 'nop' cannot be predicated
[^:]*:83: Error: predication on A0 not supported on this architecture
[^:]*:83: Error: instruction 'nop' cannot be predicated
[^:]*:84: Error: instruction 'nop' cannot be predicated
[^:]*:85: Error: instruction 'nop' cannot be predicated
[^:]*:86: Error: instruction 'nop' cannot be predicated
[^:]*:87: Error: instruction 'nop' cannot be predicated
[^:]*:88: Error: instruction 'nop' cannot be predicated
[^:]*:89: Error: predication on A0 not supported on this architecture
[^:]*:89: Error: instruction 'nop' cannot be predicated
[^:]*:90: Error: instruction 'nop' cannot be predicated
[^:]*:91: Error: instruction 'nop' cannot be predicated
[^:]*:92: Error: instruction 'nop' cannot be predicated
[^:]*:93: Error: instruction 'nop' cannot be predicated
[^:]*:94: Error: instruction 'nop' cannot be predicated
