
.*:     file format.*


Disassembly of section destsect:

00108002 <[^>]*>:
  108002:	f7ff fffe 	bl	108002 <dest>

Disassembly of section .text:

000080.. <[^>]*>:
    80..:	f07f afff 	bne.w	108002 <dest>
