.*: Assembler messages:
.*:2: Error: relocation invalid for store .*
.*:3: Error: relocation invalid for store .*
.*:4: Error: relocation invalid for store .*
.*:6: Error: relocation invalid for store .*
.*:7: Error: relocation invalid for store .*
.*:8: Error: relocation invalid for store .*
.*:9: Error: relocation invalid for store .*
.*:11: Error: relocation invalid for store .*
.*:12: Error: relocation invalid for store .*
.*:13: Error: relocation invalid for store .*
