.*: Assembler messages:
.*:4: Error: opcode not supported on this processor: .* \(.*\) `recip.d \$f4,\$f6'
.*:5: Error: opcode not supported on this processor: .* \(.*\) `recip.s \$f4,\$f6'
.*:6: Error: opcode not supported on this processor: .* \(.*\) `rsqrt.d \$f4,\$f6'
.*:7: Error: opcode not supported on this processor: .* \(.*\) `rsqrt.s \$f4,\$f6'
