[^:]*: Assembler messages:
[^:]*:3: Error: r15 not allowed here -- `vld1.8 {d0},1f'
[^:]*:5: Error: r15 not allowed here -- `vld1.8 {D0},R0'
[^:]*:6: Error: r15 not allowed here -- `vld1.8 {Q1},R0'
[^:]*:7: Error: r15 not allowed here -- `vld1.8 {D0},\[PC\]'
[^:]*:8: Error: r15 not allowed here -- `vld1.8 {D0},\[PC,#0\]'
[^:]*:9: Error: r15 not allowed here -- `vst1.8 {D0},R0'
[^:]*:10: Error: r15 not allowed here -- `vst1.8 {Q1},R0'
[^:]*:11: Error: r15 not allowed here -- `vst1.8 {D0},\[PC\]'
[^:]*:12: Error: r15 not allowed here -- `vst1.8 {D0},\[PC,#0\]'
[^:]*:13: Error: only loads support such operands -- `vst1.8 {D0\[\].*
[^:]*:14: Error: only loads support such operands -- `vst2.8 {D0\[\].*
[^:]*:15: Error: only loads support such operands -- `vst3.16 {D0\[\].*
[^:]*:16: Error: only loads support such operands -- `vst4.32 {D0\[\].*
[^:]*:17: Error: instruction does not accept this addressing mode -- `vld1.8 {Q0},\[R0,#8\]'
[^:]*:18: Error: instruction does not accept this addressing mode -- `vld1.8 {Q0},\[R0,#8\]!'
[^:]*:19: Error: instruction does not accept this addressing mode -- `vld1.8 {Q0},\[R0,R1\]'
[^:]*:20: Error: instruction does not accept this addressing mode -- `vld1.8 {Q0},\[R0,R1\]!'
[^:]*:22: Error: r15 not allowed here -- `vld1.8 {d0},2f'
[^:]*:24: Error: r15 not allowed here -- `vld1.8 {D0},R0'
[^:]*:25: Error: r15 not allowed here -- `vld1.8 {Q1},R0'
[^:]*:26: Error: r15 not allowed here -- `vld1.8 {D0},\[PC\]'
[^:]*:27: Error: r15 not allowed here -- `vld1.8 {D0},\[PC,#0\]'
[^:]*:28: Error: r15 not allowed here -- `vst1.8 {D0},R0'
[^:]*:29: Error: r15 not allowed here -- `vst1.8 {Q1},R0'
[^:]*:30: Error: r15 not allowed here -- `vst1.8 {D0},\[PC\]'
[^:]*:31: Error: r15 not allowed here -- `vst1.8 {D0},\[PC,#0\]'
[^:]*:34: Error: immediate out of range for shift -- `vshl.i8 d0,d0,#8'
[^:]*:36: Error: immediate out of range for shift -- `vshl.i16 d0,d0,#16'
[^:]*:38: Error: immediate out of range for shift -- `vshl.i32 d0,d0,#32'
[^:]*:40: Error: .* -- `vshl.i64 d0,d0,#64'
[^:]*:43: Error: immediate out of range for shift -- `vqshl.s8 d0,d0,#8'
[^:]*:45: Error: immediate out of range for shift -- `vqshl.s16 d0,d0,#16'
[^:]*:47: Error: immediate out of range for shift -- `vqshl.s32 d0,d0,#32'
[^:]*:49: Error: .* -- `vqshl.s64 d0,d0,#64'
[^:]*:52: Error: immediate out of range for shift -- `vqshlu.s8 d0,d0,#8'
[^:]*:54: Error: immediate out of range for shift -- `vqshlu.s16 d0,d0,#16'
[^:]*:56: Error: immediate out of range for shift -- `vqshlu.s32 d0,d0,#32'
[^:]*:58: Error: .* -- `vqshlu.s64 d0,d0,#64'
