	.globl text_symbol1
	.globl text_symbol2
	.globl text_symbol3
	.globl end_symbol
	.text
text_symbol1:
	.byte 0,0,0,0
	.byte 0,0,0,0
	.byte 0,0,0,0
text_symbol2:
	.byte 0,0,0,0
	.byte 0,0,0,0
text_symbol3:
	.byte 0,0,0,0
end_symbol:
