[^:]*: Assembler messages:
[^:]*:10: Error: immediate value out of range -- `vshlc q0,r1,#0'
[^:]*:11: Error: immediate value out of range -- `vshlc q0,r1,#33'
[^:]*:12: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:13: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:16: Error: syntax error -- `vshlceq q0,r1,#2'
[^:]*:17: Error: syntax error -- `vshlceq q0,r1,#2'
[^:]*:19: Error: syntax error -- `vshlceq q0,r1,#2'
[^:]*:20: Error: vector predicated instruction should be in VPT/VPST block -- `vshlct q0,r1,#2'
[^:]*:22: Error: instruction missing MVE vector predication code -- `vshlc q0,r1,#2'
