[^:]*: Assembler messages:
[^:]*:[0-9]+: Error: selected processor does not support system register name 'rctx'
[^:]*:[0-9]+: Error: selected processor does not support `cfp rctx,x1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'rctx'
[^:]*:[0-9]+: Error: selected processor does not support `dvp rctx,x2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'rctx'
[^:]*:[0-9]+: Error: selected processor does not support `cpp rctx,x3'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cvadp'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'rndr'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'rndrrs'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'scxtnum_el0'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'scxtnum_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'scxtnum_el2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'scxtnum_el3'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'scxtnum_el12'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'id_pfr2_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tco'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tco'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsre0_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el3'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el12'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'rgsr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'gcr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'gmid_el1'
[^:]*:[0-9]+: Error: selected processor does not support PSTATE field name 'tco'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tco'
[^:]*:[0-9]+: Error: selected processor does not support PSTATE field name 'tco'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tco'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsre0_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el2'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el3'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'tfsr_el12'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'rgsr_el1'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'gcr_el1'
[^:]*:[0-9]+: Error: selected processor does not support PSTATE field name 'tco'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'igvac'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'igsw'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgsw'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cigsw'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgvac'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgvap'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgvadp'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cigvac'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'gva'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'igdvac'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'igdsw'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgdsw'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cigdsw'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgdvac'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgdvap'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cgdvadp'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'cigdvac'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'gzva'
