#source: ./mvtacgu.s
#objdump: -dr

.*:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	fd 17 30                      	mvtacgu	a0, r0
   3:	fd 17 3f                      	mvtacgu	a0, r15
   6:	fd 17 b0                      	mvtacgu	a1, r0
   9:	fd 17 bf                      	mvtacgu	a1, r15
