	.section	.debug_loc,"",%progbits

	.byte 0x5a
	.byte 0x4c
	.byte 0x49
	.byte 0x42
	.byte 0x00
	.byte 0x00
	.byte 0x00
	.byte 0x00
	.byte 0x00
	.byte 0x00
	.byte 0x00
	.byte 0x6b
	.byte 0x78
	.byte 0x9c
	.byte 0x63
	.byte 0x60
	.byte 0x80
	.byte 0x00
	.byte 0x46
	.byte 0x86
	.byte 0x00
	.byte 0x28
	.byte 0x8b
	.byte 0x81
	.byte 0x85
	.byte 0xe1
	.byte 0x33
	.byte 0x63
	.byte 0xc0
	.byte 0x7c
	.byte 0x06
	.byte 0x34
	.byte 0xc0
	.byte 0xc8
	.byte 0x10
	.byte 0x08
	.byte 0x63
	.byte 0x32
	.byte 0x33
	.byte 0x14
	.byte 0xd6
	.byte 0xc3
	.byte 0xe5
	.byte 0xb9
	.byte 0x19
	.byte 0x0a
	.byte 0x18
	.byte 0x14
	.byte 0x3e
	.byte 0x33
	.byte 0x06
	.byte 0x2a
	.byte 0x15
	.byte 0x30
	.byte 0x28
	.byte 0xa1
	.byte 0x0a
	.byte 0x02
	.byte 0x05
	.byte 0x40
	.byte 0xe2
	.byte 0x70
	.byte 0x41
	.byte 0x00
	.byte 0xc1
	.byte 0x6a
	.byte 0x0a
	.byte 0x83
