[^:]+: Assembler messages:
[^:]+:[0-9]+: Error: immediate value out of range 0 to 63 at operand 2 -- `rmif X0,65,2'
[^:]+:[0-9]+: Error: immediate value out of range 0 to 15 at operand 3 -- `rmif X1,60,20'
[^:]+:[0-9]+: Error: immediate offset out of range -256 to 255 at operand 2 -- `ldapurb W0,\[X0,256\]'
