
.*:     file format .*


Disassembly of section \.text:

00008f00 <targetfn>:
    8f00:	4770      	bx	lr
#...

00008f08 <_start>:
    8f08:	bf00      	nop
    8f0a:	eb01 0002 	add\.w	r0, r1, r2
    8f0e:	f7ff fff7 	bl	8f00 <targetfn>
    8f12:	eb01 0002 	add\.w	r0, r1, r2
    8f16:	f7ff fff3 	bl	8f00 <targetfn>
    8f1a:	eb01 0002 	add\.w	r0, r1, r2
    8f1e:	f7ff ffef 	bl	8f00 <targetfn>
    8f22:	eb01 0002 	add\.w	r0, r1, r2
    8f26:	f7ff ffeb 	bl	8f00 <targetfn>
    8f2a:	eb01 0002 	add\.w	r0, r1, r2
    8f2e:	f7ff ffe7 	bl	8f00 <targetfn>
    8f32:	eb01 0002 	add\.w	r0, r1, r2
    8f36:	f7ff ffe3 	bl	8f00 <targetfn>
    8f3a:	eb01 0002 	add\.w	r0, r1, r2
    8f3e:	f7ff ffdf 	bl	8f00 <targetfn>
    8f42:	eb01 0002 	add\.w	r0, r1, r2
    8f46:	f7ff ffdb 	bl	8f00 <targetfn>
    8f4a:	eb01 0002 	add\.w	r0, r1, r2
    8f4e:	f7ff ffd7 	bl	8f00 <targetfn>
    8f52:	eb01 0002 	add\.w	r0, r1, r2
    8f56:	f7ff ffd3 	bl	8f00 <targetfn>
    8f5a:	eb01 0002 	add\.w	r0, r1, r2
    8f5e:	f7ff ffcf 	bl	8f00 <targetfn>
    8f62:	eb01 0002 	add\.w	r0, r1, r2
    8f66:	f7ff ffcb 	bl	8f00 <targetfn>
    8f6a:	eb01 0002 	add\.w	r0, r1, r2
    8f6e:	f7ff ffc7 	bl	8f00 <targetfn>
    8f72:	eb01 0002 	add\.w	r0, r1, r2
    8f76:	f7ff ffc3 	bl	8f00 <targetfn>
    8f7a:	eb01 0002 	add\.w	r0, r1, r2
    8f7e:	f7ff ffbf 	bl	8f00 <targetfn>
    8f82:	eb01 0002 	add\.w	r0, r1, r2
    8f86:	f7ff ffbb 	bl	8f00 <targetfn>
    8f8a:	eb01 0002 	add\.w	r0, r1, r2
    8f8e:	f7ff ffb7 	bl	8f00 <targetfn>
    8f92:	eb01 0002 	add\.w	r0, r1, r2
    8f96:	f7ff ffb3 	bl	8f00 <targetfn>
    8f9a:	eb01 0002 	add\.w	r0, r1, r2
    8f9e:	f7ff ffaf 	bl	8f00 <targetfn>
    8fa2:	eb01 0002 	add\.w	r0, r1, r2
    8fa6:	f7ff ffab 	bl	8f00 <targetfn>
    8faa:	eb01 0002 	add\.w	r0, r1, r2
    8fae:	f7ff ffa7 	bl	8f00 <targetfn>
    8fb2:	eb01 0002 	add\.w	r0, r1, r2
    8fb6:	f7ff ffa3 	bl	8f00 <targetfn>
    8fba:	eb01 0002 	add\.w	r0, r1, r2
    8fbe:	f7ff ff9f 	bl	8f00 <targetfn>
    8fc2:	eb01 0002 	add\.w	r0, r1, r2
    8fc6:	f7ff ff9b 	bl	8f00 <targetfn>
    8fca:	eb01 0002 	add\.w	r0, r1, r2
    8fce:	f7ff ff97 	bl	8f00 <targetfn>
    8fd2:	eb01 0002 	add\.w	r0, r1, r2
    8fd6:	f7ff ff93 	bl	8f00 <targetfn>
    8fda:	eb01 0002 	add\.w	r0, r1, r2
    8fde:	f7ff ff8f 	bl	8f00 <targetfn>
    8fe2:	eb01 0002 	add\.w	r0, r1, r2
    8fe6:	f7ff ff8b 	bl	8f00 <targetfn>
    8fea:	eb01 0002 	add\.w	r0, r1, r2
    8fee:	f7ff ff87 	bl	8f00 <targetfn>
    8ff2:	eb01 0002 	add\.w	r0, r1, r2
    8ff6:	f7ff ff83 	bl	8f00 <targetfn>
    8ffa:	eb01 0002 	add\.w	r0, r1, r2
    8ffe:	f000 f807 	bl	9010 <_start\+0x108>
    9002:	eb01 0002 	add\.w	r0, r1, r2
    9006:	f7ff ff7b 	bl	8f00 <targetfn>
    900a:	4770      	bx	lr
#...
    9010:	f7ff bf76 	b\.w	8f00 <targetfn>
