[^:]*: Assembler messages:
[^:]*:8: Error: cannot use register index with PC-relative addressing -- `str r0,\[pc,4\]'
[^:]*:9: Error: cannot use register index with PC-relative addressing -- `str r0,d'
[^:]*:10: Error: r15 not allowed here -- `str pc,\[r0\]'
