[^:]*: Assembler messages:
[^:]*:10: Error: bad type in SIMD instruction -- `vmulh.f16 q0,q1,q2'
[^:]*:11: Error: bad type in SIMD instruction -- `vmulh.i32 q0,q1,q2'
[^:]*:12: Error: bad type in SIMD instruction -- `vmulh.s64 q0,q1,q2'
[^:]*:13: Error: bad type in SIMD instruction -- `vrmulh.f16 q0,q1,q2'
[^:]*:14: Error: bad type in SIMD instruction -- `vrmulh.i32 q0,q1,q2'
[^:]*:15: Error: bad type in SIMD instruction -- `vrmulh.s64 q0,q1,q2'
[^:]*:16: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:16: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:16: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:16: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:16: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:16: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:19: Error: syntax error -- `vmulheq.s16 q0,q1,q2'
[^:]*:20: Error: syntax error -- `vmulheq.s16 q0,q1,q2'
[^:]*:22: Error: syntax error -- `vmulheq.s16 q0,q1,q2'
[^:]*:23: Error: vector predicated instruction should be in VPT/VPST block -- `vmulht.s16 q0,q1,q2'
[^:]*:25: Error: instruction missing MVE vector predication code -- `vmulh.s16 q0,q1,q2'
[^:]*:27: Error: syntax error -- `vrmulheq.s16 q0,q1,q2'
[^:]*:28: Error: syntax error -- `vrmulheq.s16 q0,q1,q2'
[^:]*:30: Error: syntax error -- `vrmulheq.s16 q0,q1,q2'
[^:]*:31: Error: vector predicated instruction should be in VPT/VPST block -- `vrmulht.s16 q0,q1,q2'
[^:]*:33: Error: instruction missing MVE vector predication code -- `vrmulh.s16 q0,q1,q2'
