#...
 0x00000017 \(JMPREL\) +0x.*08
 0x00000011 \(REL\) +0x.*00
#...

Relocation section '\.rel\.dyn' at offset 0x.*00 contains 2 entries:
 Offset +Info +Type +Sym\.Value +Sym\. Name
.* R_ARM_COPY .* data_obj
.* R_ARM_JUMP_SLOT .* lib_func1
