#objdump: -d

.*:     file format .*

Disassembly of section \.text:

0+000 <.*>:
   0:	aa1103e7 	mov	x7, x17
   4:	aa1167e7 	orr	x7, xzr, x17, lsl #25
   8:	aa1167e7 	orr	x7, xzr, x17, lsl #25
   c:	aa4003e0 	orr	x0, xzr, x0, lsr #0
  10:	aa0007e0 	orr	x0, xzr, x0, lsl #1
  14:	aa0003d0 	orr	x16, x30, x0
