[^:]*: Assembler messages:
[^:]*:7: Error: r15 not allowed here -- `strexh r0,r1,#0x04'
[^:]*:8: Error: instruction does not accept this addressing mode -- `strexh r0,r1,\[r2\],#0x04'
[^:]*:9: Error: instruction does not accept this addressing mode -- `strexh r0,r1,\[r2,#\+0x00\]!'
[^:]*:10: Error: instruction does not accept this addressing mode -- `strexh r0,r1,\[r2,r3\]'
[^:]*:11: Error: registers may not be the same -- `strexh r0,r0,\[r1]'
[^:]*:12: Error: instruction does not accept this addressing mode -- `strexh r0,r1,\[r2,#-0x04\]'
[^:]*:13: Error: r15 not allowed here -- `strexh r0,r1,\[r15\]'
[^:]*:14: Error: r13 not allowed here -- `strexh r0,r13,\[r1\]'
[^:]*:15: Error: r15 not allowed here -- `strexh r0,r15,\[r1\]'
[^:]*:16: Error: r13 not allowed here -- `strexh r13,r0,\[r1\]'
[^:]*:17: Error: r15 not allowed here -- `strexh r15,r0,\[r1\]'
[^:]*:21: Error: r15 not allowed here -- `strexb r0,r1,#0x04'
[^:]*:22: Error: instruction does not accept this addressing mode -- `strexb r0,r1,\[r2\],#0x04'
[^:]*:23: Error: instruction does not accept this addressing mode -- `strexb r0,r1,\[r2,#\+0x00\]!'
[^:]*:24: Error: instruction does not accept this addressing mode -- `strexb r0,r1,\[r2,r3\]'
[^:]*:25: Error: registers may not be the same -- `strexb r0,r0,\[r1]'
[^:]*:26: Error: instruction does not accept this addressing mode -- `strexb r0,r1,\[r2,#-0x04\]'
[^:]*:27: Error: r15 not allowed here -- `strexb r0,r1,\[r15\]'
[^:]*:28: Error: r13 not allowed here -- `strexb r0,r13,\[r1\]'
[^:]*:29: Error: r15 not allowed here -- `strexb r0,r15,\[r1\]'
[^:]*:30: Error: r13 not allowed here -- `strexb r13,r0,\[r1\]'
[^:]*:31: Error: r15 not allowed here -- `strexb r15,r0,\[r1\]'

