
Elf file type is EXEC.*
Entry point 0x0
There is 1 program header, starting at offset [0-9]+

Program Headers:
  Type           Offset   VirtAddr   PhysAddr   FileSiz MemSiz  Flg Align
  LOAD ( +0x[0-9a-f]+){5} RWE 0x[0-f]+

 Section to Segment mapping:
  Segment Sections...
   00     \.text_vle \.text_iv \.data \.iv_handlers 
