MACHINE=
SCRIPT_NAME=elfm9s12z
OUTPUT_FORMAT="elf32-s12z"
ROM_TOP=0xFFFFFF
ROM_SIZE=0x20000
RAM_START_ADDR=0x001000
RAM_SIZE=8192
EEPROM_START_ADDR=0x100000
EEPROM_SIZE=2048
TEXT_MEMORY=text
DATA_MEMORY=data
EEPROM_MEMORY=eeprom
ARCH=s12z
EMBEDDED=yes
GENERIC_BOARD=no
TEMPLATE_NAME=generic
EXTRA_EM_FILE=genelf
NOP=0x00

