               movw   sp, #0x1234
               movw   ax, sp
               movw   sp, ax
               movw   ax, !0xffff8
               movw   !0xffff8, ax
               movw   hl, sp
               movw   bc, sp
               movw   de, sp
  