.text
foo:
	lpdfr	%f6,%f2
	lndfr	%f6,%f2
	cpsdr	%f6,%f1,%f2
	lcdfr	%f6,%f2
	ldgr	%f6,%r2
	lgdr	%r2,%f6
	adtr	%f6,%f2,%f4
	axtr	%f8,%f9,%f4
	cdtr	%f6,%f2
	cxtr	%f1,%f0
	kdtr	%f6,%f2
	kxtr	%f6,%f2
	cedtr	%f6,%f2
	cextr	%f1,%f0
	cdgtr	%f6,%r2
	cxgtr	%f1,%r2
	cdstr	%f6,%r2
	cxstr	%f6,%r2
	cdutr	%f6,%r2
	cxutr	%f1,%r2
	cgdtr	%r2,1,%f6
	cgxtr	%r2,1,%f1
	csdtr	%r6,%f3,13
	csxtr	%r6,%f1,13
	cudtr	%r2,%f6
	cuxtr	%r2,%f1
	ddtr	%f6,%f2,%f4
	dxtr	%f1,%f0,%f4
	eedtr	%r2,%f6
	eextr	%r2,%f1
	esdtr	%r2,%f6
	esxtr	%r2,%f1
	iedtr	%f6,%f2,%r4
	iextr	%f1,%f0,%r4
	ltdtr	%f6,%f2
	ltxtr	%f5,%f4
	fidtr	%f6,1,%f2,3
	fixtr	%f5,1,%f4,3
	lfas	3(%r1)
	ldetr	%f6,%f2,1
	lxdtr	%f4,%f2,1
	ledtr	%f6,1,%f2,3
	ldxtr	%f6,1,%f4,3
	mdtr	%f6,%f2,%f4
	mxtr	%f9,%f8,%f4
	qadtr	%f6,%f2,%f4,1
	qaxtr	%f9,%f8,%f4,1
	rrdtr	%f6,%f2,%r4,1
	rrxtr	%f9,%f8,%r4,1
	srnmt	3(%r1)
	sfasr	%r2
	sldt	%f6,%f2,3(%r1,%r4)
	slxt	%f5,%f4,3(%r1,%r4)
	srdt	%f6,%f2,3(%r1,%r4)
	srxt	%f5,%f4,3(%r1,%r4)
	sdtr	%f6,%f2,%f4
	sxtr	%f5,%f1,%f4
	tdcet	%f6,3(%r1,%r2)
	tdcdt	%f6,3(%r1,%r2)
	tdcxt	%f5,3(%r1,%r2)
	tdget	%f6,3(%r1,%r2)
	tdgdt	%f6,3(%r1,%r2)
	tdgxt	%f5,3(%r1,%r2)
	pfpo
	ectg	10(%r1),20(%r2),%r3
	csst	10(%r1),20(%r2),%r3
	/* The following .data section is 4 byte aligned.
	   So we get 2 additional bytes of 07 07 wherefor
	   we have to provide an instruction.  */
	bcr	0,%r7
