#objdump: -d
#name:    
#source:  cmp-opr-reg.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	f0 b8       	cmp d2, d2
   2:	f1 b9       	cmp d3, d3
   4:	f2 ba       	cmp d4, d4
   6:	f3 bb       	cmp d5, d5
   8:	f4 bc       	cmp d0, d0
   a:	f5 bd       	cmp d1, d1
   c:	f6 be       	cmp d6, d6
   e:	f7 bf       	cmp d7, d7
