[^:]*: Assembler messages:
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:19: Error: syntax error -- `vandeq q0,q1,q2'
[^:]*:20: Error: syntax error -- `vandeq q0,q1,q2'
[^:]*:22: Error: syntax error -- `vandeq q0,q1,q2'
[^:]*:24: Error: instruction missing MVE vector predication code -- `vand q0,q1,q2'
[^:]*:25: Error: vector predicated instruction should be in VPT/VPST block -- `vandt q0,q1,q2'
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Error: syntax error -- `vandeq.i16 q0,#255'
[^:]*:29: Error: syntax error -- `vandeq.i16 q0,#255'
[^:]*:31: Error: syntax error -- `vandeq.i16 q0,#255'
[^:]*:33: Error: instruction missing MVE vector predication code -- `vand.i16 q0,#255'
[^:]*:34: Error: vector predicated instruction should be in VPT/VPST block -- `vandt.i16 q0,#255'
[^:]*:35: Error: bad type in SIMD instruction -- `vand.i8 q0,#255'
[^:]*:36: Error: bad type in SIMD instruction -- `vand.i64 q0,#255'
[^:]*:37: Error: immediate value out of range -- `vand.i16 q0,#0'
[^:]*:38: Error: immediate value out of range -- `vand.i32 q0,#0'
