
Unwind section '\.ARM\.exidx' at offset .* contains 4 entries:

0x8004 <_start>: @0x8010
  Compact model index: 1
  0xc9 0x40 pop {D4}
  0xc9 0x00 pop {D0}
  0xa8      pop {r4, r14}
  0xb0      finish

0x8008 <__aeabi_unwind_cpp_pr1>: 0x1 \[cantunwind\]

0x800c <end>: 0x80a8b0b0
  Compact model index: 0
  0xa8      pop {r4, r14}
  0xb0      finish
  0xb0      finish

0x8010 <end\+0x4>: 0x1 \[cantunwind\]

