[^:]*: Assembler messages:
[^:]*:5: Error: parallel instruction not following another instruction
[^:]*:8: Error: parallel instruction not following another instruction
[^:]*:11: Error: label not at start of execute packet
