.*: Assembler messages:
.*: Error: invalid operands `vabs\.w \$vf0w,\$vf0z'
.*: Error: invalid operands `vabs\.w \$vf0z,\$vf31w'
.*: Error: invalid operands `vabs\.xw \$vf0xw,\$vf0w'
.*: Error: invalid operands `vabs\.xw \$vf0x,\$vf31xw'
.*: Error: invalid operands `vabs\.xyzw \$vf0xyz,\$vf0xyzw'
.*: Error: invalid operands `vaddai\.w \$ACCw,\$vf0w,\$Q'
.*: Error: invalid operands `vaddai\.w \$ACCz,\$vf0w,\$Q'
.*: Error: invalid operands `vaddai\.xyzw \$ACCxyw,\$vf0xyzw,\$I'
.*: Error: invalid operands `vaddaq\.w \$ACCw,\$vf31z,\$Q'
.*: Error: invalid operands `vaddaq\.x \$ACCx,\$vf0w,\$Q'
.*: Error: invalid operands `vaddaq\.x \$ACCw,\$vf1x,\$Q'
.*: Error: invalid operands `vaddaq\.xw \$ACCxw,\$vf1z,\$Q'
.*: Error: invalid operands `vaddaq\.xw \$ACCw,\$vf31xw,\$Q'
.*: Error: invalid operands `vaddaq\.xyw \$ACCxw,\$vf0xyw,\$Q'
.*: Error: invalid operands `vaddaq\.xyw \$ACCxyw,\$vf1yw,\$Q'
.*: Error: invalid operands `vaddaq\.xyzw \$ACCxyzw,\$vf1yzw,\$Q'
.*: Error: invalid operands `vaddaq\.z \$ACCxz,\$vf0xz,\$Q'
.*: Error: invalid operands `vaddaq\.x \$ACCxz,\$vf1xz,\$Q'
.*: Error: invalid operands `vaddaq\.xzw \$ACCxw,\$vf0xzw,\$Q'
.*: Error: invalid operands `vaddaq\.y \$ACCy,\$vf0y,\$R'
.*: Error: invalid operands `vaddaq\.y \$ACCy,\$vf1y,\$I'
.*: Error: invalid operands `vaddaq\.yw \$ACCxyw,\$vf0yw,\$Q'
.*: Error: invalid operands `vaddaq\.yw \$ACCwy,\$vf1yw,\$Q'
.*: Error: invalid operands `vaddaq\.yw \$ACCyw,\$vf31wy,\$Q'
.*: Error: invalid operands `vaddaq\.yz \$ACCy,\$vf0yz,\$Q'
.*: Error: invalid operands `vaddaq\.yzw \$ACCxyzw,\$vf0yzw,\$Q'
.*: Error: invalid operands `vaddaq\.yzw \$ACCyzw,\$vf1xyzw,\$Q'
.*: Error: invalid operands `vaddaq\.yzw \$ACCyzw,\$vf31yzw,\$Qyzw'
.*: Error: invalid operands `vadda\.w \$ACCw,\$vf1w,\$vf2z'
.*: Error: invalid operands `vadda\.w \$ACCw,\$vf31w,\$vf0x'
.*: Error: invalid operands `vaddaw\.xyzw \$ACCxyzw,\$vf0xyzw,\$vf0x'
.*: Error: invalid operands `vaddaw\.xyzw \$ACCxyzw,\$vf0xyzw,\$vf31xyzw'
.*: Error: invalid operands `vaddaw\.xz \$ACCxyz,\$vf0xz,\$vf0w'
.*: Error: invalid operands `vaddaw\.xz \$ACCxzw,\$vf0xz,\$vf31w'
.*: Error: invalid operands `vaddaw\.xz \$ACCxz,\$vf1xyz,\$vf2w'
.*: Error: invalid operands `vaddaw\.xz \$ACCxz,\$vf31xzw,\$vf0w'
.*: Error: invalid operands `vaddaw\.xz \$ACCxz,\$vf31z,\$vf15w'
.*: Error: invalid operands `vaddaw\.xzw \$ACCxyzw,\$vf0xzw,\$vf0w'
.*: Error: invalid operands `vaddaw\.xzw \$ACC,\$vf0,\$vf31z'
.*: Error: invalid operands `vaddaw\.xzw \$ACCxzw,\$vf1xzw,\$vf2z'
.*: Error: invalid operands `vaddaw\.xzw \$ACCxzw,\$vf31xzw,\$vf0x'
.*: Error: invalid operands `vaddaw\.y \$ACCy,\$vf0y,\$vf0z'
.*: Error: invalid operands `vaddax\.w \$ACCw,\$vf0w,\$vf31z'
.*: Error: invalid operands `vaddax\.w \$ACC,\$vf1,\$vf2z'
.*: Error: invalid operands `vaddax\.w \$ACCw,\$vf31w,\$vf0w'
.*: Error: invalid operands `vaddax\.w \$ACCw,\$vf31w,\$vf15y'
.*: Error: invalid operands `vadda\.xw \$ACCxw,\$vf0xw,\$vf0xyw'
.*: Error: invalid operands `vadda\.xw \$ACCxw,\$vf0xw,\$vf31wx'
.*: Error: invalid operands `vaddax\.x \$ACCw,\$vf0x,\$vf0x'
.*: Error: invalid operands `vaddax\.x \$ACCx,\$vf0x,\$vf31w'
.*: Error: invalid operands `vaddax\.x \$ACCx,\$vf1x,\$vf2y'
.*: Error: invalid operands `vaddax\.x \$ACCx,\$vf31x,\$vf0z'
.*: Error: invalid operands `vaddax\.xw \$ACCxw,\$vf0xw,\$vf0y'
.*: Error: invalid operands `vaddax\.xw \$ACCxw,\$vf0xw,\$vf31z'
.*: Error: invalid operands `vaddax\.xw \$ACCxw,\$vf1xw,\$vf2w'
.*: Error: invalid operands `vaddax\.xw \$ACCxw,\$vf31wx,\$vf0'
.*: Error: invalid operands `vaddax\.xyzw \$ACC,\$vf1,\$vf2y'
.*: Error: invalid operands `vaddax\.xyzw \$ACC,\$vf31,\$vf0z'
.*: Error: invalid operands `vadda\.zw \$ACCzw,\$vf0zw,\$vf0wz'
.*: Error: invalid operands `vadda\.zw \$ACCzw,\$vf0w,\$vf31zw'
.*: Error: invalid operands `vadda\.zw \$ACCw,\$vf1zw,\$vf2zw'
.*: Error: invalid operands `vadda\.zw \$ACCxzw,\$vf31zw,\$vf0zw'
.*: Error: invalid operands `vadda\.zw \$ACCzw,\$vf31xzw,\$vf15zw'
.*: Error: invalid operands `vadda\.zw \$ACCzw,\$vf31zw,\$vf31yzw'
.*: Error: invalid operands `vaddaz\.x \$ACCx,\$vf0x,\$vf0x'
.*: Error: invalid operands `vaddaz\.x \$ACCx,\$vf0x,\$vf31y'
.*: Error: invalid operands `vaddaz\.xw \$ACCxw,\$vf31w,\$vf15z'
.*: Error: invalid operands `vaddaz\.xw \$ACCx,\$vf31xw,\$vf31z'
.*: Error: invalid operands `vaddaz\.xy \$ACCx,\$vf0xy,\$vf0z'
.*: Error: invalid operands `vaddaz\.xy \$ACCxyz,\$vf0xy,\$vf31z'
.*: Error: invalid operands `vaddaz\.y \$ACCx,\$vf31y,\$vf0z'
.*: Error: invalid operands `vaddaz\.yw \$ACCyw,\$vf0yw,\$a0'
.*: Error: invalid operands `vaddi\.w \$vf0w,\$vf31w,\$Q'
.*: Error: invalid operands `vaddi\.w \$vf1w,\$vf2w,\$R'
.*: Error: invalid operands `vaddi\.w \$vf31w,\$vf0w,\$ACC'
.*: Error: invalid operands `vaddi\.w \$vf31w,\$vf15w,\$ACCw'
.*: Error: invalid operands `vaddi\.xzw \$vf1xyzw,\$vf2xzw,\$I'
.*: Error: invalid operands `vaddi\.xzw \$vf31xw,\$vf0xzw,\$I'
.*: Error: invalid operands `vaddi\.xzw \$vf31xzw,\$vf15xzw,\$Ixzw'
.*: Error: invalid operands `vaddq\.w \$vf1w,\$vf2w,\$Qw'
.*: Error: invalid operands `vaddq\.w \$vf31w,\$vf0w,\$R'
.*: Error: invalid operands `vaddq\.w \$vf31w,\$vf15w,\$ACCw'
.*: Error: invalid operands `vaddq\.w \$vf31w,\$vf31w,\$ACC'
.*: Error: invalid operands `vaddq\.xyzw \$vf31xyzw,\$vf32xyzw,\$Q'
.*: Error: invalid operands `vaddq\.xyzw \$vf31xyzw,\$32,\$Q'
.*: Error: invalid operands `vaddq\.xz \$vf0xz,\$\-1,\$Q'
.*: Error: invalid operands `vaddw\.xyzw \$vf31xyzw,\$vf15xyzw,\$vf7z'
.*: Error: invalid operands `vaddx\.yw \$vf31yw,\$vf31yw,\$vf31y'
.*: Error: invalid operands `vadd\.xyz \$vf0xyz,\$vf0xyz,\$vf0xz'
.*: Error: invalid operands `vadd\.xyz \$vf0xyz,\$vf0xyz,\$vf31xyzw'
.*: Error: invalid operands `vadd\.xyz \$vf0xyz,\$vf31xyzw,\$vf0xyz'
.*: Error: invalid operands `vaddx\.yz \$vf0yz,\$vf0xyz,\$vf0x'
.*: Error: invalid operands `vaddz\.xyzw \$vf31xyzw,\$vf0xyzw,\$vf0x'
.*: Error: invalid operands `vaddz\.xyzw \$vf31xyzw,\$vf15xyzw,\$vf7y'
.*: Error: invalid operands `vaddz\.xyzw \$vf31xyzw,\$vf31xyzw,\$vf31w'
.*: Error: operand 1 out of range `vcallms -1'
.*: Error: operand 1 out of range `vcallms -0x0080'
.*: Error: operand 1 out of range `vcallms 0x1'
.*: Error: operand 1 out of range `vcallms 0x7'
.*: Error: operand 1 out of range `vcallms 0x4'
.*: Error: operand 1 out of range `vcallms 0x2'
.*: Error: operand 1 out of range `vcallms 0x40000'
.*: Error: operand 1 out of range `vcallms 0x40008'
.*: Error: invalid operands `vclipw\.xyz \$vf0xyz,\$vf0x'
.*: Error: invalid operands `vclipw\.xyz \$vf0xyz,\$vf31y'
.*: Error: invalid operands `vclipw\.xyz \$vf1xyz,\$vf2z'
.*: Error: invalid operands `vdiv \$Q,\$vf0x,\$vf0xy'
.*: Error: invalid operands `vdiv \$Q,\$vf0xyzw,\$vf31y'
.*: Error: invalid operands `vdiv \$Q,\$vf1,\$vf2z'
.*: Error: invalid operands `vdiv \$Q,\$vf31x,\$vf15'
.*: Error: invalid operands `vdiv \$0,\$vf31w,\$vf31y'
.*: Error: invalid operands `vdiv \$Q,\$vf32y,\$vf0w'
.*: Error: invalid operands `vftoi0\.w \$vf0w,\$vf0x'
.*: Error: invalid operands `vftoi0\.w \$vf0x,\$vf31w'
.*: Error: invalid operands `vftoi0\.w \$vf1xw,\$vf2w'
.*: Error: invalid operands `vftoi0\.w \$vf31wx,\$vf0w'
.*: Error: invalid operands `vftoi0\.w \$vf31w,\$vf15wz'
.*: Error: invalid operands `vftoi12\.xw \$vf0xw,\$vf0w'
.*: Error: invalid operands `vftoi12\.xw \$vf0x,\$vf31xw'
.*: Error: invalid operands `vftoi15\.xyz \$vf31xyzw,\$vf15xyz'
.*: Error: invalid operands `vftoi15\.xyz \$vf31xyz,\$vf31xyzw'
.*: Error: invalid operands `vftoi15\.xyzw \$vf0xyzw,\$vf0xyz'
.*: Error: invalid operands `vftoi15\.y \$vf1y,\$vf2x'
.*: Error: invalid operands `vftoi15\.y \$vf31y,\$vf0w'
.*: Error: operand 3 out of range `viaddi \$vi0,\$vi0,-17'
.*: Error: operand 3 out of range `viaddi \$vi1,\$vi2,16'
.*: Error: operand 3 out of range `viaddi \$vi31,\$vi0,17'
.*: Error: operand 3 out of range `viaddi \$vi31,\$vi15,32'
.*: Error: operand 3 out of range `viaddi \$vi31,\$vi31,31'
.*: Error: invalid operands `viand \$vi0xyzw,\$vi0,\$vi0'
.*: Error: invalid operands `viand \$vi0,\$vi0xyzw,\$vi31'
.*: Error: invalid operands `viand \$vi0,\$vi31,\$vi0xyzw'
.*: Error: invalid operands `viand \$vi1,\$vi2,\$vi3x'
.*: Error: invalid operands `viand \$vi31,\$vi0y,\$vi0'
.*: Error: invalid operands `viand \$vi31w,\$vi15,\$vi7'
.*: Error: invalid operands `viand \$vi31,\$vi31,\$vi31x'
.*: Error: invalid operands `vilwr\.w \$vi0,\(\$vi0x\)'
.*: Error: invalid operands `vilwr\.w \$vi0,\(\$vi31y\)'
.*: Error: invalid operands `vilwr\.w \$vi1,\(\$vi2z\)'
.*: Error: invalid operands `vilwr\.w \$vi31,\(\$vi0w\)'
.*: Error: invalid operands `vilwr\.w \$vi31,\(\$vi15xyzw\)'
.*: Error: invalid operands `vilwr\.w \$vi31x,\(\$vi31\)'
.*: Error: invalid operands `vilwr\.x \$vi0y,\(\$vi0\)'
.*: Error: invalid operands `vilwr\.x \$vi0z,\(\$vi31\)'
.*: Error: invalid operands `vilwr\.x \$vi1w,\(\$vi2\)'
.*: Error: invalid operands `vilwr\.x \$vi31xyzw,\(\$vi0\)'
.*: Error: invalid operands `vilwr\.x \$vi31xy,\(\$vi15\)'
.*: Error: invalid operands `vilwr\.x \$vi31zw,\(\$vi31\)'
.*: Error: invalid operands `vilwr\.y \$vi0wx,\(\$vi0\)'
.*: Error: invalid operands `vilwr\.y \$vi0xyzw,\(\$vi31\)'
.*: Error: invalid operands `vilwr\.y \$vi1y,\(\$vi2\)'
.*: Error: invalid operands `vilwr\.y \$vi31,\(\$vi0y\)'
.*: Error: invalid operands `vilwr\.z \$vi0z,\(\$vi0\)'
.*: Error: invalid operands `vilwr\.z \$vi0,\(\$vi31z\)'
.*: Error: invalid operands `vior \$vi0x,\$vi0,\$vi0'
.*: Error: invalid operands `vior \$vi0,\$vi0x,\$vi31'
.*: Error: invalid operands `vior \$vi0,\$vi31,\$vi0x'
.*: Error: invalid operands `vior \$vi1y,\$vi2,\$vi3'
.*: Error: invalid operands `vior \$vi31,\$vi0y,\$vi0'
.*: Error: invalid operands `vior \$vi31,\$vi15,\$vi7y'
.*: Error: invalid operands `vior \$vi31xyzw,\$vi31,\$vi31'
.*: Error: invalid operands `visub \$vi0x,\$vi0,\$vi0'
.*: Error: invalid operands `visub \$vi0,\$vi0y,\$vi31'
.*: Error: invalid operands `visub \$vi0,\$vi31,\$vi0z'
.*: Error: invalid operands `visub \$vi1w,\$vi2,\$vi3'
.*: Error: invalid operands `visub \$vi31,\$vi0xy,\$vi0'
.*: Error: invalid operands `visub \$vi31,\$vi15,\$vi7zw'
.*: Error: invalid operands `visub \$vi31,\$vi31,\$vi31w'
.*: Error: invalid operands `viswr\.w \$vi0,\(\$vi0w\)'
.*: Error: invalid operands `viswr\.w \$vi0w,\(\$vi31\)'
.*: Error: invalid operands `viswr\.x \$vi0x,\(\$vi31\)'
.*: Error: invalid operands `viswr\.x \$vi1,\(\$vi2x\)'
.*: Error: invalid operands `viswr\.x \$vi31x,\(\$vi0x\)'
.*: Error: invalid operands `viswr\.y \$vi31y,\(\$vi15\)'
.*: Error: invalid operands `viswr\.y \$vi31,\(\$vi31y\)'
.*: Error: invalid operands `viswr\.z \$vi0,\(\$vi0z\)'
.*: Error: invalid operands `viswr\.z \$vi0z,\(\$vi31\)'
.*: Error: invalid operands `viswr\.z \$vi1z,\(\$vi2z\)'
.*: Error: invalid operands `vitof0\.w \$vf1w,\$vf2x'
.*: Error: invalid operands `vitof0\.w \$vf31z,\$vf0w'
.*: Error: invalid operands `vitof0\.xw \$vf0xw,\$vf0xyw'
.*: Error: invalid operands `vitof0\.xw \$vf0xw,\$vf31w'
.*: Error: invalid operands `vitof12\.xw \$vf31xw,\$vf0x'
.*: Error: invalid operands `vitof12\.xzw \$vf0xzw,\$vf31xz'
.*: Error: invalid operands `vitof12\.xzw \$vf1xzw,\$vf2xw'
.*: Error: invalid operands `vitof12\.xzw \$vf31xzw,\$vf0xyzw'
.*: Error: invalid operands `vitof12\.xzw \$vf31xyzw,\$vf15xzw'
.*: Error: invalid operands `vitof12\.xzw \$vf31xw,\$vf31xzw'
.*: Error: invalid operands `vitof12\.y \$vf0y,\$vf0w'
.*: Error: invalid operands `vitof12\.y \$vf0x,\$vf31y'
.*: Error: invalid operands `vitof15\.xyw \$vf0xyw,\$vf31xw'
.*: Error: invalid operands `vitof15\.xyw \$vf1xyw,\$vf2yxw'
.*: Error: invalid operands `vitof15\.xyw \$vf31xwy,\$vf15xyw'
.*: Error: invalid operands `vitof15\.xyzw \$vf1\.xyzw,\$vf2xyzw'
.*: Error: invalid operands `vitof15\.xyzw \$vf31xyzw,\$vf0\.xyzw'
.*: Error: invalid operands `vitof4\.xw \$vf31xw,\$31xw'
.*: Error: invalid operands `vitof4\.xy \$0xy,\$vf0xy'
.*: Error: invalid operands `vitof4\.xyzw \$vf0yzw,\$vf0xyzw'
.*: Error: invalid operands `vitof4\.yzw \$vf1yzw,\$vf2yw'
.*: Error: invalid operands `vlqd\.w \$vf0,\(\-\-\$vi0w\)'
.*: Error: invalid operands `vlqd\.w \$vf0,\(\-\-\$vi31w\)'
.*: Error: invalid operands `vlqd\.w \$vf0x,\(\-\-\$vi0\)'
.*: Error: invalid operands `vlqd\.x \$vf0w,\(\-\-\$vi0x\)'
.*: Error: invalid operands `vlqd\.x \$vf0x,\(\-\-\$vi31x\)'
.*: Error: invalid operands `vlqd\.x \$vf0w,\(\-\-\$vi0\)'
.*: Error: invalid operands `vlqd\.xw \$vf0,\(\-\-\$vi0xw\)'
.*: Error: invalid operands `vlqd\.xy \$vf0,\(\-\-\$vi0xy\)'
.*: Error: invalid operands `vlqd\.xyw \$vf0,\(\-\-\$vi0xyw\)'
.*: Error: invalid operands `vlqd\.xyz \$vf0,\(\-\-\$vi0xyz\)'
.*: Error: invalid operands `vlqd\.xyzw \$vf0,\(\-\-\$vi0xyzw\)'
.*: Error: invalid operands `vlqd\.xz \$vf0,\(\-\-\$vi0xz\)'
.*: Error: invalid operands `vlqd\.xzw \$vf0,\(\-\-\$vi0xzw\)'
.*: Error: invalid operands `vlqd\.y \$vf0,\(\-\-\$vi0y\)'
.*: Error: invalid operands `vlqd\.yw \$vf0,\(\-\-\$vi0yw\)'
.*: Error: invalid operands `vlqd\.yz \$vf0,\(\-\-\$vi0yz\)'
.*: Error: invalid operands `vlqd\.yzw \$vf0,\(\-\-\$vi0yzw\)'
.*: Error: invalid operands `vlqd\.z \$vf0,\(\-\-\$vi0z\)'
.*: Error: invalid operands `vlqd\.zw \$vf0,\(\-\-\$vi0zw\)'
.*: Error: invalid operands `vlqi\.w \$vf0,\(\$vi0w\+\+\)'
.*: Error: invalid operands `vlqi\.x \$vf31,\(\$vi15x\+\+\)'
.*: Error: invalid operands `vlqi\.xw \$vf0x,\(\$vi0\+\+\)'
.*: Error: invalid operands `vlqi\.xw \$vf0,\(\$vi31xw\+\+\)'
.*: Error: invalid operands `vlqi\.xy \$vf0,\(\$vi0xy\+\+\)'
.*: Error: bad expression
.*: Error: missing '\)'
.*: Error: invalid operands `vlqi\.xy \$vf1,\(\$2xy\+\+\)'
.*: Error: invalid operands `vlqi\.xyw \$vf0,\(\$vi0xyw\+\+\)'
.*: Error: invalid operands `vlqi\.xyz \$vf0,\(\$vi0xyz\+\+\)'
.*: Error: invalid operands `vlqi\.xyzw \$vf0,\(\$vi0xyzw\+\+\)'
.*: Error: invalid operands `vlqi\.xz \$vf0,\(\$vi0xz\+\+\)'
.*: Error: invalid operands `vlqi\.xzw \$vf0,\(\$vi0xzw\+\+\)'
.*: Error: invalid operands `vlqi\.y \$vf0,\(\$vi0y\+\+\)'
.*: Error: invalid operands `vlqi\.yw \$vf0,\(\$vi0yw\+\+\)'
.*: Error: invalid operands `vlqi\.yz \$vf0yz,\(\$vi0yz\+\+\)'
.*: Error: invalid operands `vlqi\.yzw \$vf0,\(\$vi0yzw\+\+\)'
.*: Error: invalid operands `vlqi\.z \$vf0,\(\$vi0z\+\+\)'
.*: Error: invalid operands `vlqi\.zw \$vf0,\(\$vi0zw\+\+\)'
.*: Error: invalid operands `vmaddai\.w \$ACCw,\$vf0w,\$R'
.*: Error: invalid operands `vmaddai\.w \$ACCw,\$vf1w,\$Iw'
.*: Error: invalid operands `vmaddai\.w \$ACCw,\$vf31w,\$Q'
.*: Error: invalid operands `vmaddai\.x \$ACCx,\$vf0x,\$ACC'
.*: Error: invalid operands `vmaddai\.x \$ACCy,\$vf1w,\$I'
.*: Error: invalid operands `vmaddai\.x \$ACCxy,\$vf31x,\$I'
.*: Error: invalid operands `vmaddai\.xw \$ACCxw,\$vf0xyw,\$I'
.*: Error: invalid operands `vmaddai\.xy \$ACCxy,\$vf0xyw,\$I'
.*: Error: invalid operands `vmaddai\.xy \$ACCxy,\$vf1xyz,\$I'
.*: Error: invalid operands `vmaddai\.xy \$ACCxyz,\$vf31xy,\$I'
.*: Error: invalid operands `vmaddai\.xyw \$ACCxy,\$vf0xyw,\$I'
.*: Error: invalid operands `vmaddai\.yw \$ACCyw,\$vf1w,\$I'
.*: Error: invalid operands `vmaddai\.yw \$ACCyw,\$vf31y,\$I'
.*: Error: invalid operands `vmaddai\.yz \$ACCyz,\$vf0yz,\$R'
.*: Error: invalid operands `vmaddaq\.xyz \$ACCxyz,\$vf0xyz,\$R'
.*: Error: invalid operands `vmaddaq\.xyz \$ACCxyz,\$vf1xyz,\$Qxyz'
.*: Error: invalid operands `vmaddaq\.xzw \$ACCxzw,\$vf31xzw,\$Qxzw'
.*: Error: invalid operands `vmaddaq\.y \$ACCy,\$vf0y,\$R'
.*: Error: invalid operands `vmaddaq\.y \$ACCy,\$vf1y,\$ACCy'
.*: Error: invalid operands `vmaddaq\.y \$ACCy,\$vf31y,\$ACC'
.*: Error: invalid operands `vmaddaw\.z \$ACCz,\$vf31z,\$vf0x'
.*: Error: invalid operands `vmaddaw\.zw \$ACCzw,\$vf31zw,\$vf15y'
.*: Error: invalid operands `vmaddax\.w \$ACCw,\$vf1w,\$vf2w'
.*: Error: invalid operands `vmadda\.xw \$ACCxw,\$vf31xw,\$vf31wx'
.*: Error: invalid operands `vmaddax\.xyz \$ACCxyz,\$vf0xyz,\$vf0xyz'
.*: Error: invalid operands `vmaddax\.xyzw \$ACCxyzw,\$vf0xyzw,\$vf0xyzw'
.*: Error: invalid operands `vmaddax\.xz \$ACCxz,\$vf0xz,\$vf31xz'
.*: Error: invalid operands `vmaddax\.xzw \$ACCxzw,\$vf0xzw,\$vf0xzw'
.*: Error: invalid operands `vmaddax\.z \$ACCz,\$vf31z,\$vf15z'
.*: Error: invalid operands `vmaddax\.zw \$ACCzw,\$vf1zw,\$vf2zw'
.*: Error: invalid operands `vmadday\.w \$ACCw,\$vf1w,\$vf2w'
.*: Error: invalid operands `vmadday\.w \$ACCw,\$vf31y,\$vf0y'
.*: Error: invalid operands `vmadday\.w \$ACCy,\$vf31w,\$vf15y'
.*: Error: invalid operands `vmadday\.w \$ACCy,\$vf31y,\$vf31y'
.*: Error: invalid operands `vmadday\.xyzw \$ACCxyzw,\$vf0xyzw,\$vf0xyzw'
.*: Error: invalid operands `vmadday\.xyzw \$ACCxyzw,\$vf0y,\$vf31y'
.*: Error: invalid operands `vmadday\.xyzw \$ACCy,\$vf1xyzw,\$vf2y'
.*: Error: invalid operands `vmadday\.xyzw \$ACCy,\$vf31y,\$vf0y'
.*: Error: invalid operands `vmaddi\.x \$vf0x,\$vf31x,\$Ix'
.*: Error: invalid operands `vmaddi\.xw \$vf1xw,\$vf2xw,\$Ixw'
.*: Error: invalid operands `vmaddi\.xy \$vf31xy,\$vf0xy,\$Ixy'
.*: Error: invalid operands `vmaddi\.xyw \$vf0xyw,\$vf0xyw,\$Ixyw'
.*: Error: invalid operands `vmaddi\.xyzw \$vf1xyzw,\$vf2xyzw,\$Ixyzw'
.*: Error: invalid operands `vmaddi\.y \$vf0y,\$vf0y,\$Iy'
.*: Error: invalid operands `vmaddi\.yw \$vf0yw,\$vf0yw,\$Iyw'
.*: Error: invalid operands `vmaddi\.zw \$vf0zw,\$vf31zw,\$0'
.*: Error: invalid operands `vmaddq\.w \$vf0w,\$vf0w,\$0'
.*: Error: invalid operands `vmadd\.w \$vf0w,\$vf0w,\$vf0y'
.*: Error: invalid operands `vmaddw\.xyz \$vf31xyz,\$vf15xyz'
.*: Error: invalid operands `vmaddw\.xyzw \$vf0xyzw,\$vf31xyzw,\$vf0xyzw'
.*: Error: invalid operands `vmaddx\.yw \$vf1yw,\$vf2yw,\$vf3yw'
.*: Error: invalid operands `vmaddy\.xy \$vf31xy,\$vf15xy,\$vf7xy'
.*: Error: invalid operands `vmadd\.z \$vf1z,\$vf2z,\$vf3x'
.*: Error: invalid operands `vmadd\.z \$vf31z,\$vf0z,\$vf0w'
.*: Error: invalid operands `vmaddz\.xyw \$vf0xyw,\$vf0xyw,\$vf31x'
.*: Error: invalid operands `vmaddz\.xz \$vf0xz,\$vf31xz,\$vf0xz'
.*: Error: invalid operands `vmaddz\.y \$vf31y,\$vf0y,\$vf0y'
.*: Error: invalid operands `vmaxi\.w \$vf31w,\$vf15w,\$Q'
.*: Error: invalid operands `vmaxi\.w \$vf31w,\$vf31w,\$0'
.*: Error: invalid operands `vmax\.w \$vf31w,\$vf31w,\$vf31x'
.*: Error: invalid operands `vmaxw\.w \$vf0w,\$vf0w,\$vf0x'
.*: Error: invalid operands `vmaxw\.x \$vf0x,\$vf0x,\$vf0x'
.*: Error: invalid operands `vmaxw\.x \$vf0w,\$vf0w,\$vf31w'
.*: Error: invalid operands `vmaxw\.xw \$vf0xw,\$vf0xw,\$vf0xw'
.*: Error: invalid operands `vmaxw\.xw \$vf0w,\$vf0w,\$vf31w'
.*: Error: invalid operands `vmaxw\.xy \$vf0xy,\$vf31xy,\$vf0xy'
.*: Error: invalid operands `vmaxw\.xy \$vf1xy,\$vf2w,\$vf3w'
.*: Error: invalid operands `vmaxw\.xy \$vf31w,\$vf0xy,\$vf0w'
.*: Error: invalid operands `vmax\.x \$vf0x,\$vf0x,\$vf31w'
.*: Error: invalid operands `vmaxx\.w \$vf0w,\$vf0w,\$vf31w'
.*: Error: invalid operands `vmaxx\.w \$vf0x,\$vf31x,\$vf0x'
.*: Error: invalid operands `vmaxx\.w \$vf31w,\$vf0w,\$vf0w'
.*: Error: invalid operands `vmaxx\.w \$vf31x,\$vf15x,\$vf7x'
.*: Error: invalid operands `vmax\.xw \$vf31xw,\$vf15xw,\$vf7w'
.*: Error: invalid operands `vmaxx\.x \$vf0x,\$vf0x,\$vf0w'
.*: Error: invalid operands `vmaxx\.x \$vf31w,\$vf15x,\$vf7x'
.*: Error: invalid operands `vmaxx\.x \$vf31x,\$vf31w,\$vf31x'
.*: Error: invalid operands `vmaxx\.xw \$vf31xw,\$vf15xw,\$vf7xw'
.*: Error: invalid operands `vmaxx\.xy \$vf0xy,\$vf31xy,\$vf0xy'
.*: Error: invalid operands `vmaxx\.xyw \$vf0xyw,\$vf0xyw,\$vf0xyw'
.*: Error: invalid operands `vmaxx\.xyz \$vf0xyz,\$vf0xyz,\$vf0xyz'
.*: Error: invalid operands `vmaxx\.xyzw \$vf0xyzw,\$vf0xyzw,\$vf0xyzw'
.*: Error: invalid operands `vmaxx\.xyzw \$vf0xyzw,\$vf0x,\$vf31x'
.*: Error: invalid operands `vmaxx\.xyzw \$vf0x,\$vf31xyzw,\$vf0x'
.*: Error: invalid operands `vmaxx\.xyzw \$vf1x,\$vf2x,\$vf3x'
.*: Error: invalid operands `vmaxx\.xzw \$vf31xzw,\$vf15xzw,\$vf7xzw'
.*: Error: invalid operands `vmaxx\.y \$vf0y,\$vf0y,\$vf0y'
.*: Error: invalid operands `vmaxx\.y \$vf0y,\$vf0x,\$vf31x'
.*: Error: invalid operands `vmaxx\.y \$vf0x,\$vf31y,\$vf0x'
.*: Error: invalid operands `vmaxx\.yw \$vf1yw,\$vf2yw,\$vf3yw'
.*: Error: invalid operands `vmaxx\.yz \$vf0yz,\$vf0yz,\$vf0yz'
.*: Error: invalid operands `vmaxx\.yz \$vf0x,\$vf0x,\$vf31x'
.*: Error: invalid operands `vmaxx\.z \$vf31z,\$vf0z,\$vf0z'
.*: Error: invalid operands `vmaxx\.z \$vf31z,\$vf15x,\$vf7x'
.*: Error: invalid operands `vmaxx\.z \$vf31x,\$vf31z,\$vf31x'
.*: Error: invalid operands `vmaxx\.zw \$vf1zw,\$vf2zw,\$vf3zw'
.*: Error: invalid operands `vmax\.y \$vf0y,\$vf0y,\$vf31x'
.*: Error: invalid operands `vmax\.yw \$vf0yw,\$vf0yw,\$vf31w'
.*: Error: invalid operands `vmax\.yw \$vf0yw,\$vf31yw,\$vf0y'
.*: Error: invalid operands `vmaxy\.xz \$vf31xz,\$vf15xz,\$vf7xz'
.*: Error: invalid operands `vmaxy\.xzw \$vf1xzw,\$vf2xzw,\$vf3xzw'
.*: Error: invalid operands `vmaxy\.y \$vf1y,\$vf2y'
.*: Error: invalid operands `vmaxy\.yz \$vf0yz,\$vf31yz,\$vf0yz'
.*: Error: invalid operands `vmaxy\.yzw \$vf0yzw,\$vf0yzw,\$vf0yzw'
.*: Error: invalid operands `vmaxy\.yzw \$vf31y,\$vf15y,\$vf7y'
.*: Error: invalid operands `vmaxy\.yzw \$vf31yzw,\$vf31yw,\$vf31y'
.*: Error: invalid operands `vmaxy\.z \$vf0z,\$vf0z,\$vf0z'
.*: Error: invalid operands `vmaxy\.z \$vf0z,\$vf0y,\$vf31y'
.*: Error: invalid operands `vmaxy\.z \$vf0y,\$vf31z,\$vf0y'
.*: Error: invalid operands `vmaxz\.xw \$vf31xw,\$vf31xw,\$vf31xw'
.*: Error: invalid operands `vmaxz\.xy \$vf0xy,\$vf0xy,\$vf0xy'
.*: Error: invalid operands `vmaxz\.xyw \$vf0xyw,\$vf0xyw,\$vf0xyw'
.*: Error: invalid operands `vmaxz\.xyz \$vf1xyz,\$vf2xyz,\$vf3xyz'
.*: Error: invalid operands `vmaxz\.xyz \$vf31xyz,\$vf0z,\$vf0z'
.*: Error: invalid operands `vmaxz\.xyz \$vf31z,\$vf15xyz,\$vf7z'
.*: Error: invalid operands `vmaxz\.xyz \$vf31z,\$vf31z,\$vf31z'
.*: Error: invalid operands `vmaxz\.xyzw \$vf0xyzw,\$vf0xyzw,\$vf0xyzw'
.*: Error: invalid operands `vmaxz\.xyzw \$vf0xyzw,\$vf0z,\$vf31z'
.*: Error: invalid operands `vmaxz\.xyzw \$vf0z,\$vf31z,\$vf0z'
.*: Error: invalid operands `vmaxz\.xyzw \$vf1xyzw,\$vf2xyzw,\$vfz'
.*: Error: invalid operands `vmaxz\.xyzw \$vf31xyzw,\$vf0xyzw,\$vf0xyzw'
.*: Error: invalid operands `vmaxz\.xz \$vf0xz,\$vf0xz,\$vf0xz'
.*: Error: invalid operands `vmaxz\.y \$vf31y,\$vf15z,\$vf7z'
.*: Error: invalid operands `vmaxz\.y \$vf31y,\$vf31y,\$vf31y'
.*: Error: invalid operands `vmaxz\.yw \$vf0yw,\$vf0yw,\$vf0yw'
.*: Error: invalid operands `vmaxz\.yzw \$vf0yzw,\$vf0yzw,\$vf31yzw'
.*: Error: invalid operands `vmaxz\.yzw \$vf0yzw,\$vf31z,\$vf0z'
.*: Error: invalid operands `vmaxz\.yzw \$vf1z,\$vf2yzw,\$vf3z'
.*: Error: invalid operands `vmaxz\.yzw \$vf31z,\$vf0z,\$vf0z'
.*: Error: invalid operands `vmaxz\.z \$vf31z,\$vf31z,\$vf31x'
.*: Error: invalid operands `vmfir\.w \$vf0w,\$vi0w'
.*: Error: invalid operands `vmfir\.w \$vf0,\$vi31w'
.*: Error: invalid operands `vmfir\.x \$vf0x,\$vi0x'
.*: Error: invalid operands `vmfir\.x \$vf0,\$vi31x'
.*: Error: invalid operands `vmfir\.xw \$vf0xw,\$vi31xw'
.*: Error: invalid operands `vmfir\.xy \$vf1xy,\$vi2xy'
.*: Error: invalid operands `vmfir\.xy \$vf31,\$vi0xy'
.*: Error: invalid operands `vmfir\.xyw \$vf0xyw,\$vi31xyw'
.*: Error: invalid operands `vmfir\.xyw \$vf31xyw,\$vi0x'
.*: Error: invalid operands `vmfir\.xyz \$vf0xyz,\$vi0xyz'
.*: Error: invalid operands `vmfir\.xyzw \$vf1xyzw,\$vi2xyzw'
.*: Error: invalid operands `vmfir\.xz \$vf0xz,\$vi31xz'
.*: Error: invalid operands `vmfir\.xzw \$vf0xzw,\$vi31xzw'
.*: Error: invalid operands `vmfir\.y \$vf0y,\$vi0y'
.*: Error: invalid operands `vmfir\.yw \$vf0yw,\$vi0yw'
.*: Error: invalid operands `vmfir\.yz \$vf0yz,\$vi31yz'
.*: Error: invalid operands `vmfir\.yzw \$vf0yzw,\$vi0yzw'
.*: Error: invalid operands `vmfir\.z \$vf0z,\$vi0z'
.*: Error: invalid operands `vmfir\.z \$0z,\$vi31'
.*: Error: invalid operands `vmfir\.zw \$vf0zw,\$vi0zw'
.*: Error: invalid operands `vminii\.w \$vf0w,\$vf0w,\$Iw'
.*: Error: invalid operands `vminii\.w \$vf0w,\$vf31x,\$I'
.*: Error: invalid operands `vminii\.w \$vf1x,\$vf2w,\$I'
.*: Error: invalid operands `vminii\.xw \$vf0xw,\$vf31xw,\$Ixw'
.*: Error: invalid operands `vminii\.xw \$vf1xw,\$vf2w,\$I'
.*: Error: invalid operands `vminii\.xw \$vf31x,\$vf0xw,\$I'
.*: Error: invalid operands `vminii\.xyw \$vf31xw,\$vf0xyw,\$I'
.*: Error: invalid operands `vminii\.xyz \$vf0xy,\$vf0xyz,\$I'
.*: Error: unrecognized opcode `minii\.xz \$vf31z,\$vf15xz,\$I'
.*: Error: invalid operands `vminii\.xz \$vf31xz,\$vf31x,\$I'
.*: Error: invalid operands `vminii\.xzw \$vf0xzw,\$vf0xw,\$I'
.*: Error: invalid operands `vminii\.xzw \$vf0zw,\$vf31xzw,\$I'
.*: Error: invalid operands `vminii\.xzw \$vf1xyzw,\$vf2xzw,\$I'
.*: Error: invalid operands `vminii\.xzw \$vf31xzw,\$vf0xyzw,\$I'
.*: Error: invalid operands `vminii\.yw \$vf31yw,\$vf31yw,\$R'
.*: Error: invalid operands `vminii\.yz \$vf0yz,\$vf0yz,\$Q'
.*: Error: invalid operands `vminii\.yz \$vf0yz,\$vf31yz,\$ACC'
.*: Error: invalid operands `vminii\.yzw \$vf31yzw,\$vf0yzw,\$R'
.*: Error: invalid operands `vminii\.yzw \$vf31yzw,\$vf15yzw,\$ACC'
.*: Error: invalid operands `vminii\.yzw \$vf31yzw,\$vf31yzw,\$Q'
.*: Error: invalid operands `vmini\.w \$vf0w,\$vf0w,\$vf0x'
.*: Error: invalid operands `vminiw\.w \$vf31w,\$vf31w,\$vf31x'
.*: Error: invalid operands `vminiw\.x \$vf0x,\$vf0x,\$vf0x'
.*: Error: invalid operands `vminiw\.x \$vf0x,\$vf0w,\$vf31w'
.*: Error: invalid operands `vminiw\.x \$vf0w,\$vf31x,\$vf0w'
.*: Error: invalid operands `vminiw\.x \$vf1w,\$vf2w,\$vf3w'
.*: Error: invalid operands `vminiw\.xw \$vf0xw,\$vf31xw,\$vf0xw'
.*: Error: invalid operands `vminiw\.xw \$vf1w,\$vf2w,\$vf3w'
.*: Error: invalid operands `vminiw\.xyzw \$vf0xyzw,\$vf0xyzw,\$vf0xyzw'
.*: Error: invalid operands `vminiw\.xyzw \$vf0xyzw,\$vf0xxyzw,\$vf31w'
.*: Error: invalid operands `vminiw\.xyzw \$vf0xyzw,\$vf31xyzw,\$vf0xyzw'
.*: Error: invalid operands `vminiw\.xyzw \$vf1xyzw,\$vf2xyzw,\$vf3ww'
.*: Error: invalid operands `vminiw\.xz \$vf31xz,\$vf0xz,\$vf0xz'
.*: Error: invalid operands `vminiw\.yw \$vf0yw,\$vf0yw,\$vf0yw'
.*: Error: invalid operands `vminiw\.yz \$vf31yz,\$vf0yz,\$vf0yz'
.*: Error: invalid operands `vminiw\.z \$vf31z,\$vf0z,\$vf0z'
.*: Error: invalid operands `vminiw\.z \$vf31z,\$vf15w,\$vf7w'
.*: Error: invalid operands `vminiw\.z \$vf31w,\$vf31z,\$vf31w'
.*: Error: invalid operands `vminix\.xw \$vf0xw,\$vf31xw,\$vf0xw'
.*: Error: invalid operands `vminix\.xyw \$vf0xyw,\$vf0xyw,\$vf0xyw'
.*: Error: invalid operands `vminix\.xyzw \$vf0xyzw,\$vf31xyzw,\$vf0xyzw'
.*: Error: invalid operands `vminix\.yw \$vf31yw,\$vf31yw,\$vf31yw'
.*: Error: invalid operands `vminix\.zw \$vf31zw,\$vf31zw,\$vf31zw'
.*: Error: invalid operands `vmini\.y \$vf0y,\$vf0x,\$vf0y'
.*: Error: invalid operands `vminiy\.w \$vf0w,\$vf31w,\$vf0w'
.*: Error: invalid operands `vminiy\.x \$vf31x,\$vf15x,\$vf7x'
.*: Error: invalid operands `vminiy\.x \$vf31x,\$vf31y,\$vf31y'
.*: Error: invalid operands `vminiy\.xw \$vf0y,\$vf0xw,\$vf0y'
.*: Error: invalid operands `vminiy\.xw \$vf0xw,\$vf0y,\$vf31y'
.*: Error: invalid operands `vminiy\.xw \$vf0xw,\$vf31xw,\$vf0xw'
.*: Error: invalid operands `vminiy\.xyz \$vf31xyz,\$vf31xyz,\$vf31xyz'
.*: Error: invalid operands `vminiy\.xyzw \$vf0xyzw,\$vf0y,\$vf0y'
.*: Error: invalid operands `vminiy\.xyzw \$vf0y,\$vf0xyzw,\$vf31y'
.*: Error: invalid operands `vminiy\.xyzw \$vf0xyzw,\$vf31xyzw,\$vf0xyzw'
.*: Error: invalid operands `vminiy\.yw \$vf1yw,\$vf2yw,\$vf3yw'
.*: Error: invalid operands `vminiy\.zw \$vf1zw,\$vf2zw,\$vf3zw'
.*: Error: invalid operands `vmini\.z \$vf0z,\$vf0z,\$vf0x'
.*: Error: invalid operands `vminiz\.x \$vf0x,\$vf31x,\$vf0x'
.*: Error: invalid operands `vminiz\.xw \$vf0xw,\$vf31xw,\$vf0xw'
.*: Error: invalid operands `vminiz\.xyw \$vf31xyw,\$vf0xyw,\$vf0xyw'
.*: Error: invalid operands `vminiz\.xyw \$vf31xyw,\$vf15z,\$vf7z'
.*: Error: invalid operands `vmove\.xyw \$vf0xyw,\$vf0xw'
.*: Error: invalid operands `vmove\.y \$vf0y,\$vf31x'
.*: Error: invalid operands `vmr32\.xw \$vf0xw,\$vf0w'
.*: Error: invalid operands `vmr32\.xw \$vf0w,\$vf31xw'
.*: Error: invalid operands `vmsubai\.xy \$ACCxy,\$vf31xy,\$Q'
.*: Error: invalid operands `vmsubai\.xyw \$ACCxyw,\$vf0xyw,\$0'
.*: Error: invalid operands `vmsubai\.xyw \$ACCxyw,\$vf1xyw,\$ACC'
.*: Error: invalid operands `vmsubai\.xyw \$ACCxyw,\$vf31xw,\$I'
.*: Error: invalid operands `vmsubaq\.y \$ACCy,\$vf31y,\$Qy'
.*: Error: invalid operands `vmsubaq\.yw \$ACCw,\$vf0yw,\$Q'
.*: Error: invalid operands `vmsubaq\.yw \$ACCwy,\$vf1yw,\$Q'
.*: Error: invalid operands `vmsubaw\.x \$ACCx,\$vf31x,\$vf0x'
.*: Error: invalid operands `vmsubaw\.x \$ACCx,\$vf31w,\$vf15w'
.*: Error: invalid operands `vmsubaw\.x \$ACCw,\$vf31x,\$vf31w'
.*: Error: invalid operands `vmsubaw\.xw \$ACCw,\$vf0xw,\$vf0w'
.*: Error: invalid operands `vmsubaw\.xw \$ACCxw,\$vf0w,\$vf31w'
.*: Error: invalid operands `vmsubaw\.xw \$ACCxw,\$vf1xw,\$vf2xw'
.*: Error: invalid operands `vmsubax\.yzw \$ACCyzw,\$vf0yzw,\$vf31yzw'
.*: Error: invalid operands `vmsubax\.z \$ACCz,\$vf31z,\$vf0z'
.*: Error: invalid operands `vmsuba\.y \$ACCy,\$vf31y,\$vf15a'
.*: Error: invalid operands `vmsuba\.yw \$ACCyw,\$vf31yw,\$vf0w'
.*: Error: invalid operands `vmsubay\.x \$ACCx,\$vf31x,\$vf15x'
.*: Error: invalid operands `vmsubay\.x \$ACCx,\$vf31y,\$vf31y'
.*: Error: invalid operands `vmsubay\.xw \$ACCxw,\$vf0xw,\$vf0xw'
.*: Error: invalid operands `vmsubaz\.xy \$ACCxy,\$vf0xy,\$vf31xy'
.*: Error: invalid operands `vmsubaz\.yw \$ACCyw,\$vf31yw,\$vf0yw'
.*: Error: invalid operands `vmsubi\.xyzw \$vf31xyzw,\$vf0xyzw,\$R'
.*: Error: invalid operands `vmsubw\.xyw \$vf0xyw,\$vf0xyw,\$vf0xyw'
.*: Error: invalid operands `vmsubw\.xzw \$vf0xzw,\$vf0xzw,\$vf31xzw'
.*: Error: invalid operands `vmsubw\.y \$vf31y,\$vf31y,\$vf31y'
.*: Error: invalid operands `vmsubw\.yw \$vf0yw,\$vf0y,\$vf0w'
.*: Error: invalid operands `vmsubw\.yw \$vf0w,\$vf0yw,\$vf31w'
.*: Error: invalid operands `vmsubw\.zw \$vf0zw,\$vf0zw,\$vf31zw'
.*: Error: invalid operands `vmsubx\.w \$vf0w,\$vf0w,\$vf0w'
.*: Error: invalid operands `vmsub\.y \$vf31y,\$vf15y,\$vf7w'
.*: Error: invalid operands `vmsuby\.x \$vf0x,\$vf0x,\$vf31x'
.*: Error: invalid operands `vmsuby\.x \$vf0x,\$vf31y,\$vf0y'
.*: Error: invalid operands `vmsubz\.x \$vf0x,\$vf31x,\$vf0x'
.*: Error: invalid operands `vmulai\.xyz \$ACCxyz,\$vf1xz,\$I'
.*: Error: invalid operands `vmulaq\.zw \$ACCzw,\$vf31zw,\$I'
.*: Error: invalid operands `vmula\.w \$ACCw,\$vf31w,\$vf0x'
.*: Error: invalid operands `vmulax\.xz \$ACCxz,\$vf0xz,\$vf31xz'
.*: Error: invalid operands `vmulax\.xz \$ACCxz,\$vf1x,\$vf2x'
.*: Error: invalid operands `vmulax\.xz \$ACCx,\$vf31xz,\$vf0x'
.*: Error: invalid operands `vmulay\.yzw \$ACCyzw,\$vf0yzw,\$vf31yzw'
.*: Error: invalid operands `vmulaz\.w \$ACCw,\$vf0w,\$vf31w'
.*: Error: unrecognized opcode `mulaz\.xy \$ACCz,\$vf31xy,\$vf0z'
.*: Error: invalid operands `vmulaz\.xy \$ACCxy,\$vf31z,\$vf15z'
.*: Error: invalid operands `vmulaz\.z \$ACCz,\$vf1z,\$vf2x'
.*: Error: invalid operands `vmuli\.x \$vf31x,\$vf15x,\$ACC'
.*: Error: invalid operands `vmulq\.x \$vf0x,\$vf31x,\$0'
.*: Error: invalid operands `vmulq\.x \$vf1x,\$vf2x,\$ACC'
.*: Error: invalid operands `vmulq\.x \$vf31x,\$vf0x,\$R'
.*: Error: invalid operands `vmulq\.x \$vf31x,\$vf15x,\$I'
.*: Error: invalid operands `vmulw\.z \$vf31z,\$vf15z,\$vf7z'
.*: Error: invalid operands `vmulw\.z \$vf31z,\$vf31w,\$vf31w'
.*: Error: invalid operands `vmulw\.zw \$vf0zw,\$vf0zw,\$vf0zw'
.*: Error: invalid operands `vmuly\.xyzw \$vf0xyzw,\$vf0y,\$vf31y'
.*: Error: invalid operands `vmuly\.xyzw \$vf0xyzw,\$vf31xyzw,\$vf0xyzw'
.*: Error: invalid operands `vmuly\.xyzw \$vf1xyzw,\$vf2y,\$vf3y'
.*: Error: invalid operands `vmuly\.xyzw \$vf31y,\$vf0xyzw,\$vf0y'
.*: Error: invalid operands `vmulz\.y \$vf0y,\$vf31y,\$vf0y'
.*: Error: invalid operands `vmulz\.y \$vf1y,\$vf2z,\$vf3z'
.*: Error: invalid operands `vmulz\.y \$vf31z,\$vf0y,\$vf0z'
.*: Error: invalid operands `vmulz\.y \$vf31z,\$vf15z,\$vf7z'
.*: Error: invalid operands `vopmsub \$vf0x,\$vf0,\$vf31'
.*: Error: invalid operands `vopmsub \$vf0,\$vf31x,\$vf0'
.*: Error: invalid operands `vopmsub \$vf1,\$vf2,\$vf3x'
.*: Error: invalid operands `vopmsub \$ACC,\$vf0,\$vf0'
.*: Error: invalid operands `vopmsub \$vf31,\$R,\$vf7'
.*: Error: invalid operands `vopmsub \$vf31,\$vf31,\$I'
.*: Error: invalid operands `vopmsub\.xyz \$vf0xyz,\$vf0xyz,\$vf0xy'
.*: Error: invalid operands `vopmula \$0,\$vf0,\$vf0'
.*: Error: invalid operands `vopmula \$Q,\$vf0,\$vf31'
.*: Error: invalid operands `vopmula \$R,\$vf1,\$vf2'
.*: Error: invalid operands `vopmula \$I,\$vf31,\$vf0'
.*: Error: invalid operands `vopmula \$ACCx,\$vf31,\$vf15'
.*: Error: invalid operands `vopmula \$ACCxyzw,\$vf31,\$vf31'
.*: Error: invalid operands `vopmula\.xyz \$ACCxyzw,\$vf0xyz,\$vf0xyz'
.*: Error: unrecognized opcode `vopmula\.xyzw \$ACCxyzw,\$vf0xyzw,\$vf31xyzw'
.*: Error: invalid operands `vrget\.w \$vf0w,\$0'
.*: Error: invalid operands `vrget\.w \$vf1w,\$I'
.*: Error: invalid operands `vrget\.w \$vf31w,\$Q'
.*: Error: invalid operands `vrget\.x \$vf0x,\$ACC'
.*: Error: invalid operands `vrget\.x \$vf1y,\$R'
.*: Error: invalid operands `vrget\.xy \$vf31x,\$R'
.*: Error: invalid operands `vrget\.xyw \$vf0xw,\$R'
.*: Error: invalid operands `vrget\.xyw \$vf1yw,\$R'
.*: Error: invalid operands `vrget\.xyw \$vf31xy,\$R'
.*: Error: invalid operands `vrget\.xyz \$vf0xy,\$R'
.*: Error: invalid operands `vrget\.xyz \$vf1xyzw,\$R'
.*: Error: invalid operands `vrget\.xyz \$vf31xyzw,\$R'
.*: Error: invalid operands `vrget\.xyzw \$vf0xyz,\$R'
.*: Error: invalid operands `vrget\.xyzw \$vf1xzw,\$R'
.*: Error: invalid operands `vrget\.xyzw \$vf31yzw,\$R'
.*: Error: invalid operands `vrget\.xz \$vf0xz,\$0'
.*: Error: invalid operands `vrget\.xz \$vf1z,\$R'
.*: Error: invalid operands `vrget\.xzw \$vf0xw,\$R'
.*: Error: invalid operands `vrget\.y \$vf0z,\$R'
.*: Error: invalid operands `vrget\.y \$vf1y,\$I'
.*: Error: invalid operands `vrget\.z \$vf31z,\$Q'
.*: Error: invalid operands `vrget\.zw \$vf0zw,\$ACC'
.*: Error: invalid operands `vrnext\.xyzw \$vf0xyz,\$R'
.*: Error: invalid operands `vrnext\.xyzw \$vf1xyzw,\$0'
.*: Error: invalid operands `vrnext\.xyzw \$vf31xyzw,\$Rxyzw'
.*: Error: invalid operands `vrnext\.yz \$vf31yz,\$Ryz'
.*: Error: invalid operands `vrnext\.z \$vf0z,\$Rz'
.*: Error: invalid operands `vrsqrt \$Q,\$vf0xz,\$vf31y'
.*: Error: invalid operands `vrsqrt \$Q,\$vf1z,\$vf2xz'
.*: Error: invalid operands `vrsqrt \$Q,\$vf31yx,\$vf15w'
.*: Error: invalid operands `vrsqrt \$Qx,\$vf31x,\$vf31y'
.*: Error: invalid operands `vrsqrt \$0,\$vf31y,\$vf0w'
.*: Error: invalid operands `vrxor \$0,\$vf0w'
.*: Error: invalid operands `vrxor \$R,\$vf0xy'
.*: Error: invalid operands `vrxor \$R,\$vf0zw'
.*: Error: invalid operands `vrxor \$R,\$vf1yz'
.*: Error: invalid operands `vrxor \$ACC,\$vf31x'
.*: Error: invalid operands `vrxor \$Q,\$vf31y'
.*: Error: invalid operands `vsqd\.w \$vf0,\(\-\-\$vi0w\)'
.*: Error: invalid operands `vsqd\.w \$vf0,\(\-\-\$vi31w\)'
.*: Error: invalid operands `vsqd\.x \$vf1,\(\-\-\$vi2x\)'
.*: Error: invalid operands `vsqd\.xw \$vf0,\(\-\-\$vi0xw\)'
.*: Error: invalid operands `vsqd\.xy \$vf0,\(\-\-\$vi0xy\)'
.*: Error: invalid operands `vsqd\.xyw \$vf0,\(\-\-\$vi0xyw\)'
.*: Error: invalid operands `vsqd\.xyz \$vf0,\(\-\-\$vi31xyz\)'
.*: Error: invalid operands `vsqd\.xyzw \$vf0,\(\-\-\$vi0xyzw\)'
.*: Error: invalid operands `vsqd\.xz \$vf0,\(\-\-\$vi31xz\)'
.*: Error: invalid operands `vsqd\.xzw \$vf0,\(\-\-\$vi0xzw\)'
.*: Error: invalid operands `vsqd\.y \$vf0,\(\-\-\$vi0y\)'
.*: Error: invalid operands `vsqd\.yw \$vf0,\(\-\-\$vi31yw\)'
.*: Error: invalid operands `vsqd\.yz \$vf0,\(\-\-\$vi31yz\)'
.*: Error: invalid operands `vsqd\.yzw \$vf0,\(\-\-\$vi31yzw\)'
.*: Error: invalid operands `vsqd\.yzw \$vf0yzw,\(\-\-\$vi0x\)'
.*: Error: invalid operands `vsqd\.z \$vf1,\(\-\-\$vi2z\)'
.*: Error: invalid operands `vsqd\.zw \$vf1,\(\-\-\$vi2zw\)'
.*: Error: invalid operands `vsqi\.w \$vf0,\(\$vi0w\+\+\)'
.*: Error: invalid operands `vsqi\.x \$vf0x,\(\$vi0x\+\+\)'
.*: Error: invalid operands `vsqi\.xw \$vf0xw,\(\$vi0xw\+\+\)'
.*: Error: invalid operands `vsqi\.xw \$vf1x,\(\$vi2\+\+\)'
.*: Error: invalid operands `vsqi\.xw \$vf31w,\(\$vi0\+\+\)'
.*: Error: invalid operands `vsqi\.xy \$vf0,\(\$vi31xy\+\+\)'
.*: Error: invalid operands `vsqi\.xyw \$vf0x,\(\$vi0\+\+\)'
.*: Error: invalid operands `vsqi\.xyw \$vf0,\(\$vi31xyw\+\+\)'
.*: Error: invalid operands `vsqi\.xyz \$vf0xyz,\(\$vi0xyz\+\+\)'
.*: Error: invalid operands `vsqi\.xyzw \$vf0,\(\$vi31xyzw\+\+\)'
.*: Error: invalid operands `vsqi\.xz \$vf0xz,\(\$vi0xz\+\+\)'
.*: Error: invalid operands `vsqi\.xzw \$vf0xzw,\(\$vi0xzw\+\+\)'
.*: Error: invalid operands `vsqi\.y \$vf1,\(\$vi2y\+\+\)'
.*: Error: invalid operands `vsqi\.yw \$vf0yw,\(\$vi0yw\+\+\)'
.*: Error: invalid operands `vsqi\.yz \$vf1,\(\$vi2yz\+\+\)'
.*: Error: invalid operands `vsqi\.yzw \$vf0yzw,\(\$vi0yzw\+\+\)'
.*: Error: invalid operands `vsqi\.z \$vf0,\(\$vi31z\+\+\)'
.*: Error: invalid operands `vsqi\.zw \$vf0zw,\(\$vi0zw\+\+\)'
.*: Error: invalid operands `vsqrt \$Q,\$vf1zw'
.*: Error: invalid operands `vsqrt \$Q,\$vf31xw'
.*: Error: invalid operands `vsqrt \$Q,\$vf31xy'
.*: Error: invalid operands `vsubai\.w \$ACCw,\$vf0w,\$0'
.*: Error: invalid operands `vsubai\.w \$ACCw,\$vf1x,\$I'
.*: Error: invalid operands `vsubai\.w \$ACCx,\$vf31w,\$I'
.*: Error: invalid operands `vsubai\.x \$ACCw,\$vf31x,\$I'
.*: Error: invalid operands `vsubai\.xw \$ACCw,\$vf0xw,\$I'
.*: Error: invalid operands `vsubai\.xw \$ACCxw,\$vf1x,\$I'
.*: Error: invalid operands `vsubai\.xw \$ACCxw,\$vf31xw,\$0'
.*: Error: invalid operands `vsubai\.xy \$ACCxy,\$vf0y,\$I'
.*: Error: invalid operands `vsubai\.xy \$ACCxy,\$vf1x,\$I'
.*: Error: invalid operands `vsubai\.xy \$ACCxy,\$vf311xy,\$I'
.*: Error: invalid operands `vsubai\.xyz \$ACCxyz,\$vf1yz,\$I'
.*: Error: invalid operands `vsubai\.xyz \$ACCxyz,\$vf31xyz,\$ACC'
.*: Error: invalid operands `vsubai\.xyzw \$ACCxyzw,\$vf0xyzw,\$R'
.*: Error: invalid operands `vsubai\.xyzw \$ACCxyzw,\$vf1xyzw,\$Q'
.*: Error: invalid operands `vsubai\.xz \$ACCxz,\$vf1z,\$I'
.*: Error: invalid operands `vsubai\.y \$ACCy,\$vf31,\$3'
.*: Error: invalid operands `vsubai\.yw \$ACCyw,\$vf0yw,\$Iyw'
.*: Error: invalid operands `vsubai\.zw \$ACCzw,\$vf1zw,\$Izw'
.*: Error: invalid operands `vsubai\.zw \$ACCzw,\$vf31w,\$I'
.*: Error: invalid operands `vsubaq\.w \$ACCw,\$Q,\$Q'
.*: Error: invalid operands `vsubaq\.w \$ACCw,\$I,\$Q'
.*: Error: invalid operands `vsubaq\.xyw \$ACCxyw,\$vf0xw,\$Q'
.*: Error: invalid operands `vsubaq\.xyzw \$ACCxyzw,\$vf0xyz,\$Q'
.*: Error: invalid operands `vsubaq\.xzw \$ACCxzw,\$vf1xw,\$Q'
.*: Error: invalid operands `vsubaq\.yw \$ACCyw,\$vf31y,\$Q'
.*: Error: invalid operands `vsubaq\.yz \$ACCyz,\$vf0yz,\$ACC'
.*: Error: invalid operands `vsubaq\.yz \$ACCyz,\$vf1yz,\$I'
.*: Error: invalid operands `vsubax\.w \$ACCw,\$vf0w,\$vf0w'
.*: Error: invalid operands `vsubax\.w \$ACCw,\$vf0x,\$vf31x'
.*: Error: invalid operands `vsubax\.w \$ACCx,\$vf1w,\$vf2x'
.*: Error: invalid operands `vsubax\.w \$ACCx,\$vf31x,\$vf0x'
.*: Error: invalid operands `vsubax\.xyzw \$ACCxyzw,\$vf31xyzw,\$vf0xyzw'
.*: Error: invalid operands `vsubax\.xzw \$ACCxzw,\$vf1xzw,\$vf2xzw'
.*: Error: invalid operands `vsubax\.y \$ACCy,\$vf31y,\$vf0y'
.*: Error: invalid operands `vsubax\.yw \$ACCyw,\$vf0yw,\$vf0yw'
.*: Error: invalid operands `vsubay\.yw \$ACCyw,\$vf0yw,\$vf31yw'
.*: Error: invalid operands `vsubay\.yzw \$ACCyzw,\$vf0yzw,\$vf31yzw'
.*: Error: invalid operands `vsubay\.z \$ACCz,\$vf0z,\$vf31z'
.*: Error: invalid operands `vsubay\.zw \$ACCzw,\$vf0zw,\$vf0zw'
.*: Error: invalid operands `vsubaz\.w \$ACCw,\$vf31w,\$vf15w'
.*: Error: invalid operands `vsubaz\.x \$ACCx,\$vf0x,\$vf31x'
.*: Error: invalid operands `vsubaz\.xy \$ACCxy,\$vf0xy,\$vf0xy'
.*: Error: invalid operands `vsubaz\.xz \$ACCxz,\$vf31xz,\$vf15xz'
.*: Error: invalid operands `vsubaz\.xz \$ACCxz,\$vf31z,\$vf31z'
.*: Error: invalid operands `vsubaz\.xzw \$ACCxw,\$vf0xzw,\$vf0z'
.*: Error: invalid operands `vsubaz\.xzw \$ACCz,\$vf0xzw,\$vf31z'
.*: Error: invalid operands `vsubaz\.xzw \$ACCxzw,\$vf1z,\$vf2z'
.*: Error: invalid operands `vsubaz\.yw \$ACCyw,\$vf1yw,\$vf2yw'
.*: Error: invalid operands `vsubi\.w \$vf31w,\$vf15w,\$0'
.*: Error: invalid operands `vsubi\.w \$vf31w,\$vf31w,\$R'
.*: Error: invalid operands `vsubi\.x \$vf0x,\$vf0y,\$I'
.*: Error: invalid operands `vsubi\.x \$vf0x,\$vf31x,\$Ix'
.*: Error: invalid operands `vsubi\.xy \$vf0xy,\$vf31y,\$I'
.*: Error: invalid operands `vsubi\.xy \$vf1x,\$vf2xy,\$I'
.*: Error: invalid operands `vsubq\.x \$vf31x,\$vf15x,\$Qx'
.*: Error: invalid operands `vsubq\.x \$vf31x,\$vf31y,\$Q'
.*: Error: invalid operands `vsubq\.xw \$vf0xw,\$vf0xw,\$0'
.*: Error: invalid operands `vsubq\.xw \$vf0xw,\$vf31xw,\$2'
.*: Error: invalid operands `vsubq\.xyzw \$vf1yzw,\$vf2xyzw,\$Q'
.*: Error: invalid operands `vsubq\.yw \$vf31w,\$vf15yw,\$Q'
.*: Error: invalid operands `vsubq\.yw \$vf31yw,\$vf31y,\$Q'
.*: Error: invalid operands `vsubx\.xyw \$vf0xyw,\$vf31xyw,\$vf0xyw'
.*: Error: invalid operands `vsubx\.xzw \$vf1xzw,\$vf2xzw,\$vf3xzw'
.*: Error: invalid operands `vsuby\.xw \$vf0xw,\$vf0xw,\$vf0xw'
.*: Error: invalid operands `vsuby\.zw \$vf0zw,\$vf0zw,\$vf0zw'
.*: Error: invalid operands `vsub\.z \$vf0z,\$vf31z,\$vf0x'
.*: Error: invalid operands `vsubz\.xyw \$vf31yw,\$vf15xyw,\$vf7z'
.*: Error: invalid operands `vsubz\.xyw \$vf31xyw,\$vf31yw,\$vf31z'
.*: Error: invalid operands `vsubz\.xyz \$vf0xyz,\$vf0xyz,\$vf0x'
.*: Error: invalid operands `vwaitq \$vf0x'
