#objdump: -dr --prefix-addresses --show-raw-insn
#name: MIPS ISA override code generation
#as: -32
#source: isa-override-1.s
#warning_output: interaptiv-mr2@isa-override-1.l
#dump: mips32r2@isa-override-1.d
