	wldrwgt	wcgr0,[r1]
	wldrb	wcgr0,[r1]
	wldrh	wcgr0,[r1]
	wldrd	wcgr0,[r1]
	wstrwgt	wcgr0,[r1]
	wstrb	wcgr0,[r1]
	wstrh	wcgr0,[r1]
	wstrd	wcgr0,[r1]
	tmcr	wibble,r1
	wldrw	wibble,[r1]
	wstrw	wibble,[r1]
