[^:]*: Assembler messages:
^[^:]*:4: Error: immediate value out of range -- `udf #0x10000'
^[^:]*:7: Error: immediate value out of range -- `udf #0x10000'
^[^:]*:8: Error: immediate value out of range -- `udf.w #0x10000'
^[^:]*:9: Error: immediate value out of range -- `udf.n #0x100'
