[^:]*: Assembler messages:
[^:]*:2: Warning: float16 format cannot be set more than once, ignoring.
[^:]*:3: Error: unrecognised float16 format "monkeys"
[^:]*:4: Error: unrecognised float16 format "..."
[^:]*:5: Error: unrecognised float16 format ""
