[^:]*: Assembler messages:
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:19: Error: syntax error -- `vbiceq q0,q1,q2'
[^:]*:20: Error: syntax error -- `vbiceq q0,q1,q2'
[^:]*:22: Error: syntax error -- `vbiceq q0,q1,q2'
[^:]*:24: Error: instruction missing MVE vector predication code -- `vbic q0,q1,q2'
[^:]*:25: Error: vector predicated instruction should be in VPT/VPST block -- `vbict q0,q1,q2'
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Error: syntax error -- `vbiceq.i16 q0,#255'
[^:]*:29: Error: syntax error -- `vbiceq.i16 q0,#255'
[^:]*:31: Error: syntax error -- `vbiceq.i16 q0,#255'
[^:]*:33: Error: instruction missing MVE vector predication code -- `vbic.i16 q0,#255'
[^:]*:34: Error: vector predicated instruction should be in VPT/VPST block -- `vbict.i16 q0,#255'
[^:]*:35: Error: bad type in SIMD instruction -- `vbic.i8 q0,#255'
[^:]*:36: Error: bad type in SIMD instruction -- `vbic.i64 q0,#255'
[^:]*:37: Error: immediate value out of range -- `vbic.i16 q0,#257'
[^:]*:38: Error: immediate value out of range -- `vbic.i32 q0,#257'

