.*: Assembler messages:
.*: Error: illegal operands `auipc x8,x9'
.*: Error: illegal operands `lui x10,x11'
.*: Error: illegal operands `auipc x12,symbol'
.*: Error: illegal operands `lui x13,symbol'
