[^:]*: Assembler messages:
[^:]*:7: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*:9: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:12: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*:13: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:15: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*:16: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:18: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*:19: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:21: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*:22: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:24: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*:25: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:33: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*:34: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:36: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:39: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:41: Warning: NOP inserted here, after an interrupt enable instruction
[^:]*:44: Warning: NOP inserted here, before an interrupt enable instruction
[^:]*: Warning: NOP inserted after the interrupt state change at the end of the file
