[^:]*: Assembler messages:
[^:]*:6: Error: \$DSBT_INDEX not supported in this context
[^:]*:7: Error: \$GOT not supported in this context
[^:]*:8: Error: \$DPR_GOT not supported in this context
[^:]*:9: Error: \$DPR_BYTE not supported in this context
[^:]*:10: Error: \$DPR_HWORD not supported in this context
[^:]*:11: Error: \$DPR_WORD not supported in this context
[^:]*:12: Error: \$PCR_OFFSET not supported in this context
[^:]*:17: Error: \$DSBT_INDEX not supported in this context
[^:]*:18: Error: \$GOT not supported in this context
[^:]*:19: Error: \$DPR_GOT not supported in this context
[^:]*:20: Error: \$DPR_BYTE not supported in this context
[^:]*:21: Error: \$DPR_HWORD not supported in this context
[^:]*:22: Error: \$DPR_WORD not supported in this context
[^:]*:23: Error: \$PCR_OFFSET not supported in this context
[^:]*:24: Error: \$DSBT_INDEX not supported in this context
[^:]*:25: Error: \$GOT not supported in this context
[^:]*:26: Error: \$DPR_GOT not supported in this context
[^:]*:27: Error: \$DPR_BYTE not supported in this context
[^:]*:28: Error: \$DPR_HWORD not supported in this context
[^:]*:29: Error: \$DPR_WORD not supported in this context
[^:]*:30: Error: \$PCR_OFFSET not supported in this context
[^:]*:31: Error: \$DPR_GOT not supported in this context
[^:]*:32: Error: \$DPR_BYTE not supported in this context
[^:]*:33: Error: \$DPR_HWORD not supported in this context
[^:]*:34: Error: \$DPR_WORD not supported in this context
[^:]*:35: Error: \$PCR_OFFSET not supported in this context
[^:]*:36: Error: \$DSBT_INDEX not supported in this context
[^:]*:37: Error: \$GOT not supported in this context
[^:]*:38: Error: \$DPR_GOT not supported in this context
[^:]*:39: Error: \$DPR_HWORD not supported in this context
[^:]*:40: Error: \$DPR_WORD not supported in this context
[^:]*:42: Error: \$DSBT_INDEX not supported in this context
[^:]*:43: Error: \$GOT not supported in this context
[^:]*:44: Error: \$DPR_GOT not supported in this context
[^:]*:45: Error: \$DPR_HWORD not supported in this context
[^:]*:46: Error: \$DPR_WORD not supported in this context
[^:]*:47: Error: \$DSBT_INDEX not supported in this context
[^:]*:48: Error: \$GOT not supported in this context
[^:]*:49: Error: \$DSBT_INDEX not supported in this context
[^:]*:50: Error: \$GOT not supported in this context
[^:]*:51: Error: \$DSBT_INDEX not supported in this context
[^:]*:52: Error: \$GOT not supported in this context
[^:]*:53: Error: \$DSBT_INDEX not supported in this context
[^:]*:54: Error: \$GOT not supported in this context
[^:]*:55: Error: \$DPR_GOT not supported in this context
[^:]*:56: Error: \$DPR_BYTE not supported in this context
[^:]*:57: Error: \$DPR_HWORD not supported in this context
[^:]*:58: Error: \$DPR_WORD not supported in this context
[^:]*:59: Error: \$PCR_OFFSET not supported in this context
[^:]*:60: Error: \$DSBT_INDEX not supported in this context
[^:]*:61: Error: \$GOT not supported in this context
[^:]*:62: Error: \$DPR_GOT not supported in this context
[^:]*:63: Error: \$DPR_BYTE not supported in this context
[^:]*:64: Error: \$DPR_HWORD not supported in this context
[^:]*:65: Error: \$DPR_WORD not supported in this context
[^:]*:66: Error: \$PCR_OFFSET not supported in this context
[^:]*:67: Error: \$DSBT_INDEX not supported in this context
[^:]*:68: Error: \$GOT not supported in this context
[^:]*:69: Error: \$DPR_GOT not supported in this context
[^:]*:70: Error: \$DPR_BYTE not supported in this context
[^:]*:71: Error: \$DPR_HWORD not supported in this context
[^:]*:72: Error: \$DPR_WORD not supported in this context
[^:]*:73: Error: \$PCR_OFFSET not supported in this context
[^:]*:74: Error: \$DSBT_INDEX not supported in this context
[^:]*:75: Error: \$GOT not supported in this context
[^:]*:76: Error: \$DPR_GOT not supported in this context
[^:]*:77: Error: \$DPR_BYTE not supported in this context
[^:]*:78: Error: \$DPR_HWORD not supported in this context
[^:]*:79: Error: \$DPR_WORD not supported in this context
[^:]*:80: Error: \$PCR_OFFSET not supported in this context
[^:]*:81: Error: \$DSBT_INDEX not supported in this context
[^:]*:82: Error: \$GOT not supported in this context
[^:]*:83: Error: \$DPR_GOT not supported in this context
[^:]*:84: Error: \$DPR_BYTE not supported in this context
[^:]*:85: Error: \$DPR_HWORD not supported in this context
[^:]*:86: Error: \$DPR_WORD not supported in this context
[^:]*:87: Error: \$PCR_OFFSET not supported in this context
[^:]*:88: Error: \$DSBT_INDEX not supported in this context
[^:]*:89: Error: \$GOT not supported in this context
[^:]*:90: Error: \$DPR_GOT not supported in this context
[^:]*:91: Error: \$DPR_BYTE not supported in this context
[^:]*:92: Error: \$DPR_HWORD not supported in this context
[^:]*:93: Error: \$DPR_WORD not supported in this context
[^:]*:94: Error: \$PCR_OFFSET not supported in this context
[^:]*:95: Error: \$DSBT_INDEX not supported in this context
[^:]*:96: Error: \$GOT not supported in this context
[^:]*:97: Error: \$DPR_GOT not supported in this context
[^:]*:98: Error: \$DPR_BYTE not supported in this context
[^:]*:99: Error: \$DPR_HWORD not supported in this context
[^:]*:100: Error: \$DPR_WORD not supported in this context
[^:]*:101: Error: \$PCR_OFFSET not supported in this context
[^:]*:102: Error: \$DSBT_INDEX not supported in this context
[^:]*:103: Error: \$GOT not supported in this context
[^:]*:104: Error: \$DPR_GOT not supported in this context
[^:]*:105: Error: \$DPR_BYTE not supported in this context
[^:]*:106: Error: \$DPR_HWORD not supported in this context
[^:]*:107: Error: \$DPR_WORD not supported in this context
[^:]*:108: Error: \$PCR_OFFSET not supported in this context
[^:]*:109: Error: \$DSBT_INDEX not supported in this context
[^:]*:110: Error: \$GOT not supported in this context
[^:]*:111: Error: \$DPR_GOT not supported in this context
[^:]*:112: Error: \$DPR_BYTE not supported in this context
[^:]*:113: Error: \$DPR_HWORD not supported in this context
[^:]*:114: Error: \$DPR_WORD not supported in this context
[^:]*:115: Error: \$PCR_OFFSET not supported in this context
[^:]*:116: Error: \$DSBT_INDEX not supported in this context
[^:]*:117: Error: \$GOT not supported in this context
[^:]*:118: Error: \$DPR_GOT not supported in this context
[^:]*:119: Error: \$DPR_BYTE not supported in this context
[^:]*:120: Error: \$DPR_HWORD not supported in this context
[^:]*:121: Error: \$DPR_WORD not supported in this context
[^:]*:122: Error: \$PCR_OFFSET not supported in this context
[^:]*:123: Error: \$DSBT_INDEX not supported in this context
[^:]*:124: Error: \$GOT not supported in this context
[^:]*:125: Error: \$DPR_GOT not supported in this context
[^:]*:126: Error: \$DPR_BYTE not supported in this context
[^:]*:127: Error: \$DPR_HWORD not supported in this context
[^:]*:128: Error: \$DPR_WORD not supported in this context
[^:]*:129: Error: \$PCR_OFFSET not supported in this context
[^:]*:130: Error: \$DSBT_INDEX not supported in this context
[^:]*:131: Error: \$GOT not supported in this context
[^:]*:132: Error: \$DPR_GOT not supported in this context
[^:]*:133: Error: \$DPR_BYTE not supported in this context
[^:]*:134: Error: \$DPR_HWORD not supported in this context
[^:]*:135: Error: \$DPR_WORD not supported in this context
[^:]*:136: Error: \$PCR_OFFSET not supported in this context
[^:]*:137: Error: \$DSBT_INDEX not supported in this context
[^:]*:138: Error: \$GOT not supported in this context
[^:]*:139: Error: \$DPR_GOT not supported in this context
[^:]*:140: Error: \$DPR_BYTE not supported in this context
[^:]*:141: Error: \$DPR_HWORD not supported in this context
[^:]*:142: Error: \$DPR_WORD not supported in this context
[^:]*:143: Error: \$PCR_OFFSET not supported in this context
[^:]*:144: Error: \$DSBT_INDEX not supported in this context
[^:]*:145: Error: \$GOT not supported in this context
[^:]*:146: Error: \$DPR_GOT not supported in this context
[^:]*:147: Error: \$DPR_BYTE not supported in this context
[^:]*:148: Error: \$DPR_HWORD not supported in this context
[^:]*:149: Error: \$DPR_WORD not supported in this context
[^:]*:150: Error: \$PCR_OFFSET not supported in this context
[^:]*:151: Error: \$DSBT_INDEX not supported in this context
[^:]*:152: Error: \$GOT not supported in this context
[^:]*:153: Error: \$DPR_GOT not supported in this context
[^:]*:154: Error: \$DPR_BYTE not supported in this context
[^:]*:155: Error: \$DPR_HWORD not supported in this context
[^:]*:156: Error: \$DPR_WORD not supported in this context
[^:]*:157: Error: \$PCR_OFFSET not supported in this context
[^:]*:158: Error: \$DPR_GOT not supported in this context
[^:]*:159: Error: \$DPR_BYTE not supported in this context
[^:]*:160: Error: \$DPR_HWORD not supported in this context
[^:]*:161: Error: \$DPR_WORD not supported in this context
[^:]*:162: Error: \$PCR_OFFSET not supported in this context
[^:]*:163: Error: \$DSBT_INDEX not supported in this context
[^:]*:164: Error: \$GOT not supported in this context
[^:]*:165: Error: \$DPR_GOT not supported in this context
[^:]*:166: Error: \$DPR_BYTE not supported in this context
[^:]*:167: Error: \$DPR_HWORD not supported in this context
[^:]*:168: Error: \$DPR_WORD not supported in this context
[^:]*:169: Error: \$PCR_OFFSET not supported in this context
[^:]*:170: Error: \$DSBT_INDEX not supported in this context
[^:]*:171: Error: \$GOT not supported in this context
[^:]*:172: Error: \$DPR_GOT not supported in this context
[^:]*:173: Error: \$DPR_BYTE not supported in this context
[^:]*:174: Error: \$DPR_HWORD not supported in this context
[^:]*:175: Error: \$DPR_WORD not supported in this context
[^:]*:176: Error: \$PCR_OFFSET not supported in this context
[^:]*:177: Error: \$DPR_GOT not supported in this context
[^:]*:178: Error: \$DPR_BYTE not supported in this context
[^:]*:179: Error: \$DPR_HWORD not supported in this context
[^:]*:180: Error: \$DPR_WORD not supported in this context
[^:]*:181: Error: \$PCR_OFFSET not supported in this context
