#source: ./rolc.s
#objdump: -dr

.*:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	7e 50                         	rolc	r0
   2:	7e 5f                         	rolc	r15
