[^:]*: Assembler messages:
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:17: Error: bad type in SIMD instruction -- `vpt.i64 eq,q0,q1'
[^:]*:18: Error: selected FPU does not support instruction -- `vpt.f16 eq,q0,q1'
[^:]*:19: Error: selected FPU does not support instruction -- `vpt.f32 eq,q0,q1'
[^:]*:20: Error: bad type in SIMD instruction -- `vpt.f64 eq,q0,q1'
[^:]*:22: Error: syntax error -- `vpteq.i8 eq,q0,q1'
[^:]*:23: Error: syntax error -- `vpteq.i8 eq,q0,q1'
[^:]*:26: Warning: instruction is UNPREDICTABLE in a VPT block
[^:]*:27: Warning: instruction is UNPREDICTABLE in a VPT block
[^:]*:30: Warning: .* finished with an open VPT/VPST block.
