#objdump: -t
#as:  --generate-missing-build-notes=no

.*:     file format .*

SYMBOL TABLE:
0+ l    d  \.text	0+ \.text
0+ l    d  \.data	0+ \.data
0+ l    d  \.bss	0+ \.bss
0+ l       \.text	0+ func
0+         \*UND\*	0+ 0x80 foobar
