[^:]*: Assembler messages:
[^:]*:12: Error: immediate value out of range -- `vcvt.f16.s16 q0,q1,#0'
[^:]*:13: Error: immediate value out of range -- `vcvt.s16.f16 q0,q1,#0'
[^:]*:14: Error: immediate value out of range -- `vcvt.f16.u16 q0,q1,#0'
[^:]*:15: Error: immediate value out of range -- `vcvt.u16.f16 q0,q1,#0'
[^:]*:16: Error: immediate value out of range -- `vcvt.f16.s16 q0,q1,#17'
[^:]*:17: Error: immediate value out of range -- `vcvt.s16.f16 q0,q1,#17'
[^:]*:18: Error: immediate value out of range -- `vcvt.f16.u16 q0,q1,#17'
[^:]*:19: Error: immediate value out of range -- `vcvt.u16.f16 q0,q1,#17'
[^:]*:20: Error: immediate value out of range -- `vcvt.f32.s32 q0,q1,#0'
[^:]*:21: Error: immediate value out of range -- `vcvt.s32.f32 q0,q1,#0'
[^:]*:22: Error: immediate value out of range -- `vcvt.f32.u32 q0,q1,#0'
[^:]*:23: Error: immediate value out of range -- `vcvt.u32.f32 q0,q1,#0'
[^:]*:24: Error: immediate value out of range -- `vcvt.f32.s32 q0,q1,#33'
[^:]*:25: Error: immediate value out of range -- `vcvt.s32.f32 q0,q1,#33'
[^:]*:26: Error: immediate value out of range -- `vcvt.f32.u32 q0,q1,#33'
[^:]*:27: Error: immediate value out of range -- `vcvt.u32.f32 q0,q1,#33'
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:29: Error: bad type in SIMD instruction -- `vcvt.f64.u64 q0,q1,#1'
[^:]*:30: Error: bad type in SIMD instruction -- `vcvt.u64.f64 q0,q1,#1'
[^:]*:31: Error: bad type in SIMD instruction -- `vcvt.f64.s64 q0,q1,#1'
[^:]*:32: Error: bad type in SIMD instruction -- `vcvt.s64.f64 q0,q1,#1'
[^:]*:34: Error: syntax error -- `vcvteq.f32.u32 q0,q1,#1'
[^:]*:35: Error: syntax error -- `vcvteq.f32.u32 q0,q1,#1'
[^:]*:37: Error: syntax error -- `vcvteq.f32.u32 q0,q1,#1'
[^:]*:39: Error: instruction missing MVE vector predication code -- `vcvt.f32.u32 q0,q1,#1'
[^:]*:40: Error: vector predicated instruction should be in VPT/VPST block -- `vcvtt.f32.u32 q0,q1,#1'

