.text
.arm
.section .vdups, "ax"
vdupeq.32  d0, r0
vdupne.32  d0, r0
vdupcs.32  d0, r0
vdupcc.32  d0, r0
vdupmi.32  d0, r0
vduppl.32  d0, r0
vdupvs.32  d0, r0
vdupvc.32  d0, r0
vduphi.32  d0, r0
vdupls.32  d0, r0
vdupge.32  d0, r0
vduplt.32  d0, r0
vdupgt.32  d0, r0
vduple.32  d0, r0
vdup.32    d0, r0
