
.*:     file format elf32-tradbigmips

Disassembly of section \.MIPS\.stubs:

.* <_MIPS_STUBS_>:
.*:	8f998010 	lw	t9,-32752\(gp\)
.*:	03e07825 	move	t7,ra
.*:	0320f809 	jalr	t9
.*:	24187fff 	li	t8,32767
.*:	00000000 	nop
.*:	00000000 	nop
.*:	00000000 	nop
.*:	00000000 	nop
Disassembly of section .text:
#pass
