[^:]*: Assembler messages:
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:17: Error: bad type in SIMD instruction -- `vpt.f64 eq,q0,q1'
[^:]*:19: Error: syntax error -- `vpteq.f32 eq,q0,q1'
[^:]*:20: Error: syntax error -- `vpteq.f32 eq,q0,q1'
[^:]*:23: Warning: instruction is UNPREDICTABLE in a VPT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in a VPT block
[^:]*:27: Warning: .* finished with an open VPT/VPST block.

