[^;]*: Assembler messages:
[^;]*:450: s suffix on comparison instruction is deprecated
[^;]*:450: s suffix on comparison instruction is deprecated
[^;]*:450: s suffix on comparison instruction is deprecated
[^;]*:450: s suffix on comparison instruction is deprecated
[^;]*:451: s suffix on comparison instruction is deprecated
[^;]*:451: s suffix on comparison instruction is deprecated
[^;]*:451: s suffix on comparison instruction is deprecated
[^;]*:451: s suffix on comparison instruction is deprecated
[^;]*:452: s suffix on comparison instruction is deprecated
[^;]*:452: s suffix on comparison instruction is deprecated
[^;]*:452: s suffix on comparison instruction is deprecated
[^;]*:452: s suffix on comparison instruction is deprecated
[^;]*:453: s suffix on comparison instruction is deprecated
[^;]*:453: s suffix on comparison instruction is deprecated
[^;]*:453: s suffix on comparison instruction is deprecated
[^;]*:453: s suffix on comparison instruction is deprecated
