# Round-type "R".
Main	FLOT X,ROUND_OFF,Z
	FLOTU X,2,$233
	SFLOT $133,0,Z0
	SFLOTU $123,ROUND_NEAR,Z
	SFLOT $133,0,Z
	FLOT X,ROUND_CURRENT,Z0
	SFLOTU $123,ROUND_NEAR,Z0
	FLOT X,ROUND_OFF,Z0
	FLOTU $173,2,$233
	FLOTU $173,2,213
	SFLOT X,0,Z
	FLOTU X,2,119
	SFLOT X,0,Z0
	FLOT X,ROUND_CURRENT,Z
X IS $135
Z IS $244
Z0 IS 91
