# readelf: -A

Attribute Section: ARC
File Attributes
  Tag_ARC_CPU_base: ARCHS
  Tag_ARC_CPU_name: "archs"
  Tag_ARC_ABI_osver: v4
  Tag_ARC_ABI_sda: GNU
  Tag_ARC_ABI_pic: GNU
  Tag_ARC_ABI_tls: r25
  Tag_ARC_ISA_config: "CD"
  Tag_ARC_ATR_version: 1
