[^:]*: Assembler messages:
[^:]*:9: Warning: a NOP might be needed here, before this interrupt state change
[^:]*:11: Warning: a NOP might also be needed here, after the instruction that changed interrupt state
[^:]*:14: Warning: a NOP might be needed here, before this interrupt state change
[^:]*:16: Warning: a NOP might also be needed here, after the instruction that changed interrupt state
