[^:]*: Assembler messages:
[^:]*:1: Error: file was compiled for the 430X ISA but the 430 ISA is selected
[^:]*:4: Error: file was compiled assuming data could be in the upper memory region, but the lower data region is exclusively in use
