.*: Assembler messages:
.*: Error: opcode not supported on this processor: r5900 \(mips3\) `ll \$5,0\(\$6\)'
.*: Error: opcode not supported on this processor: r5900 \(mips3\) `sc \$5,0\(\$6\)'
.*: Error: opcode not supported on this processor: r5900 \(mips3\) `lld \$5,0\(\$6\)'
.*: Error: opcode not supported on this processor: r5900 \(mips3\) `scd \$5,0\(\$6\)'
