#GCC like attribute structure
	.cpu EM
	.arc_attribute  Tag_ARC_PCS_config, 2
	.arc_attribute  Tag_ARC_CPU_variation, 2
	.arc_attribute	Tag_ARC_CPU_name, "arcem"
	.arc_attribute  Tag_ARC_ABI_osver, 4
	.arc_attribute  Tag_ARC_ISA_config, "CD"
	.arc_attribute  Tag_ARC_ATR_version, 1
