#as: --auto-litpools
#objdump: -d
#source: text-section-literals-1.s

.*: +file format .*xtensa.*
#...
Disassembly of section .init.literal:
#...
Disassembly of section .fini.literal:
#...
Disassembly of section .init:
#...
 *0:.*l32r.*
#...
Disassembly of section .fini:
#...
 *0:.*l32r.*
#...
