# source: attr-merge-3.s
# source: attr-merge-4.s
# as:
# ld: -r
# readelf: -A

Attribute Section: ARC
File Attributes
  Tag_ARC_CPU_base: ARCHS
  Tag_ARC_CPU_name: "archs"
  Tag_ARC_ABI_osver: v4
  Tag_ARC_ISA_config: "CD,FPUS"
  Tag_ARC_ATR_version: 1
