#objdump: -d
#name:    
#source:  ld-immu18.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	00          	bgnd
   1:	ca ff ee    	ld x, #65518
   4:	00          	bgnd
   5:	cb df e4    	ld y, #57316
   8:	00          	bgnd
   9:	da f0 ea    	ld x, #127210
   c:	00          	bgnd
   d:	db 7f 6e    	ld y, #98158
  10:	00          	bgnd
  11:	ea 6f ea    	ld x, #159722
  14:	00          	bgnd
  15:	eb 7f 9e    	ld y, #163742
  18:	00          	bgnd
  19:	fa 1f ca    	ld x, #204746
  1c:	00          	bgnd
  1d:	fb 7f 0e    	ld y, #229134
  20:	01          	nop
