.*: Assembler messages:
.*:9: Warning: relaxed out-of-range branch into a jump
.*:10: Warning: relaxed out-of-range branch into a jump
.*:11: Warning: relaxed out-of-range branch into a jump
.*:12: Warning: relaxed out-of-range branch into a jump
.*:13: Warning: relaxed out-of-range branch into a jump
.*:14: Warning: relaxed out-of-range branch into a jump
.*:15: Warning: relaxed out-of-range branch into a jump
.*:16: Warning: relaxed out-of-range branch into a jump
.*:17: Warning: relaxed out-of-range branch into a jump
.*:18: Warning: relaxed out-of-range branch into a jump
.*:20: Warning: relaxed out-of-range branch into a jump
.*:21: Warning: relaxed out-of-range branch into a jump
.*:23: Warning: relaxed out-of-range branch into a jump
.*:24: Warning: relaxed out-of-range branch into a jump
.*:25: Warning: relaxed out-of-range branch into a jump
.*:26: Warning: relaxed out-of-range branch into a jump
.*:27: Warning: relaxed out-of-range branch into a jump
.*:28: Warning: relaxed out-of-range branch into a jump
.*:29: Warning: relaxed out-of-range branch into a jump
.*:30: Warning: relaxed out-of-range branch into a jump
.*:32: Warning: relaxed out-of-range branch into a jump
.*:33: Warning: relaxed out-of-range branch into a jump
.*:37: Warning: relaxed out-of-range branch into a jump
.*:38: Warning: relaxed out-of-range branch into a jump
.*:39: Warning: relaxed out-of-range branch into a jump
.*:40: Warning: relaxed out-of-range branch into a jump
.*:41: Warning: relaxed out-of-range branch into a jump
.*:42: Warning: relaxed out-of-range branch into a jump
.*:43: Warning: relaxed out-of-range branch into a jump
.*:44: Warning: relaxed out-of-range branch into a jump
.*:45: Warning: relaxed out-of-range branch into a jump
.*:46: Warning: relaxed out-of-range branch into a jump
.*:48: Warning: relaxed out-of-range branch into a jump
.*:49: Warning: relaxed out-of-range branch into a jump
.*:51: Warning: relaxed out-of-range branch into a jump
.*:52: Warning: relaxed out-of-range branch into a jump
.*:53: Warning: relaxed out-of-range branch into a jump
.*:54: Warning: relaxed out-of-range branch into a jump
.*:55: Warning: relaxed out-of-range branch into a jump
.*:56: Warning: relaxed out-of-range branch into a jump
.*:57: Warning: relaxed out-of-range branch into a jump
.*:58: Warning: relaxed out-of-range branch into a jump
.*:60: Warning: relaxed out-of-range branch into a jump
.*:61: Warning: relaxed out-of-range branch into a jump
