#objdump: --dwarf=frames
#as:
#...
.*:     file format elf.*-.*riscv

Contents of the .* section:

00000000 0+[0-9a-f]+ 0+000 CIE
  Version:               3
  Augmentation:          .*
  Code alignment factor: .*
  Data alignment factor: .*
  Return address column: .*
  Augmentation data:     .*
#...