.*: Assembler messages:
.*: selected FPU does not support instruction -- `vmrs r0,FPSCR'
.*: selected processor does not support instruction -- `vmrs r1,FPSCR_nzcvqc'
.*: selected processor does not support instruction -- `vmrs r2,VPR'
.*: selected processor does not support instruction -- `vmrs r3,P0'
.*: selected FPU does not support instruction -- `vmsr fpscr,r0'
.*: selected processor does not support instruction -- `vmsr fpscr_nzcvqc,r1'
.*: selected processor does not support instruction -- `vmsr vpr,r2'
.*: selected processor does not support instruction -- `vmsr p0,r3'
