Primary GOT:
 Canonical gp value: 00008250

 Reserved entries:
   Address     Access  Initial Purpose
  00000260 -32752\(gp\) 00000000 Lazy resolver
  00000264 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  00000268 -32744\(gp\) 00000000
  0000026c -32740\(gp\) 00000000

 Global entries:
   Address     Access  Initial Sym\.Val\. Type    Ndx Name
  00000270 -32736\(gp\) 00000000 00000000 NOTYPE  ABS __gnu_absolute_zero
