# readelf: -A
# This test is only valid on ELF based ports.
#notarget: *-*-pe *-*-wince
Attribute Section: aeabi
File Attributes
  Tag_CPU_arch: v8
  Tag_CPU_arch_profile: Application
  Tag_THUMB_ISA_use: Thumb-2

