.*ldmf-stmf-diag.s: Assembler messages:
.*ldmf-stmf-diag.s:7: Error: Illegal operands
.*ldmf-stmf-diag.s:12: Error: Illegal operands
.*ldmf-stmf-diag.s:3: Error: relocation overflow
.*ldmf-stmf-diag.s:4: Error: relocation overflow
.*ldmf-stmf-diag.s:5: Error: relocation overflow
.*ldmf-stmf-diag.s:6: Error: relocation overflow
.*ldmf-stmf-diag.s:8: Error: relocation overflow
.*ldmf-stmf-diag.s:9: Error: relocation overflow
.*ldmf-stmf-diag.s:10: Error: relocation overflow
.*ldmf-stmf-diag.s:11: Error: relocation overflow
