.*: Assembler messages:
.*:16: Error: invalid unextended operand value
.*:18: Error: invalid unextended operand value
.*:20: Error: invalid unextended operand value
.*:22: Error: invalid unextended operand value
.*:24: Error: invalid unextended operand value
.*:26: Error: invalid unextended operand value
.*:28: Error: invalid unextended operand value
.*:30: Error: invalid unextended operand value
.*:32: Error: invalid unextended operand value
.*:34: Error: invalid unextended operand value
.*:36: Error: invalid unextended operand value
.*:38: Error: invalid unextended operand value
.*:40: Error: unsupported relocation
.*:42: Error: unsupported relocation
