[^:]*: Assembler messages:
[^:]*:11: Error: bad type in SIMD instruction -- `vadd.p8 q0,q1,q2'
[^:]*:12: Error: selected FPU does not support instruction -- `vadd.f16 q0,q1,q2'
[^:]*:13: Error: selected FPU does not support instruction -- `vadd.f32 q0,q1,q2'
[^:]*:14: Error: selected FPU does not support instruction -- `vadd.i64 q0,q1,q2'
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:16: Error: bad type in SIMD instruction -- `vsub.p8 q0,q1,q2'
[^:]*:17: Error: selected FPU does not support instruction -- `vsub.f16 q0,q1,q2'
[^:]*:18: Error: selected FPU does not support instruction -- `vsub.f32 q0,q1,q2'
[^:]*:19: Error: selected FPU does not support instruction -- `vsub.i64 q0,q1,q2'
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:21: Error: bad type in SIMD instruction -- `vadd.p8 q0,q1,r2'
[^:]*:22: Error: selected FPU does not support instruction -- `vadd.f16 q0,q1,r2'
[^:]*:23: Error: selected FPU does not support instruction -- `vadd.f32 q0,q1,r2'
[^:]*:24: Error: selected FPU does not support instruction -- `vadd.i64 q0,q1,r2'
[^:]*:25: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:25: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:25: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:25: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:25: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:25: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:26: Error: bad type in SIMD instruction -- `vsub.p8 q0,q1,r2'
[^:]*:27: Error: selected FPU does not support instruction -- `vsub.f16 q0,q1,r2'
[^:]*:28: Error: selected FPU does not support instruction -- `vsub.f32 q0,q1,r2'
[^:]*:29: Error: selected FPU does not support instruction -- `vsub.i64 q0,q1,r2'
[^:]*:30: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:30: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:30: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:30: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:30: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:30: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:31: Error: bad type in SIMD instruction -- `vabd.p8 q0,q1,q2'
[^:]*:32: Error: selected FPU does not support instruction -- `vabd.f16 q0,q1,q2'
[^:]*:33: Error: selected FPU does not support instruction -- `vabd.f32 q0,q1,q2'
[^:]*:34: Error: bad type in SIMD instruction -- `vabd.i64 q0,q1,q2'
[^:]*:35: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:35: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:35: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:35: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:35: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:35: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:36: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:37: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:38: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:39: Warning: instruction is UNPREDICTABLE with PC operand
