[^:]*: Assembler messages:
[^:]*:8: Error: stack pointer offset too large for personality routine
[^:]*:20: Error: stack frame layout does not match personality routine
[^:]*:33: Error: stack frame layout does not match personality routine
[^:]*:39: Error: unable to generate unwinding opcode for reg 20
[^:]*:46: Error: unable to generate unwinding opcode for reg 20
[^:]*:53: Error: unable to generate unwinding opcode for reg 20
[^:]*:63: Error: unable to restore return address from previously restored reg
[^:]*:70: Error: unhandled CFA insn for unwinding \(259\)
[^:]*:77: Error: unable to generate unwinding opcode for frame pointer reg 14
[^:]*:84: Error: unable to generate unwinding opcode for frame pointer offset
[^:]*:91: Error: unwound stack pointer not doubleword aligned
[^:]*:100: Error: stack frame layout too complex for unwinder
[^:]*:110: Error: unwound frame has negative size
