.*: Assembler messages:
.*: Warning: accessing MVE system register without MVE is UNPREDICTABLE
.*: Warning: accessing MVE system register without MVE is UNPREDICTABLE
.*: Warning: accessing MVE system register without MVE is UNPREDICTABLE
.*: Warning: accessing MVE system register without MVE is UNPREDICTABLE
