	.cpu arm9e
	.fpu neon
	.eabi_attribute Tag_CPU_arch, 3
	@ .eabi_attribute Tag_CPU_arch_profile, 0x41
	.eabi_attribute Tag_ARM_ISA_use, 1
	.eabi_attribute Tag_THUMB_ISA_use, 2
	.eabi_attribute Tag_VFP_arch, 4
	.eabi_attribute Tag_WMMX_arch, 2
	.eabi_attribute Tag_Advanced_SIMD_arch, 1
	.eabi_attribute Tag_PCS_config, 2
	.eabi_attribute Tag_ABI_PCS_R9_use, 3
	.eabi_attribute Tag_ABI_PCS_RW_data, 3
	.eabi_attribute Tag_ABI_PCS_RO_data, 2
	.eabi_attribute Tag_ABI_PCS_GOT_use, 2
	.eabi_attribute Tag_ABI_PCS_wchar_t, 0
	.eabi_attribute Tag_ABI_FP_rounding, 1
	.eabi_attribute Tag_ABI_FP_denormal, 2
	.eabi_attribute Tag_ABI_FP_exceptions, 1
	.eabi_attribute Tag_ABI_FP_user_exceptions, 1
	.eabi_attribute Tag_ABI_FP_number_model, 3
	.eabi_attribute Tag_ABI_align8_needed, 2
	.eabi_attribute Tag_ABI_align8_preserved, 2
	.eabi_attribute Tag_ABI_enum_size, 3
	.eabi_attribute Tag_ABI_HardFP_use, 2
	.eabi_attribute Tag_ABI_VFP_args, 1
	@ .eabi_attribute Tag_ABI_WMMX_args, 0
	@ .eabi_attribute Tag_ABI_optimization_goals, 0
	@ .eabi_attribute Tag_ABI_FP_optimization_goals, 0
	@ .eabi_attribute Tag_compatibility, 1, "gnu"
	.eabi_attribute Tag_CPU_unaligned_access, 1
	.eabi_attribute Tag_VFP_HP_extension, 1
	@ .eabi_attribute Tag_ABI_FP_16bit_format, 0
	.eabi_attribute Tag_nodefaults, 1
	@ .eabi_attribute Tag_also_compatible_with,
	.eabi_attribute Tag_T2EE_use, 1
	.eabi_attribute Tag_conformance, "2.08"
	.eabi_attribute Tag_Virtualization_use, 1
	.eabi_attribute Tag_MPextension_use, 1
	.eabi_attribute Tag_DIV_use, 1
